//------------------------------------------------------------------------------
//
// OpenDCC - Cooperative Simple Task Scheduler
//
// Copyright (c) 2008, 2010 Kufer
//
// This source file is subject of the GNU general public license 2,
// that is available at the world-wide-web at
// http://www.gnu.org/licenses/gpl.txt
// 
//-----------------------------------------------------------------------------
//
// file:      cortos_tasklist.h
// author:    Wolfgang Kufer
// contact:   kufer@gmx.de
// webpage:   http://www.opendcc.de
// history:   2008-12-12 V0.1 kw started
//
//-----------------------------------------------------------------------------
//
// purpose:   A small and tiny cooperative scheduler
//
//------------------------------------------------------------------------------
// Interface Guide:
//  #include "cortos.h"
//  #define BUF_SIZE 8
//  uint8_t buffer[BUF_SIZE];
//  cr_fifo_t my_fifo;
//  ...
//  fifo_init (&my_fifo, buffer, BUF_SIZE);       
//  ...
//  Producer:   uint8_t zeichen = ...;
//              cr_fifo_put (&fifo, zeichen);
//  Consumer:   zeichen = cr_fifo_get_wait (&fifo);
//------------------------------------------------------------------------------


#ifndef _CORTOS_TASKLIST_H_
#define _CORTOS_TASKLIST_H_

#include <avr/io.h>
#include <avr/interrupt.h>
#include "cortos_tasklist.h"


//------------------------------------------------------------------------------
//
// Tasks-ENUMS
//
//------------------------------------------------------------------------------

// this is the list of task (higher index = higher priority)
// Every task in the system must have a number

typedef enum {  TASK_IDLE,           // must be the first one, low prio
                TASK_INIT_XBEE,      // at power up - ask some parameters
                TASK_CURSOR,         // Cursor Blinking
                TASK_PARSER,         // Parser for Configure (USB)
                TASK_LED,            // LED driver
                TASK_SYSMON,         // System Monitor
                TASK_PROGRAMMER,     // Sequenzer for read/write addresses
                TASK_XBEE,           // XBEE client
                TASK_OBJECTS,        // Switching delays for Turnouts + Loco control
                TASK_NAVIGATOR,      // GUI
                TASK_DISPLAY,        // lcd update
                TASK_XPRESSNET       // Xpressnet Client
              } t_task_id;



//------------------------------------------------------------------------------
//
// FIFO Objects
//
//------------------------------------------------------------------------------



#endif /* _CORTOS_TASKLIST_H_ */

