//----------------------------------------------------------------
//
// OpenDCC
//
// Copyright (c) 2006 Kufer
//
// This source file is subject of the GNU general public license 2,
// that is available at the world-wide-web at
// http://www.gnu.org/licenses/gpl.txt
//
//-----------------------------------------------------------------
//
// file:      database.h
// author:    Wolfgang Kufer
// contact:   kufer@gmx.de
// history:   2006-08-25 V0.01 started
//            2009-02-28 V0.04 kw added count_loco_in_database
//            2009-07-04 V0.05 kw added assign pic
//
//-----------------------------------------------------------------
//
// purpose:   lowcost central station for dcc
// content:   handling of lok names and speed steps
//            (This is not locobuffer, this is the data base,
//            has nothing to do with the actual dcc content)
//
// interface upstream:
//
//-----------------------------------------------------------------

#ifndef _DATABASE_H_
#define _DATABASE_H_

#include "config.h"
#include <avr/eeprom.h>

typedef union
  {
    struct
      {
        unsigned int addr:14;
        t_format format:2;
      } w;
    unsigned char b[sizeof(unsigned int)];
  } t_addr_fmt;
    

typedef struct
  {
    unsigned char next;     // pointer to next entry
    unsigned char prev;     // pointer to prev entry
    union
      {
        struct
          {
            unsigned int addr:14;
            t_format format:2;
          } w;
        unsigned char b[sizeof(unsigned int)];
      } ;
    unsigned int picture_id;                      // pointer to graphic
    unsigned char name[LOK_NAME_LENGTH];          // multiMaus supports up to 5 chars
                                                  // omitting trailing 0 is allowed
  } t_locoentry;


// extern unsigned char next_search_index;

extern unsigned char actual_database_index;        // the index currently used

void store_curr_index(unsigned char index);

extern unsigned char db_message[17];
extern unsigned char db_message_ready;            // interface flag to Xpressnet


// old calls


void rewind_database(void);         // before dump, do a rewind

void run_database(void);            // multitask replacement, call in loop

void do_xmit_database(void);        // start transfer on Xpressnet

void clear_loco_database(void);     // delete all

void dump_loco_database(void);


//----------------------------------------------------------------------------

void init_database(void);           // at power up



// this returns index of entry
unsigned char scan_loco_database_forward(unsigned char index);
unsigned char scan_loco_database_revers(unsigned char index);
unsigned char search_loco(unsigned int addr);

void get_loco_data(unsigned char index, t_locoentry* actual);
void save_loco_data(unsigned char index, t_locoentry* actual);
void delete_loco_data(unsigned char index);
unsigned char insert_new_loco_data(unsigned char index);
void move_loco_data(unsigned char new_index, unsigned char old_index);

unsigned char get_loco_in_database(void);     


unsigned char format_to_uint8(t_format myformat);

unsigned char store_loco_format(unsigned int addr, t_format format);

unsigned char store_loco_name(unsigned int addr, char * name);

// ret 1 if successful
unsigned char assign_picture_to_loco(unsigned int addr, unsigned int pic_id);

// ret 1 if succesful, sets pict-ID
unsigned int query_picture_to_loco(unsigned int addr, unsigned int *pic_id);


//----------------------------------------------------------------------------
// turnouts
void read_actual_waddr(void);
void write_actual_waddr(void);



//----------------------------------------------------------------------------
// signals
void read_actual_saddr(void);
void write_actual_saddr(void);



#endif  // _DATABASE_H_



