//----------------------------------------------------------------
//
// OpenDCC
//
// Copyright (c) 2006, 2007, 2009 Kufer
//
// This source file is subject of the GNU general public license 2,
// that is available at the world-wide-web at
// http://www.gnu.org/licenses/gpl.txt
//
//-----------------------------------------------------------------
//
// file:      database_switch.c
// author:    Wolfgang Kufer
// contact:   kufer@gmx.de
// history:   2011-01-22 V0.01 kw  taken from Volkmar Dierkes
//
//--------------------------------------------------------------------------
//
// purpose:   lowcost central station for dcc
// content:   handling of switch routes
//
//
//--------------------------------------------------------------------------

#include <stdlib.h>
#include <stdbool.h>
#include <inttypes.h>
#include <avr/io.h>
#include <avr/interrupt.h>
#include <avr/pgmspace.h>         // put var to program memory
#include <avr/eeprom.h>
#include <string.h>

#include "config.h"                // general structures and definitions
#include "timer.h"                 // timerval
#include "cortos.h"                // real time kernel
#include "messages_objects.h"      // actual*
#include "database_switch.h"

#include "display.h"               // display_error


#if ( MENU_SWITCH_TYPE == 1 )


unsigned char actual_databaseW_index;    // the index for actual_lok




unsigned char cur_database_entry;
unsigned char total_databaseW_entry;    // actual number of locos (not included the position 0)

//------------------------------------------------------------------------
//------------------------------------------------------------------------
// Database for NAME and assigned routes
//------------------------------------------------------------------------
//------------------------------------------------------------------------
//
// We allocate this storage to a fixed address to have access from the
// parser with a constant offset to eeprom
// (parser commands: read and write Special Option)
//
#if (EEPROM_FIXED_ADDR == 1)
 #define EEMEM_SWITCH __attribute__((section(".ee_loco")))
#else
 #define EEMEM_SWITCH EEMEM
#endif
//
// please add following command to linker:
//
//   -Wl,--section-start=.ee_loco=0x810080

t_switchentry switchentry[SIZE_SWITCH_DATABASE] EEMEM_SWITCH =
  {
    //  next,   prev,   name                  
    {    1,      8,     {  "Schne.1-Stiege2" }, {{{   5,  0,  1 }}                   }  },
    {    2,      0,     {  "Schne.2-Eckdorf" }, {{{   1,  1,  0 }}, {{   2,  0,  1 }}}  },
    {    3,      1,     {  "Eckdorf-Schne.2" }, {{{   1,  1,  0 }}, {{   2,  0,  1 }}}  },
    {    4,      2,     {  "Stiege1-Eckdorf"  }, {{{   1,  1,  0 }}, {{   2,  0,  1 }}}  },
    {    5,      3,     {  "Hauptstrecke"     }, {{{   0,  0,  1 }}                   }  },
    {    6,      4,     {  "Gterbhf Li An"   }, {{{ 205,  1,  0 }}, {{ 206,  1,  0 }}, {{ 207,  1,  0 }}, {{ 208,  1,  1 }}}  },
    {    7,      5,     {  "Gterbhf Li Aus"  }, {{{ 205,  0,  1 }}}  },
    {    8,      6,     {  "Haus brennt"      }, {{{ 205,  0,  0 }}}  },
    {    0,      7,     {  "Haus gelscht"    }, {{{ 205,  0,  0 }}, {{ 206,  0,  0 }}, {{ 207,  0,  0 }}, {{  208, 0,  1 }}}  },
  };

t_switchentry switch_neu;   // this hold the NEW? -Switch

//---------------------------------------------------------------

/*
static void _write_switch_name(unsigned char index, char * name)
  {
    unsigned char i;
    for (i=0; i<SWITCH_NAME_LENGTH; i++)
      {
        eeprom_write_byte(&switchentry[index].name[i], name[i]);
      }
  }
*/

/*
// ret true if successful
unsigned char assign_picture_to_loco(unsigned int addr, unsigned int pic_id)
  {
    unsigned char i;
    if ((i = !!search_switch(addr)) < SIZE_LOCO_DATABASE)
      {
        eeprom_write_word(&locoentry[i].picture_id, pic_id);
        return(1);
      }
    return(0);       // failed
  }
*/

/*
// ret true if successful
unsigned char store_loco_format(unsigned int addr, t_format format)
  {
    unsigned char i;
    t_locoentry test;
    if ((i = !!search_switch(addr)) < SIZE_LOCO_DATABASE)
      {
        test.b[1] = eeprom_read_byte(&locoentry[i].b[1]);
        test.w.format = format;
        eeprom_write_byte(&locoentry[i].b[1], test.b[1] );
        return(1);
      }
    return(0);       // failed
  }
*/

// fills structure actual

void get_switch_data(unsigned char index, t_switchentry* actual)
  {
    unsigned char j, data;

//    if (index > 0)
//      {
  //      actual->b[0] = eeprom_read_byte(&switchentry[index].b[0]);
  //      actual->b[1] = eeprom_read_byte(&switchentry[index].b[1]);

        for (j=0; j<sizeof(switchentry[0].name); j++)
          {
            if ((data = eeprom_read_byte(&switchentry[index].name[j])))   // yes we have a name
               actual->name[j] = data;
            else actual->name[j] = ' ';
          }
		for (j=0; j<SWITCH_ADR_NUMBER; j++) {
			actual->adr[j].b[0] = eeprom_read_byte(&switchentry[index].adr[j].b[0]);
			actual->adr[j].b[1] = eeprom_read_byte(&switchentry[index].adr[j].b[1]);
		}
//        return;
//      }
//    else
//      { // do no read from eeprom, but use our local values
//        memcpy(actual, &switch_neu, sizeof(switch_neu));
//      }
  }


// copy from structure actual to the given database entry
// no new position
void save_switch_data(unsigned char index, t_switchentry* actual)
  {
    unsigned char i;

//    if (index > 0)
//      {
        //eeprom_write_byte(&locoentry[index].b[0], actual->b[0]);
        //eeprom_write_byte(&locoentry[index].b[1], actual->b[1]);

        //eeprom_write_word(&locoentry[index].picture_id, actual->picture_id);

        for (i=0; i<SWITCH_NAME_LENGTH; i++)
          {
			if (eeprom_read_byte(&switchentry[index].name[i]) != actual->name[i])
				eeprom_write_byte(&switchentry[index].name[i], actual->name[i]);
          }
        for (i=0; i<SWITCH_ADR_NUMBER; i++)
          {
			if (eeprom_read_byte(&switchentry[index].adr[i].b[0]) != actual->adr[i].b[0])
				eeprom_write_byte(&switchentry[index].adr[i].b[0], actual->adr[i].b[0]);
			if (eeprom_read_byte(&switchentry[index].adr[i].b[1]) != actual->adr[i].b[1])
				eeprom_write_byte(&switchentry[index].adr[i].b[1], actual->adr[i].b[1]);
          }
//      }
//    else
//      { // do no write to eeprom, but use our local values
//        memcpy(&switch_neu, actual, sizeof(switch_neu));
//      }
  }

// 'search forward', returns the index of an entry found;

unsigned char scan_switch_database_forward(unsigned char index)
  {
    unsigned char i;

    i = eeprom_read_byte(&switchentry[index].next);
    if (i >= SIZE_SWITCH_DATABASE)
      {
        // panic! chain must be broken
        i = 0;
        display_error(ERR_DATABASE);
      }
    // if (i==0) i = eeprom_read_byte(&switchentry[i].next);
    return(i);
  }


// 'search revers', returns the index of an entry found;

unsigned char scan_switch_database_reverse(unsigned char index)
  {
    unsigned char i;

    i = eeprom_read_byte(&switchentry[index].prev);
    if (i >= SIZE_SWITCH_DATABASE)
      {
        // panic! chain must be broken
        i = 0;
      }
    // if (i==0) i = eeprom_read_byte(&switchentry[i].prev);
    return(i);
  }



unsigned char find_empty_switch_data(void)
  {
    unsigned char i;
    unsigned char stored_h, stored_l;

    for (i=1; i<SIZE_SWITCH_DATABASE; i++)         // start from 0
      {
        stored_h = eeprom_read_byte(&switchentry[i].next);
        if (stored_h == 0x00)
          {
            stored_l = eeprom_read_byte(&switchentry[i].prev);
            if (stored_l == 0x00)
              {
                // empty found
                return(i);
              }
          }
      }
    return(0);
  }


// this creates a new entry and inserts it after the given index.
// the new index is returned
// index = 0: this is void

unsigned char insert_new_switch_data(unsigned char index)
  {
    unsigned char new_index;
    unsigned char temp_next;

    // 1. search for an empty place
    // 2. rearrange pointers

    if ((new_index = find_empty_switch_data()) != 0)
      {
        temp_next = eeprom_read_byte(&switchentry[index].next);
        eeprom_write_byte(&switchentry[new_index].next, temp_next);
        eeprom_write_byte(&switchentry[index].next, new_index);
        eeprom_write_byte(&switchentry[new_index].prev, index);
        eeprom_write_byte(&switchentry[temp_next].prev, new_index);

        total_databaseW_entry++;
      }
    return(new_index);
  }


void delete_switch_data(unsigned char index)
  {
    unsigned char temp_next, temp_prev;

    if (index > 0)            // we do not allow index 0 to be deleted
      {

        // 2. rearrange pointers

        temp_next = eeprom_read_byte(&switchentry[index].next);
        temp_prev = eeprom_read_byte(&switchentry[index].prev);

        eeprom_write_byte(&switchentry[temp_next].prev, temp_prev);
        eeprom_write_byte(&switchentry[temp_prev].next, temp_next);

        // 1. delete content

        eeprom_write_byte(&switchentry[index].prev, 0);
        eeprom_write_byte(&switchentry[index].next, 0);
        total_databaseW_entry--;

        // if (index == actual_database_index)        // if our ref is stolen
        //  {
        //    actual_database_index = temp_next;
        //  }
      }
  }

// the chain at old is broken and the entry goes after new_index
void move_switch_data(unsigned char new_index, unsigned char old_index)
  {
    unsigned char temp_next, temp_prev;

    // 1. rearrange pointers old place

    temp_next = eeprom_read_byte(&switchentry[old_index].next);
    temp_prev = eeprom_read_byte(&switchentry[old_index].prev);

    eeprom_write_byte(&switchentry[temp_next].prev, temp_prev);
    eeprom_write_byte(&switchentry[temp_prev].next, temp_next);

    // 2. rearrange pointers new place

    temp_next = eeprom_read_byte(&switchentry[new_index].next);
    eeprom_write_byte(&switchentry[old_index].next, temp_next);
    eeprom_write_byte(&switchentry[new_index].next, old_index);
    eeprom_write_byte(&switchentry[old_index].prev, new_index);
    eeprom_write_byte(&switchentry[temp_next].prev, old_index);
  }


unsigned char get_switch_in_database(void)
  {
    return(total_databaseW_entry);
  } 

unsigned char count_switch_in_database(void)
  {
    unsigned char i;
    unsigned char databaseW_entry = 0;
    unsigned char index = 0;
    unsigned char stored_h, stored_l;

    index = 0;
    index = scan_switch_database_forward(index);

    for (i=0; i<SIZE_SWITCH_DATABASE; i++)
      {
        if (index != 0)
          {
            databaseW_entry++;
            // check this entry
            stored_l = eeprom_read_byte(&switchentry[i].next);
         
            if (stored_l == 0)
              {
                stored_h = eeprom_read_byte(&switchentry[i].prev);
                if ((stored_h & 0x07) == 0)
                  {
                    display_error(ERR_DATABASE_ADDR0);
                  }
              }
            index = scan_switch_database_forward(index);
          }
      }
    return(databaseW_entry);
  } 


unsigned char read_switch_softkey(unsigned char key) {
	switch (key) {
		case 0:
			return(eeprom_read_byte((void *)eadr_switch_sca));
			break;
		case 1:
			return(eeprom_read_byte((void *)eadr_switch_scb));
			break;
		case 2:
			return(eeprom_read_byte((void *)eadr_switch_scc));
			break;
		case 3:
			return(eeprom_read_byte((void *)eadr_switch_scd));
			break;
		default:
			return(0);
			break;
	}
}

void write_switch_softkey(unsigned char key, unsigned char index) {
	switch (key) {
		case 0:
			eeprom_write_byte((void *)eadr_switch_sca, index );
			break;
		case 1:
			eeprom_write_byte((void *)eadr_switch_scb, index );
			break;
		case 2:
			eeprom_write_byte((void *)eadr_switch_scc, index );
			break;
		case 3:
			eeprom_write_byte((void *)eadr_switch_scd, index );
			break;
		default:
			break;
	}
}





//!warning!

// #if (XPRESSNET_ENABLED == 1)




//---------------------------------------------------------------------------
//
// Init the Switch database
//
//---------------------------------------------------------------------------

unsigned char read_currW_index(void)
  {
    return(eeprom_read_byte((void *)eadr_switch_search_entry));
  }


void store_currW_index(unsigned char index)
  {
    eeprom_write_byte((void *)eadr_switch_search_entry, index );
  }

  
void init_databaseW(void)
  {

    actual_databaseW_index = read_currW_index();

    eeprom_read_block(&switch_neu, &switchentry[0], sizeof(switch_neu));        // load preset for custom switch

    total_databaseW_entry = count_switch_in_database();
    
    //read_actual_switch();
  }

#endif
