//----------------------------------------------------------------
//
// OpenDCC
//
// Copyright (c) 2006 Kufer
//
// This source file is subject of the GNU general public license 2,
// that is available at the world-wide-web at
// http://www.gnu.org/licenses/gpl.txt
//
//-----------------------------------------------------------------
//
// file:      database_switch.h
// author:    Wolfgang Kufer
// contact:   kufer@gmx.de
// history:   2011-01-22 V0.01 kw taken changes from Volkmar Dierkes
//
//-----------------------------------------------------------------
//
// purpose:   lowcost central station for dcc
// content:   handling of switch routes
//
// interface upstream:
//
//-----------------------------------------------------------------

#ifndef _DATABASE_SWITCH_H_
#define _DATABASE_SWITCH_H_

#include "config.h"
#include <avr/eeprom.h>

#if ( MENU_SWITCH_TYPE == 1 )

typedef union
      {
        struct
          {
            unsigned int addr:11;
            unsigned int state:1;
			unsigned int last:1;
          } w;
        unsigned char b[sizeof(unsigned int)];
      } t_switchadr;

typedef struct
  {
    unsigned char next;     // pointer to next entry
    unsigned char prev;     // pointer to prev entry
	unsigned char name[SWITCH_NAME_LENGTH];      // omitting trailing 0 is allowed
    t_switchadr   adr[SWITCH_ADR_NUMBER];
  } t_switchentry;


extern unsigned char actual_databaseW_index;        // the index currently used

void store_currW_index(unsigned char index);


//----------------------------------------------------------------------------

void init_database_switch(void);           // at power up



// this returns index of entry
unsigned char scan_switch_database_forward(unsigned char index);
unsigned char scan_switch_database_reverse(unsigned char index);

void get_switch_data(unsigned char index, t_switchentry* actual);
void save_switch_data(unsigned char index, t_switchentry* actual);
void delete_switch_data(unsigned char index);
unsigned char insert_new_switch_data(unsigned char index);
void move_switch_data(unsigned char new_index, unsigned char old_index);

unsigned char get_switch_in_database(void);     


unsigned char store_switch_item(unsigned int addr, unsigned w_addr, unsigned int value);

unsigned char store_switch_name(unsigned int addr, char * name);


unsigned char read_switch_softkey(unsigned char key);
void write_switch_softkey(unsigned char key, unsigned char index);

#endif  // MENU_SWITCH_TYPE

#endif  // _DATABASE_SWITCH_H_
