//------------------------------------------------------------------------
//
// Emulate a general purpose graphics frontend
// 
//------------------------------------------------------------------------
//
// file:      debug_fonts.c
// history:   2010-06-15 V0.01 nn  started
//            2010-07-11 V0.02 nn  ue was missing, now added
//
//------------------------------------------------------------------------
//
// purpose:   bitmaps for character
//            
// copyright: THIS IS CONFIDENTIAL CODE
//
//            used hardware: MFT from www.opendcc.de
//
//------------------------------------------------------------------------
//
#include <avr/io.h>
#include <avr/interrupt.h>
#include <avr/pgmspace.h>           // put var to program memory
#include <avr/eeprom.h>
#include <util/delay.h>
#include <stdio.h>
#include <stdbool.h>

//
// here we have all codepages used by pc-emu
//
// Die Byte geben die Pixel in den Spalten von links nach rechts wieder, das LSB ist oben.
// Wenn die erforderliche Pixelzahl in X erreicht ist, wird in der Zeile tiefer wieder
// links begonnen. Dies entspricht der blichen Page-Adressierung.
// 
//
//            ------ = Codepage
//            |  --- = ASCII Code
//            |  |
//            v  v             width, height, pixeldata[] ....
const char cp_1F_20[] PROGMEM = {0x03, 0x0D, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, };
const char cp_1F_21[] PROGMEM = {0x04, 0x0D, 0x00, 0x1E, 0x7E, 0x00, 0x00, 0x03, 0x03, 0x00, };
const char cp_1F_27[] PROGMEM = {0x04, 0x0D, 0x00, 0x0E, 0x0E, 0x00, 0x00, 0x00, 0x00, 0x00, };
const char cp_1F_23[] PROGMEM = {0x07, 0x0D, 0x90, 0xF8, 0x96, 0x90, 0xF8, 0x96, 0x00, 0x03, 0x00, 0x00, 0x03, 0x00, 0x00, 0x00, };
const char cp_1F_24[] PROGMEM = {0x07, 0x0D, 0x00, 0x9C, 0x32, 0xFF, 0x62, 0xCC, 0x00, 0x00, 0x01, 0x02, 0x07, 0x02, 0x01, 0x00, };
const char cp_1F_25[] PROGMEM = {0x0F, 0x0D, 0x00, 0x3C, 0x7E, 0x42, 0x7E, 0x3C, 0xC0, 0x20, 0x18, 0xE4, 0xF2, 0x10, 0xF0, 0xE0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0x01, 0x00, 0x00, 0x00, 0x01, 0x03, 0x02, 0x03, 0x01, 0x00, };
const char cp_1F_26[] PROGMEM = {0x0B, 0x0D, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x08, 0x00, };
const char cp_1F_28[] PROGMEM = {0x04, 0x0D, 0xF0, 0xF8, 0x0C, 0x02, 0x03, 0x07, 0x0C, 0x10, };
const char cp_1F_29[] PROGMEM = {0x04, 0x0D, 0x02, 0x0C, 0xF8, 0xF0, 0x10, 0x0C, 0x07, 0x03, };
const char cp_1F_2A[] PROGMEM = {0x07, 0x0D, 0x00, 0x08, 0x28, 0x1E, 0x28, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,  };
const char cp_1F_2B[] PROGMEM = {0x07, 0x0D, 0x20, 0x20, 0x20, 0xFC, 0x20, 0x20, 0x20, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00,  };
const char cp_1F_2C[] PROGMEM = {0x03, 0x0D, 0x00, 0x00, 0x00, 0x00, 0x0B, 0x07, };
const char cp_1F_2D[] PROGMEM = {0x04, 0x0D, 0x80, 0x80, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, };
const char cp_1F_2E[] PROGMEM = {0x03, 0x0D, 0x00, 0x00, 0x00, 0x00, 0x03, 0x03, };
const char cp_1F_2F[] PROGMEM = {0x04, 0x0D, 0x00, 0xE0, 0x1C, 0x02, 0x03, 0x00, 0x00, 0x00, };
const char cp_1F_30[] PROGMEM = {0x07, 0x0D, 0xFC, 0xFE, 0x02, 0x02, 0xFE, 0xFC, 0x00, 0x01, 0x03, 0x02, 0x02, 0x03, 0x01, 0x00, };
const char cp_1F_31[] PROGMEM = {0x07, 0x0D, 0x00, 0x02, 0xFE, 0xFE, 0x00, 0x00, 0x00, 0x00, 0x02, 0x03, 0x03, 0x02, 0x00, 0x00, };
const char cp_1F_32[] PROGMEM = {0x07, 0x0D, 0x08, 0x04, 0x86, 0x46, 0x3E, 0x1C, 0x00, 0x02, 0x03, 0x03, 0x03, 0x03, 0x03, 0x00, };
const char cp_1F_33[] PROGMEM = {0x07, 0x0D, 0x08, 0x04, 0x26, 0x66, 0xFE, 0xCC, 0x00, 0x03, 0x03, 0x02, 0x02, 0x01, 0x01, 0x00, };
const char cp_1F_34[] PROGMEM = {0x07, 0x0D, 0xC0, 0xA0, 0x98, 0xFC, 0xFE, 0x80, 0x00, 0x00, 0x00, 0x00, 0x03, 0x03, 0x00, 0x00, };
const char cp_1F_35[] PROGMEM = {0x07, 0x0D, 0x20, 0x3C, 0x36, 0x36, 0x76, 0xE2, 0x00, 0x03, 0x03, 0x02, 0x02, 0x01, 0x00, 0x00, };
const char cp_1F_36[] PROGMEM = {0x07, 0x0D, 0xF0, 0xF8, 0x1C, 0x16, 0xF2, 0xE2, 0x00, 0x01, 0x03, 0x02, 0x02, 0x03, 0x01, 0x00, };
const char cp_1F_37[] PROGMEM = {0x07, 0x0D, 0x0C, 0x06, 0x06, 0xE6, 0x1E, 0x06, 0x00, 0x00, 0x00, 0x03, 0x00, 0x00, 0x00, 0x00, };
const char cp_1F_38[] PROGMEM = {0x07, 0x0D, 0xDC, 0xFE, 0x32, 0x62, 0xFE, 0xCC, 0x00, 0x01, 0x03, 0x02, 0x02, 0x03, 0x01, 0x00, };
const char cp_1F_39[] PROGMEM = {0x07, 0x0D, 0x3C, 0x7E, 0x42, 0xC2, 0xFE, 0x7C, 0x00, 0x02, 0x02, 0x03, 0x01, 0x00, 0x00, 0x00, };
const char cp_1F_3A[] PROGMEM = {0x04, 0x0D, 0x00, 0x30, 0x30, 0x00, 0x00, 0x03, 0x03, 0x00, };
const char cp_1F_3B[] PROGMEM = {0x04, 0x0D, 0x00, 0x30, 0x30, 0x00, 0x00, 0x0B, 0x07, 0x00, };
const char cp_1F_3C[] PROGMEM = {0x07, 0x0D, 0x20, 0x50, 0x50, 0x88, 0x88, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x00, };
const char cp_1F_3D[] PROGMEM = {0x07, 0x0D, 0x50, 0x50, 0x50, 0x50, 0x50, 0x50, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, };
const char cp_1F_3E[] PROGMEM = {0x07, 0x0D, 0x04, 0x88, 0x88, 0x50, 0x50, 0x20, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, };
const char cp_1F_3F[] PROGMEM = {0x07, 0x0D, 0x00, 0x0C, 0x0E, 0x62, 0x3E, 0x1C, 0x00, 0x00, 0x00, 0x03, 0x03, 0x00, 0x00, 0x00, };
const char cp_1F_40[] PROGMEM = {0x0C, 0x0D, 0x00, 0xF0, 0x08, 0xC4, 0xE2, 0x32, 0x12, 0xE2, 0x32, 0x04, 0xF8, 0x00, 0x00, 0x03, 0x04, 0x09, 0x13, 0x12, 0x11, 0x13, 0x12, 0x09, 0x04, 0x02, };
const char cp_1F_41[] PROGMEM = {0x09, 0x0D, 0x00, 0x80, 0x70, 0x4C, 0x5E, 0xF8, 0xE0, 0x00, 0x00, 0x02, 0x03, 0x02, 0x00, 0x00, 0x02, 0x03, 0x03, 0x02, };
const char cp_1F_42[] PROGMEM = {0x09, 0x0D, 0x02, 0xFE, 0xFE, 0x22, 0x22, 0x32, 0xFE, 0xCC, 0x00, 0x02, 0x03, 0x03, 0x02, 0x02, 0x02, 0x03, 0x01, 0x00, };
const char cp_1F_43[] PROGMEM = {0x09, 0x0D, 0x00, 0xF8, 0xFC, 0x06, 0x02, 0x02, 0x04, 0x0E, 0x00, 0x00, 0x00, 0x01, 0x03, 0x02, 0x02, 0x02, 0x01, 0x00, };
const char cp_1F_44[] PROGMEM = {0x09, 0x0D, 0x02, 0xFE, 0xFE, 0x02, 0x02, 0x06, 0xFC, 0xF8, 0x00, 0x02, 0x03, 0x03, 0x02, 0x02, 0x03, 0x01, 0x00, 0x00, };
const char cp_1F_45[] PROGMEM = {0x07, 0x0D, 0x02, 0xFE, 0xFE, 0x22, 0x72, 0x02, 0x06, 0x02, 0x03, 0x03, 0x02, 0x02, 0x02, 0x03, };
const char cp_1F_46[] PROGMEM = {0x07, 0x0D, 0x02, 0xFE, 0xFE, 0x22, 0x72, 0x02, 0x06, 0x02, 0x03, 0x03, 0x02, 0x00, 0x00, 0x00, };
const char cp_1F_47[] PROGMEM = {0x09, 0x0D, 0x00, 0xF8, 0xFC, 0x06, 0x02, 0x42, 0xC4, 0xCE, 0x40, 0x00, 0x00, 0x01, 0x03, 0x02, 0x02, 0x03, 0x01, 0x00, };
const char cp_1F_48[] PROGMEM = {0x09, 0x0D, 0x02, 0xFE, 0xFE, 0x22, 0x20, 0x22, 0xFE, 0xFE, 0x02, 0x02, 0x03, 0x03, 0x02, 0x00, 0x02, 0x03, 0x03, 0x02, };
const char cp_1F_49[] PROGMEM = {0x04, 0x0D, 0x02, 0xFE, 0xFE, 0x02, 0x02, 0x03, 0x03, 0x02, };
const char cp_1F_4A[] PROGMEM = {0x07, 0x0D, 0x80, 0x80, 0x00, 0x02, 0xFE, 0xFE, 0x02, 0x01, 0x03, 0x02, 0x02, 0x03, 0x01, 0x00, };
const char cp_1F_4B[] PROGMEM = {0x09, 0x0D, 0x02, 0xFE, 0xFE, 0x22, 0x70, 0xCA, 0x86, 0x02, 0x02, 0x02, 0x03, 0x03, 0x02, 0x00, 0x02, 0x03, 0x03, 0x02,  };
const char cp_1F_4C[] PROGMEM = {0x08, 0x0D, 0x02, 0xFE, 0xFE, 0x02, 0x00, 0x00, 0xC0, 0x00, 0x02, 0x03, 0x03, 0x02, 0x02, 0x03, 0x03, 0x00, };
const char cp_1F_4D[] PROGMEM = {0x0B, 0x0D, 0x02, 0xFE, 0x0E, 0x7E, 0xF0, 0x80, 0x70, 0x0E, 0xFE, 0xFE, 0x02, 0x02, 0x03, 0x02, 0x00, 0x03, 0x03, 0x00, 0x02, 0x03, 0x03, 0x02, };
const char cp_1F_4E[] PROGMEM = {0x09, 0x0D, 0x02, 0xFE, 0x06, 0x0E, 0x38, 0x70, 0xC2, 0xFE, 0x02, 0x02, 0x03, 0x02, 0x00, 0x00, 0x00, 0x01, 0x03, 0x00, };
const char cp_1F_4F[] PROGMEM = {0x0A, 0x0D, 0x00, 0xF8, 0xFC, 0x06, 0x02, 0x02, 0x06, 0xFC, 0xF8, 0x00, 0x00, 0x00, 0x01, 0x03, 0x02, 0x02, 0x03, 0x01, 0x00, 0x00, };
const char cp_1F_50[] PROGMEM = {0x08, 0x0D, 0x02, 0xFE, 0xFE, 0x22, 0x22, 0x3E, 0x1C, 0x00, 0x02, 0x03, 0x03, 0x02, 0x00, 0x00, 0x00, 0x00, };
const char cp_1F_51[] PROGMEM = {0x0A, 0x0D, 0x00, 0xF8, 0xFC, 0x06, 0x02, 0x02, 0x06, 0xFC, 0xF8, 0x00, 0x00, 0x00, 0x01, 0x03, 0x0E, 0x1E, 0x13, 0x11, 0x00, 0x00, };
const char cp_1F_52[] PROGMEM = {0x09, 0x0D, 0x02, 0xFE, 0xFE, 0x22, 0x62, 0xE2, 0xBE, 0x1C, 0x00, 0x02, 0x03, 0x03, 0x02, 0x00, 0x01, 0x03, 0x02, 0x02, };
const char cp_1F_53[] PROGMEM = {0x08, 0x0D, 0x00, 0x9C, 0x1E, 0x32, 0x62, 0xE4, 0xCE, 0x00, 0x00, 0x03, 0x01, 0x02, 0x02, 0x03, 0x01, 0x00, };
const char cp_1F_54[] PROGMEM = {0x08, 0x0D, 0x06, 0x02, 0x02, 0xFE, 0xFE, 0x02, 0x02, 0x06, 0x00, 0x00, 0x02, 0x03, 0x03, 0x02, 0x00, 0x00, };
const char cp_1F_55[] PROGMEM = {0x08, 0x0D, 0x02, 0xFE, 0xFE, 0x02, 0x00, 0x02, 0xFE, 0x02, 0x00, 0x01, 0x03, 0x02, 0x02, 0x02, 0x01, 0x00, };
const char cp_1F_56[] PROGMEM = {0x09, 0x0D, 0x02, 0x06, 0x1E, 0x7A, 0xE0, 0x80, 0x62, 0x1E, 0x06, 0x00, 0x00, 0x00, 0x00, 0x03, 0x03, 0x00, 0x00, 0x00, };
const char cp_1F_57[] PROGMEM = {0x0D, 0x0D, 0x02, 0x0E, 0x7E, 0xF0, 0x82, 0x62, 0x1E, 0x7E, 0xE2, 0x80, 0x62, 0x1E, 0x02, 0x00, 0x00, 0x00, 0x03, 0x03, 0x00, 0x00, 0x00, 0x03, 0x03, 0x00, 0x00, 0x00, };
const char cp_1F_58[] PROGMEM = {0x09, 0x0D, 0x02, 0x06, 0x8E, 0x5A, 0x70, 0xD0, 0x8A, 0x06, 0x02, 0x02, 0x03, 0x03, 0x02, 0x00, 0x02, 0x03, 0x03, 0x02, };
const char cp_1F_59[] PROGMEM = {0x08, 0x0D, 0x02, 0x06, 0x1E, 0xFA, 0xE0, 0x1A, 0x06, 0x02, 0x00, 0x00, 0x02, 0x03, 0x03, 0x02, 0x00, 0x00, };
const char cp_1F_5A[] PROGMEM = {0x08, 0x0D, 0x00, 0x0E, 0xC6, 0xE2, 0x3A, 0x1E, 0x06, 0x82, 0x02, 0x03, 0x03, 0x02, 0x02, 0x02, 0x03, 0x03, };
const char cp_1F_5B[] PROGMEM = {0x04, 0x0D, 0x00, 0xFE, 0xFE, 0x02, 0x00, 0x1F, 0x1F, 0x10, };
const char cp_1F_5C[] PROGMEM = {0x04, 0x0D, 0x06, 0x38, 0xC0, 0x00, 0x00, 0x00, 0x01, 0x02, };
const char cp_1F_5D[] PROGMEM = {0x04, 0x0D, 0x02, 0xFE, 0xFE, 0x00, 0x10, 0x1F, 0x1F, 0x00, };
const char cp_1F_5E[] PROGMEM = {0x08, 0x0D, 0x20, 0x18, 0x04, 0x02, 0x04, 0x18, 0x20, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, };
const char cp_1F_5F[] PROGMEM = {0x07, 0x0D, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, };
const char cp_1F_60[] PROGMEM = {0x04, 0x0D, 0x00, 0x02, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00,  };
const char cp_1F_61[] PROGMEM = {0x06, 0x0D, 0x20, 0xB0, 0x90, 0xF0, 0xE0, 0x00, 0x01, 0x03, 0x02, 0x03, 0x03, 0x02, };
const char cp_1F_62[] PROGMEM = {0x06, 0x0D, 0xFE, 0xFE, 0x10, 0xF0, 0xE0, 0x00, 0x03, 0x01, 0x02, 0x03, 0x01, 0x00, };
const char cp_1F_63[] PROGMEM = {0x06, 0x0D, 0xE0, 0xF0, 0x10, 0x30, 0x30, 0x00, 0x01, 0x03, 0x02, 0x02, 0x01, 0x00, };
const char cp_1F_64[] PROGMEM = {0x06, 0x0D, 0xE0, 0xF0, 0x12, 0xFE, 0xFE, 0x00, 0x01, 0x03, 0x02, 0x03, 0x03, 0x02, };
const char cp_1F_65[] PROGMEM = {0x06, 0x0D, 0xE0, 0xF0, 0x50, 0x70, 0x60, 0x00, 0x01, 0x03, 0x02, 0x02, 0x01, 0x00, };
const char cp_1F_66[] PROGMEM = {0x04, 0x0D, 0x10, 0xFC, 0xFE, 0x12, 0x02, 0x03, 0x03, 0x02,  };
const char cp_1F_67[] PROGMEM = {0x07, 0x0D, 0x60, 0xF0, 0x90, 0xF0, 0x70, 0x10, 0x00, 0x0F, 0x16, 0x16, 0x16, 0x16, 0x0C, 0x00, };
const char cp_1F_68[] PROGMEM = {0x07, 0x0D, 0x02, 0xFE, 0xFE, 0x20, 0xF0, 0xF0, 0x00, 0x02, 0x03, 0x03, 0x00, 0x03, 0x03, 0x02, };
const char cp_1F_69[] PROGMEM = {0x04, 0x0D, 0x10, 0xF6, 0xF6, 0x00, 0x02, 0x03, 0x03, 0x02, };
const char cp_1F_6A[] PROGMEM = {0x04, 0x0D, 0x10, 0xF6, 0xF6, 0x00, 0x10, 0x1F, 0x0F, 0x00, };
const char cp_1F_6B[] PROGMEM = {0x08, 0x0D, 0x02, 0xFE, 0xFE, 0x40, 0xF0, 0x90, 0x10, 0x00, 0x02, 0x03, 0x03, 0x02, 0x00, 0x03, 0x03, 0x02, };
const char cp_1F_6C[] PROGMEM = {0x04, 0x0D, 0x02, 0xFE, 0xFE, 0x00, 0x02, 0x03, 0x03, 0x02, };
const char cp_1F_6D[] PROGMEM = {0x0A, 0x0D, 0x10, 0xF0, 0xF0, 0x20, 0xF0, 0xF0, 0x20, 0xF0, 0xF0, 0x00, 0x02, 0x03, 0x03, 0x00, 0x03, 0x03, 0x00, 0x03, 0x03, 0x02, };
const char cp_1F_6E[] PROGMEM = {0x07, 0x0D, 0x10, 0xF0, 0xF0, 0x20, 0xF0, 0xF0, 0x00, 0x02, 0x03, 0x03, 0x00, 0x03, 0x03, 0x02, };
const char cp_1F_6F[] PROGMEM = {0x06, 0x0D, 0xE0, 0xF0, 0x10, 0xF0, 0xE0, 0x00, 0x01, 0x03, 0x02, 0x03, 0x01, 0x00, };
const char cp_1F_70[] PROGMEM = {0x06, 0x0D, 0xF0, 0xF0, 0x10, 0xF0, 0xE0, 0x00, 0x1F, 0x1F, 0x12, 0x03, 0x01, 0x00, };
const char cp_1F_71[] PROGMEM = {0x06, 0x0D, 0xE0, 0xF0, 0x10, 0xE0, 0xF0, 0x00, 0x01, 0x03, 0x12, 0x1F, 0x1F, 0x10, };
const char cp_1F_72[] PROGMEM = {0x06, 0x0D, 0x10, 0xF0, 0xF0, 0x20, 0x10, 0x30, 0x02, 0x03, 0x03, 0x02, 0x00, 0x00, };
const char cp_1F_73[] PROGMEM = {0x06, 0x0D, 0x60, 0x70, 0xD0, 0x90, 0xB0, 0x00, 0x03, 0x02, 0x02, 0x03, 0x01, 0x00, };
const char cp_1F_74[] PROGMEM = {0x04, 0x0D, 0x10, 0xF0, 0xFC, 0x10, 0x00, 0x03, 0x03, 0x02, };
const char cp_1F_75[] PROGMEM = {0x07, 0x0D, 0x10, 0xF0, 0xF0, 0x00, 0xF0, 0xF0, 0x00, 0x00, 0x01, 0x03, 0x02, 0x03, 0x03, 0x02,  };
const char cp_1F_76[] PROGMEM = {0x05, 0x0D, 0xF0, 0xF0, 0x00, 0xF0, 0x10, 0x00, 0x03, 0x03, 0x00, 0x00,  };
const char cp_1F_77[] PROGMEM = {0x08, 0x0D, 0x70, 0xF0, 0x80, 0x70, 0xF0, 0x80, 0x70, 0x10, 0x00, 0x03, 0x03, 0x00, 0x03, 0x03, 0x00, 0x00, };
const char cp_1F_78[] PROGMEM = {0x06, 0x0D, 0x10, 0x30, 0xF0, 0xE0, 0x90, 0x10, 0x02, 0x03, 0x00, 0x03, 0x03, 0x02, };
const char cp_1F_79[] PROGMEM = {0x06, 0x0D, 0x10, 0x70, 0xF0, 0x80, 0x70, 0x10, 0x18, 0x10, 0x0D, 0x03, 0x00, 0x00, };
const char cp_1F_7A[] PROGMEM = {0x06, 0x0D, 0x30, 0x90, 0xF0, 0x70, 0x10, 0x00, 0x02, 0x03, 0x03, 0x02, 0x03, 0x00, };
const char cp_1F_7B[] PROGMEM = {0x05, 0x0D, 0x00, 0x40, 0xBC, 0x1E, 0x02, 0x00, 0x00, 0x0F, 0x1F, 0x10,  };
const char cp_1F_7C[] PROGMEM = {0x03, 0x0D, 0x00, 0xFE, 0x00, 0x00, 0x1F, 0x00,  };
const char cp_1F_7D[] PROGMEM = {0x05, 0x0D, 0x02, 0x1E, 0xBC, 0x40, 0x00, 0x10, 0x1F, 0x0F, 0x00, 0x00,  };
const char cp_1F_7E[] PROGMEM = {0x07, 0x0D, 0xC0, 0x40, 0x40, 0x80, 0x80, 0xC0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,  };
// some specials
const char cp_1F_C4[] PROGMEM = {0x09, 0x0D, 0x00, 0x80, 0x71, 0x4D, 0x5E, 0xF9, 0xE1, 0x00, 0x00, 0x02, 0x03, 0x02, 0x00, 0x00, 0x02, 0x03, 0x03, 0x02, };
const char cp_1F_D6[] PROGMEM = {0x0A, 0x0D, 0x00, 0xF8, 0xFD, 0x07, 0x02, 0x03, 0x07, 0xFC, 0xF8, 0x00, 0x00, 0x00, 0x01, 0x03, 0x02, 0x02, 0x03, 0x01, 0x00, 0x00, };
const char cp_1F_DC[] PROGMEM = {0x08, 0x0D, 0x02, 0xFE, 0xFF, 0x03, 0x00, 0x03, 0xFF, 0x02, 0x00, 0x01, 0x03, 0x02, 0x02, 0x02, 0x01, 0x00, };
const char cp_1F_E4[] PROGMEM = {0x06, 0x0D, 0x26, 0xB6, 0x90, 0xF6, 0xE6, 0x00, 0x01, 0x03, 0x02, 0x03, 0x03, 0x02, };
const char cp_1F_F6[] PROGMEM = {0x06, 0x0D, 0xE6, 0xF6, 0x10, 0xF6, 0xE6, 0x00, 0xE1, 0xE3, 0xE2, 0xE3, 0xE1, 0xE0, };
const char cp_1F_FC[] PROGMEM = {0x07, 0x0D, 0x10, 0xF6, 0xF6, 0x00, 0xF6, 0xF6, 0x00, 0xE0, 0xE1, 0xE3, 0xE2, 0xE3, 0xE3, 0xE2, };
const char cp_1F_DF[] PROGMEM = {0x07, 0x0D, 0x00, 0xFC, 0xFE, 0x12, 0xFE, 0xEC, 0x00, 0x02, 0x03, 0x03, 0x02, 0x03, 0x01, 0x00, };

const char cp_1C_20[] PROGMEM = {0x03, 0x0A, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, };
const char cp_1C_21[] PROGMEM = {0x04, 0x0A, 0x00, 0x8E, 0xBE, 0x00, 0x00, 0x01, 0x01, 0x00, };
const char cp_1C_27[] PROGMEM = {0x03, 0x0A, 0x00, 0x0E, 0x0E, 0x00, 0x00, 0x00, };
const char cp_1C_23[] PROGMEM = {0x06, 0x0A, 0x50, 0xF0, 0x5E, 0xF0, 0x5E, 0x50, 0x00, 0x01, 0x00, 0x01, 0x00, 0x00, };
const char cp_1C_24[] PROGMEM = {0x06, 0x0A, 0x8C, 0x1A, 0xFF, 0x32, 0xE4, 0x00, 0x00, 0x01, 0x03, 0x01, 0x00, 0x00, };
const char cp_1C_25[] PROGMEM = {0x0A, 0x0A, 0x00, 0x1C, 0x22, 0x9C, 0x60, 0x18, 0xE4, 0x12, 0xE0, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, };
const char cp_1C_26[] PROGMEM = {0x09, 0x0A, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, };
const char cp_1C_28[] PROGMEM = {0x04, 0x0A, 0xF0, 0xFC, 0x04, 0x02, 0x00, 0x03, 0x02, 0x00, };
const char cp_1C_29[] PROGMEM = {0x04, 0x0A, 0x02, 0x04, 0xFC, 0xF0, 0x00, 0x02, 0x03, 0x00, };
const char cp_1C_2A[] PROGMEM = {0x06, 0x0A, 0x08, 0x28, 0x1E, 0x28, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, };
const char cp_1C_2B[] PROGMEM = {0x06, 0x0A, 0x20, 0x20, 0xF8, 0x20, 0x20, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, };
const char cp_1C_2C[] PROGMEM = {0x03, 0x0A, 0x80, 0x80, 0x00, 0x01, 0x03, 0x00, };
const char cp_1C_2D[] PROGMEM = {0x04, 0x0A, 0x40, 0x40, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00, };
const char cp_1C_2E[] PROGMEM = {0x03, 0x0A, 0x80, 0x80, 0x00, 0x01, 0x01, 0x00, };
const char cp_1C_2F[] PROGMEM = {0x03, 0x0A, 0x80, 0x78, 0x06, 0x01, 0x00, 0x00, };
const char cp_1C_30[] PROGMEM = {0x06, 0x0A, 0xFC, 0xFE, 0x02, 0xFE, 0xFC, 0x00, 0x00, 0x01, 0x01, 0x01, 0x00, 0x00, };
const char cp_1C_31[] PROGMEM = {0x06, 0x0A, 0x00, 0x02, 0xFE, 0xFE, 0x00, 0x00, 0x00, 0x01, 0x01, 0x01, 0x01, 0x00, };
const char cp_1C_32[] PROGMEM = {0x06, 0x0A, 0x0C, 0xC6, 0xC6, 0xBE, 0x8C, 0x00, 0x01, 0x01, 0x01, 0x01, 0x01, 0x00, };
const char cp_1C_33[] PROGMEM = {0x06, 0x0A, 0x84, 0x02, 0x12, 0xFE, 0xEC, 0x00, 0x00, 0x01, 0x01, 0x01, 0x00, 0x00, };
const char cp_1C_34[] PROGMEM = {0x06, 0x0A, 0x60, 0x50, 0x48, 0xFC, 0xFE, 0x40, 0x00, 0x00, 0x00, 0x01, 0x01, 0x00, };
const char cp_1C_35[] PROGMEM = {0x06, 0x0A, 0xB0, 0xBE, 0x36, 0xB6, 0x62, 0x00, 0x01, 0x01, 0x01, 0x00, 0x00, 0x00, };
const char cp_1C_36[] PROGMEM = {0x06, 0x0A, 0xF0, 0xFC, 0x14, 0xF2, 0xE2, 0x00, 0x00, 0x01, 0x01, 0x01, 0x00, 0x00, };
const char cp_1C_37[] PROGMEM = {0x06, 0x0A, 0x06, 0x06, 0xC6, 0x3E, 0x06, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00, };
const char cp_1C_38[] PROGMEM = {0x06, 0x0A, 0xCC, 0xFE, 0x32, 0xFE, 0xCC, 0x00, 0x00, 0x01, 0x01, 0x01, 0x00, 0x00, };
const char cp_1C_39[] PROGMEM = {0x06, 0x0A, 0x1C, 0x3E, 0xA2, 0xFE, 0x3C, 0x00, 0x01, 0x01, 0x00, 0x00, 0x00, 0x00, };
const char cp_1C_3A[] PROGMEM = {0x04, 0x0A, 0x00, 0xB0, 0xB0, 0x00, 0x00, 0x01, 0x01, 0x00, };
const char cp_1C_3B[] PROGMEM = {0x04, 0x0A, 0x00, 0xB0, 0xB0, 0x00, 0x00, 0x01, 0x03, 0x00, };
const char cp_1C_3C[] PROGMEM = {0x06, 0x0A, 0x20, 0x50, 0x50, 0x50, 0x88, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, };
const char cp_1C_3D[] PROGMEM = {0x06, 0x0A, 0x50, 0x50, 0x50, 0x50, 0x50, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, };
const char cp_1C_3E[] PROGMEM = {0x06, 0x0A, 0x88, 0x50, 0x50, 0x50, 0x20, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, };
const char cp_1C_3F[] PROGMEM = {0x06, 0x0A, 0x00, 0x0C, 0x8E, 0xA2, 0x1E, 0x0C, 0x00, 0x00, 0x01, 0x01, 0x00, 0x00, };
const char cp_1C_40[] PROGMEM = {0x0A, 0x0A, 0xF0, 0x08, 0xC4, 0xE2, 0x12, 0x92, 0xE2, 0xB4, 0xF8, 0x00, 0x00, 0x01, 0x02, 0x01, 0x01, 0x00, 0x01, 0x02, 0x01, 0x00, };
const char cp_1C_41[] PROGMEM = {0x08, 0x0A, 0x00, 0xC0, 0x30, 0x2E, 0x3E, 0xF8, 0xC0, 0x00, 0x01, 0x01, 0x01, 0x00, 0x01, 0x01, 0x01, 0x01, };
const char cp_1C_42[] PROGMEM = {0x08, 0x0A, 0x02, 0xFE, 0xFE, 0x12, 0x12, 0xFE, 0xEC, 0x00, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x00, 0x00, };
const char cp_1C_43[] PROGMEM = {0x09, 0x0A, 0x00, 0x78, 0xFC, 0x86, 0x02, 0x02, 0x04, 0x8E, 0x00, 0x00, 0x00, 0x00, 0x01, 0x01, 0x01, 0x01, 0x00, 0x00, };
const char cp_1C_44[] PROGMEM = {0x08, 0x0A, 0x02, 0xFE, 0xFE, 0x02, 0x02, 0x86, 0xFC, 0x78, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x00, 0x00, };
const char cp_1C_45[] PROGMEM = {0x06, 0x0A, 0x02, 0xFE, 0xFE, 0x12, 0x3A, 0x86, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, };
const char cp_1C_46[] PROGMEM = {0x06, 0x0A, 0x02, 0xFE, 0xFE, 0x12, 0x3A, 0x06, 0x01, 0x01, 0x01, 0x01, 0x00, 0x00, };
const char cp_1C_47[] PROGMEM = {0x09, 0x0A, 0x00, 0x78, 0xFC, 0x86, 0x02, 0x42, 0xC4, 0xCE, 0x40, 0x00, 0x00, 0x00, 0x01, 0x01, 0x01, 0x01, 0x00, 0x00, };
const char cp_1C_48[] PROGMEM = {0x09, 0x0A, 0x02, 0xFE, 0xFE, 0x12, 0x10, 0x12, 0xFE, 0xFE, 0x02, 0x01, 0x01, 0x01, 0x01, 0x00, 0x01, 0x01, 0x01, 0x01, };
const char cp_1C_49[] PROGMEM = {0x04, 0x0A, 0x02, 0xFE, 0xFE, 0x02, 0x01, 0x01, 0x01, 0x01, };
const char cp_1C_4A[] PROGMEM = {0x06, 0x0A, 0xC0, 0xC0, 0x02, 0xFE, 0xFE, 0x02, 0x00, 0x01, 0x01, 0x01, 0x00, 0x00, };
const char cp_1C_4B[] PROGMEM = {0x08, 0x0A, 0x02, 0xFE, 0xFE, 0x32, 0x78, 0xC6, 0x82, 0x02, 0x01, 0x01, 0x01, 0x01, 0x00, 0x01, 0x01, 0x01, };
const char cp_1C_4C[] PROGMEM = {0x07, 0x0A, 0x02, 0xFE, 0xFE, 0x02, 0x00, 0x80, 0xC0, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, };
const char cp_1C_4D[] PROGMEM = {0x0A, 0x0A, 0x02, 0xFE, 0x0E, 0x7E, 0xF0, 0x70, 0x0E, 0xFE, 0xFE, 0x02, 0x01, 0x01, 0x01, 0x00, 0x01, 0x00, 0x01, 0x01, 0x01, 0x01, };
const char cp_1C_4E[] PROGMEM = {0x08, 0x0A, 0x02, 0xFE, 0x06, 0x1C, 0x38, 0xE2, 0xFE, 0x02, 0x01, 0x01, 0x01, 0x00, 0x00, 0x00, 0x01, 0x00, };
const char cp_1C_4F[] PROGMEM = {0x0A, 0x0A, 0x00, 0x78, 0xFC, 0x86, 0x02, 0x02, 0x86, 0xFC, 0x78, 0x00, 0x00, 0x00, 0x00, 0x01, 0x01, 0x01, 0x01, 0x00, 0x00, 0x00, };
const char cp_1C_50[] PROGMEM = {0x07, 0x0A, 0x02, 0xFE, 0xFE, 0x22, 0x22, 0x3E, 0x1C, 0x01, 0x01, 0x01, 0x01, 0x00, 0x00, 0x00, };
const char cp_1C_51[] PROGMEM = {0x0A, 0x0A, 0x00, 0x78, 0xFC, 0x86, 0x02, 0x02, 0x86, 0xFC, 0x78, 0x00, 0x00, 0x00, 0x00, 0x01, 0x03, 0x03, 0x01, 0x00, 0x00, 0x00, };
const char cp_1C_52[] PROGMEM = {0x08, 0x0A, 0x02, 0xFE, 0xFE, 0x12, 0x72, 0xEE, 0x8C, 0x00, 0x01, 0x01, 0x01, 0x01, 0x00, 0x01, 0x01, 0x01, };
const char cp_1C_53[] PROGMEM = {0x07, 0x0A, 0x00, 0x9C, 0xBE, 0x32, 0xF4, 0xE6, 0x00, 0x00, 0x01, 0x00, 0x01, 0x01, 0x00, 0x00, };
const char cp_1C_54[] PROGMEM = {0x06, 0x0A, 0x06, 0x02, 0xFE, 0xFE, 0x02, 0x06, 0x00, 0x01, 0x01, 0x01, 0x01, 0x00, };
const char cp_1C_55[] PROGMEM = {0x08, 0x0A, 0x02, 0xFE, 0xFE, 0x02, 0x00, 0x02, 0xFE, 0x02, 0x00, 0x00, 0x01, 0x01, 0x01, 0x01, 0x00, 0x00, };
const char cp_1C_56[] PROGMEM = {0x08, 0x0A, 0x02, 0x0E, 0x7E, 0xF2, 0x80, 0x72, 0x0E, 0x02, 0x00, 0x00, 0x00, 0x01, 0x01, 0x00, 0x00, 0x00, };
const char cp_1C_57[] PROGMEM = {0x0C, 0x0A, 0x02, 0x0E, 0x3E, 0xF0, 0xC2, 0x36, 0x3E, 0xF2, 0xC0, 0x3A, 0x06, 0x02, 0x00, 0x00, 0x00, 0x01, 0x01, 0x00, 0x00, 0x01, 0x01, 0x00, 0x00, 0x00};
const char cp_1C_58[] PROGMEM = {0x07, 0x0A, 0x02, 0x86, 0x5E, 0x7A, 0xE8, 0x86, 0x02, 0x01, 0x01, 0x01, 0x00, 0x01, 0x01, 0x01, };
const char cp_1C_59[] PROGMEM = {0x08, 0x0A, 0x02, 0x06, 0x1E, 0xFA, 0xE0, 0x1A, 0x06, 0x02, 0x00, 0x00, 0x01, 0x01, 0x01, 0x01, 0x00, 0x00, };
const char cp_1C_5A[] PROGMEM = {0x07, 0x0A, 0x00, 0x8E, 0xE2, 0x7A, 0x1E, 0x86, 0xC2, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, };
const char cp_1C_5B[] PROGMEM = {0x04, 0x0A, 0x00, 0xFE, 0xFE, 0x02, 0x00, 0x03, 0x03, 0x00, };
const char cp_1C_5C[] PROGMEM = {0x03, 0x0A, 0x06, 0x78, 0x80, 0x00, 0x00, 0x01, };
const char cp_1C_5D[] PROGMEM = {0x04, 0x0A, 0x02, 0xFE, 0xFE, 0x00, 0x00, 0x03, 0x03, 0x00, };
const char cp_1C_5E[] PROGMEM = {0x06, 0x0A, 0x20, 0x18, 0x04, 0x18, 0x20, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, };
const char cp_1C_5F[] PROGMEM = {0x06, 0x0A, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, };
const char cp_1C_60[] PROGMEM = {0x04, 0x0A, 0x00, 0x02, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, };
const char cp_1C_61[] PROGMEM = {0x06, 0x0A, 0xA0, 0xD0, 0x50, 0xF0, 0xE0, 0x00, 0x00, 0x01, 0x01, 0x01, 0x01, 0x01, };
const char cp_1C_62[] PROGMEM = {0x06, 0x0A, 0xFE, 0xFE, 0x10, 0xF0, 0xE0, 0x00, 0x01, 0x00, 0x01, 0x01, 0x00, 0x00, };
const char cp_1C_63[] PROGMEM = {0x05, 0x0A, 0xE0, 0xF0, 0x10, 0x30, 0x00, 0x00, 0x01, 0x01, 0x01, 0x00, };
const char cp_1C_64[] PROGMEM = {0x06, 0x0A, 0xE0, 0xF0, 0x12, 0xFE, 0xFE, 0x00, 0x00, 0x01, 0x01, 0x01, 0x01, 0x01, };
const char cp_1C_65[] PROGMEM = {0x06, 0x0A, 0xE0, 0xF0, 0x50, 0x70, 0x60, 0x00, 0x00, 0x01, 0x01, 0x01, 0x01, 0x00, };
const char cp_1C_66[] PROGMEM = {0x04, 0x0A, 0x10, 0xFC, 0xFE, 0x12, 0x01, 0x01, 0x01, 0x01, };
const char cp_1C_67[] PROGMEM = {0x06, 0x0A, 0x50, 0xF8, 0xA8, 0xB8, 0x98, 0x88, 0x01, 0x03, 0x02, 0x02, 0x03, 0x01, };
const char cp_1C_68[] PROGMEM = {0x07, 0x0A, 0x02, 0xFE, 0xFE, 0x10, 0xF0, 0xE0, 0x00, 0x01, 0x01, 0x01, 0x00, 0x01, 0x01, 0x01, };
const char cp_1C_69[] PROGMEM = {0x04, 0x0A, 0x10, 0xF6, 0xF6, 0x00, 0x01, 0x01, 0x01, 0x01, };
const char cp_1C_6A[] PROGMEM = {0x04, 0x0A, 0x10, 0xF6, 0xF6, 0x00, 0x00, 0x03, 0x03, 0x00, };
const char cp_1C_6B[] PROGMEM = {0x07, 0x0A, 0x02, 0xFE, 0xFE, 0x20, 0xF0, 0xD0, 0x10, 0x01, 0x01, 0x01, 0x00, 0x01, 0x01, 0x01, };
const char cp_1C_6C[] PROGMEM = {0x04, 0x0A, 0x02, 0xFE, 0xFE, 0x00, 0x01, 0x01, 0x01, 0x01, };
const char cp_1C_6D[] PROGMEM = {0x0A, 0x0A, 0x10, 0xF0, 0xF0, 0x10, 0xF0, 0xE0, 0x10, 0xF0, 0xE0, 0x00, 0x01, 0x01, 0x01, 0x00, 0x01, 0x01, 0x00, 0x01, 0x01, 0x01, };
const char cp_1C_6E[] PROGMEM = {0x07, 0x0A, 0x10, 0xF0, 0xF0, 0x10, 0xF0, 0xE0, 0x00, 0x01, 0x01, 0x01, 0x00, 0x01, 0x01, 0x01, };
const char cp_1C_6F[] PROGMEM = {0x06, 0x0A, 0xE0, 0xF0, 0x10, 0xF0, 0xE0, 0x00, 0x00, 0x01, 0x01, 0x01, 0x00, 0x00, };
const char cp_1C_70[] PROGMEM = {0x06, 0x0A, 0xF8, 0xF8, 0x88, 0xF8, 0x70, 0x00, 0x03, 0x03, 0x02, 0x00, 0x00, 0x00, };
const char cp_1C_71[] PROGMEM = {0x06, 0x0A, 0x70, 0xF8, 0x88, 0xF0, 0xF8, 0x00, 0x00, 0x00, 0x02, 0x03, 0x03, 0x02, };
const char cp_1C_72[] PROGMEM = {0x05, 0x0A, 0x10, 0xF0, 0xF0, 0x10, 0x30, 0x01, 0x01, 0x01, 0x01, 0x00, };
const char cp_1C_73[] PROGMEM = {0x05, 0x0A, 0xA0, 0x70, 0xD0, 0xB0, 0x00, 0x01, 0x01, 0x01, 0x00, 0x00, };
const char cp_1C_74[] PROGMEM = {0x04, 0x0A, 0x10, 0xF0, 0xFC, 0x10, 0x00, 0x01, 0x01, 0x01, };
const char cp_1C_75[] PROGMEM = {0x07, 0x0A, 0x10, 0xF0, 0xF0, 0x00, 0xF0, 0xF0, 0x00, 0x00, 0x00, 0x01, 0x01, 0x01, 0x01, 0x01, };
const char cp_1C_76[] PROGMEM = {0x05, 0x0A, 0x70, 0xF0, 0x80, 0x70, 0x10, 0x00, 0x01, 0x01, 0x00, 0x00, };
const char cp_1C_77[] PROGMEM = {0x08, 0x0A, 0x70, 0xF0, 0x80, 0x70, 0xF0, 0x80, 0x70, 0x10, 0x00, 0x01, 0x01, 0x00, 0x01, 0x01, 0x00, 0x00, };
const char cp_1C_78[] PROGMEM = {0x06, 0x0A, 0x10, 0x30, 0xF0, 0xE0, 0x90, 0x10, 0x01, 0x01, 0x00, 0x01, 0x01, 0x01, };
const char cp_1C_79[] PROGMEM = {0x06, 0x0A, 0x08, 0x38, 0xF8, 0x60, 0x18, 0x08, 0x03, 0x02, 0x01, 0x00, 0x00, 0x00, };
const char cp_1C_7A[] PROGMEM = {0x06, 0x0A, 0x10, 0xD0, 0xF0, 0x70, 0x10, 0x00, 0x01, 0x01, 0x01, 0x01, 0x01, 0x00, };
const char cp_1C_7B[] PROGMEM = {0x04, 0x0A, 0x20, 0xDC, 0x8E, 0x02, 0x00, 0x03, 0x03, 0x00, };
const char cp_1C_7C[] PROGMEM = {0x03, 0x0A, 0x00, 0xFE, 0x00, 0x00, 0x03, 0x00, };
const char cp_1C_7D[] PROGMEM = {0x04, 0x0A, 0x02, 0x8E, 0xDC, 0x20, 0x00, 0x03, 0x03, 0x00, };
const char cp_1C_7E[] PROGMEM = {0x06, 0x0A, 0x60, 0x20, 0x40, 0x40, 0x60, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, };
const char cp_1C_C4[] PROGMEM = {0x08, 0x0A, 0x00, 0xC0, 0x31, 0x2F, 0x3E, 0xF9, 0xC1, 0x00, 0x01, 0x01, 0x01, 0x00, 0x01, 0x01, 0x01, 0x01, };
const char cp_1C_D6[] PROGMEM = {0x0A, 0x0A, 0x00, 0x78, 0xFC, 0x87, 0x03, 0x02, 0x87, 0xFD, 0x78, 0x00, 0x00, 0x00, 0x00, 0x01, 0x01, 0x01, 0x01, 0x00, 0x00, 0x00, };
const char cp_1C_DC[] PROGMEM = {0x08, 0x0A, 0x02, 0xFE, 0xFF, 0x03, 0x00, 0x03, 0xFF, 0x02, 0x00, 0x00, 0x01, 0x01, 0x01, 0x01, 0x00, 0x00, };
const char cp_1C_E4[] PROGMEM = {0x06, 0x0A, 0xA6, 0xD6, 0x50, 0xF6, 0xE6, 0x00, 0x00, 0x01, 0x01, 0x01, 0x01, 0x01, };
const char cp_1C_F6[] PROGMEM = {0x06, 0x0A, 0xE6, 0xF6, 0x10, 0xF6, 0xE6, 0x00, 0xFC, 0xFD, 0xFD, 0xFD, 0xFC, 0xFC, };
const char cp_1C_FC[] PROGMEM = {0x07, 0x0A, 0x10, 0xF6, 0xF6, 0x00, 0xF6, 0xF6, 0x00, 0xFC, 0xFC, 0xFD, 0xFD, 0xFD, 0xFD, 0xFD, };
const char cp_1C_DF[] PROGMEM = {0x06, 0x0A, 0xFC, 0xFE, 0x0A, 0xFE, 0xF4, 0x00, 0x01, 0x01, 0x01, 0x01, 0x00, 0x00, };

const char cp_1B_20[] PROGMEM = {0x02, 0x08, 0x00, 0x00, };
const char cp_1B_21[] PROGMEM = {0x03, 0x08, 0x00, 0x5F, 0x00, };
const char cp_1B_27[] PROGMEM = {0x02, 0x08, 0x03, 0x00, };
const char cp_1B_23[] PROGMEM = {0x05, 0x08, 0x7C, 0x17, 0x74, 0x1F, 0x00, };
const char cp_1B_24[] PROGMEM = {0x05, 0x08, 0x46, 0xF9, 0x4F, 0x31, 0x00, };
const char cp_1B_25[] PROGMEM = {0x08, 0x08, 0x00, 0x42, 0x25, 0x1A, 0x24, 0x52, 0x21, 0x00, };
const char cp_1B_26[] PROGMEM = {0x06, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, };
const char cp_1B_28[] PROGMEM = {0x03, 0x08, 0x00, 0xFE, 0x01, };
const char cp_1B_29[] PROGMEM = {0x03, 0x08, 0x01, 0xFE, 0x00, };
const char cp_1B_2A[] PROGMEM = {0x04, 0x08, 0x05, 0x02, 0x05, 0x00, };
const char cp_1B_2B[] PROGMEM = {0x05, 0x08, 0x08, 0x08, 0x3E, 0x08, 0x08, };
const char cp_1B_2C[] PROGMEM = {0x03, 0x08, 0x80, 0x40, 0x00, };
const char cp_1B_2D[] PROGMEM = {0x03, 0x08, 0x10, 0x10, 0x10, };
const char cp_1B_2E[] PROGMEM = {0x03, 0x08, 0x00, 0x40, 0x00, };
const char cp_1B_2F[] PROGMEM = {0x03, 0x08, 0x60, 0x1C, 0x03, };
const char cp_1B_30[] PROGMEM = {0x05, 0x08, 0x3E, 0x41, 0x41, 0x3E, 0x00, };
const char cp_1B_31[] PROGMEM = {0x05, 0x08, 0x00, 0x02, 0x7F, 0x00, 0x00, };
const char cp_1B_32[] PROGMEM = {0x05, 0x08, 0x62, 0x51, 0x49, 0x46, 0x00, };
const char cp_1B_33[] PROGMEM = {0x05, 0x08, 0x22, 0x41, 0x49, 0x36, 0x00, };
const char cp_1B_34[] PROGMEM = {0x05, 0x08, 0x18, 0x14, 0x12, 0x7F, 0x10, };
const char cp_1B_35[] PROGMEM = {0x05, 0x08, 0x27, 0x45, 0x45, 0x39, 0x00, };
const char cp_1B_36[] PROGMEM = {0x05, 0x08, 0x3E, 0x49, 0x49, 0x32, 0x00, };
const char cp_1B_37[] PROGMEM = {0x05, 0x08, 0x01, 0x61, 0x1D, 0x03, 0x00, };
const char cp_1B_38[] PROGMEM = {0x05, 0x08, 0x36, 0x49, 0x49, 0x36, 0x00, };
const char cp_1B_39[] PROGMEM = {0x05, 0x08, 0x26, 0x49, 0x49, 0x3E, 0x00, };
const char cp_1B_3A[] PROGMEM = {0x03, 0x08, 0x00, 0x44, 0x00, };
const char cp_1B_3B[] PROGMEM = {0x03, 0x08, 0x80, 0x44, 0x00, };
const char cp_1B_3C[] PROGMEM = {0x05, 0x08, 0x08, 0x14, 0x14, 0x22, 0x00, };
const char cp_1B_3D[] PROGMEM = {0x05, 0x08, 0x14, 0x14, 0x14, 0x14, 0x00, };
const char cp_1B_3E[] PROGMEM = {0x05, 0x08, 0x22, 0x14, 0x14, 0x08, 0x00, };
const char cp_1B_3F[] PROGMEM = {0x05, 0x08, 0x02, 0x01, 0x59, 0x06, 0x00, };
const char cp_1B_40[] PROGMEM = {0x09, 0x08, 0x3C, 0x42, 0x99, 0xA5, 0xA5, 0xBD, 0xA2, 0x1C, 0x00, };
const char cp_1B_41[] PROGMEM = {0x07, 0x08, 0x60, 0x18, 0x16, 0x11, 0x16, 0x18, 0x60, };
const char cp_1B_42[] PROGMEM = {0x06, 0x08, 0x00, 0x7F, 0x49, 0x49, 0x36, 0x00, };
const char cp_1B_43[] PROGMEM = {0x07, 0x08, 0x00, 0x3E, 0x41, 0x41, 0x41, 0x22, 0x00, };
const char cp_1B_44[] PROGMEM = {0x07, 0x08, 0x00, 0x7F, 0x41, 0x41, 0x22, 0x1C, 0x00, };
const char cp_1B_45[] PROGMEM = {0x06, 0x08, 0x00, 0x7F, 0x49, 0x49, 0x49, 0x00, };
const char cp_1B_46[] PROGMEM = {0x06, 0x08, 0x00, 0x7F, 0x09, 0x09, 0x09, 0x00, };
const char cp_1B_47[] PROGMEM = {0x07, 0x08, 0x00, 0x3E, 0x41, 0x41, 0x49, 0x7A, 0x00, };
const char cp_1B_48[] PROGMEM = {0x07, 0x08, 0x00, 0x7F, 0x08, 0x08, 0x08, 0x7F, 0x00, };
const char cp_1B_49[] PROGMEM = {0x03, 0x08, 0x00, 0x7F, 0x00, };
const char cp_1B_4A[] PROGMEM = {0x05, 0x08, 0x20, 0x40, 0x40, 0x3F, 0x00, };
const char cp_1B_4B[] PROGMEM = {0x06, 0x08, 0x00, 0x7F, 0x08, 0x14, 0x22, 0x41, };
const char cp_1B_4C[] PROGMEM = {0x05, 0x08, 0x00, 0x7F, 0x40, 0x40, 0x40, };
const char cp_1B_4D[] PROGMEM = {0x09, 0x08, 0x00, 0x7F, 0x04, 0x18, 0x20, 0x18, 0x04, 0x7F, 0x00, };
const char cp_1B_4E[] PROGMEM = {0x07, 0x08, 0x00, 0x7F, 0x06, 0x08, 0x30, 0x7F, 0x00, };
const char cp_1B_4F[] PROGMEM = {0x07, 0x08, 0x00, 0x3E, 0x41, 0x41, 0x41, 0x3E, 0x00, };
const char cp_1B_50[] PROGMEM = {0x06, 0x08, 0x00, 0x7F, 0x09, 0x09, 0x09, 0x06, };
const char cp_1B_51[] PROGMEM = {0x07, 0x08, 0x00, 0x3E, 0x41, 0x41, 0x61, 0xBE, 0x00, };
const char cp_1B_52[] PROGMEM = {0x07, 0x08, 0x00, 0x7F, 0x09, 0x09, 0x19, 0x66, 0x00, };
const char cp_1B_53[] PROGMEM = {0x06, 0x08, 0x00, 0x26, 0x49, 0x49, 0x32, 0x00, };
const char cp_1B_54[] PROGMEM = {0x05, 0x08, 0x01, 0x01, 0x7F, 0x01, 0x01, };
const char cp_1B_55[] PROGMEM = {0x07, 0x08, 0x00, 0x3F, 0x40, 0x40, 0x40, 0x3F, 0x00, };
const char cp_1B_56[] PROGMEM = {0x07, 0x08, 0x03, 0x0C, 0x30, 0x40, 0x30, 0x0C, 0x03, };
const char cp_1B_57[] PROGMEM = {0x09, 0x08, 0x03, 0x0C, 0x70, 0x0C, 0x03, 0x0C, 0x70, 0x0C, 0x03, };
const char cp_1B_58[] PROGMEM = {0x06, 0x08, 0x41, 0x22, 0x1C, 0x1C, 0x22, 0x41, };
const char cp_1B_59[] PROGMEM = {0x05, 0x08, 0x03, 0x04, 0x78, 0x04, 0x03, };
const char cp_1B_5A[] PROGMEM = {0x06, 0x08, 0x00, 0x61, 0x59, 0x45, 0x43, 0x00, };
const char cp_1B_5B[] PROGMEM = {0x03, 0x08, 0x00, 0xFF, 0x01, };
const char cp_1B_5C[] PROGMEM = {0x03, 0x08, 0x03, 0x1C, 0x60, };
const char cp_1B_5D[] PROGMEM = {0x03, 0x08, 0x01, 0xFF, 0x00, };
const char cp_1B_5E[] PROGMEM = {0x05, 0x08, 0x04, 0x02, 0x01, 0x02, 0x04, };
const char cp_1B_5F[] PROGMEM = {0x05, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, };
const char cp_1B_60[] PROGMEM = {0x03, 0x08, 0x00, 0x01, 0x00, };
const char cp_1B_61[] PROGMEM = {0x05, 0x08, 0x24, 0x54, 0x54, 0x78, 0x00, };
const char cp_1B_62[] PROGMEM = {0x05, 0x08, 0x7F, 0x44, 0x44, 0x38, 0x00, };
const char cp_1B_63[] PROGMEM = {0x05, 0x08, 0x38, 0x44, 0x44, 0x28, 0x00, };
const char cp_1B_64[] PROGMEM = {0x05, 0x08, 0x38, 0x44, 0x44, 0x7F, 0x00, };
const char cp_1B_65[] PROGMEM = {0x05, 0x08, 0x38, 0x54, 0x54, 0x58, 0x00, };
const char cp_1B_66[] PROGMEM = {0x03, 0x08, 0x7E, 0x05, 0x00, };
const char cp_1B_67[] PROGMEM = {0x05, 0x08, 0x9C, 0xA2, 0xA2, 0x7E, 0x00, };
const char cp_1B_68[] PROGMEM = {0x05, 0x08, 0x7F, 0x04, 0x04, 0x78, 0x00, };
const char cp_1B_69[] PROGMEM = {0x02, 0x08, 0x7D, 0x00, };
const char cp_1B_6A[] PROGMEM = {0x02, 0x08, 0xFD, 0x00, };
const char cp_1B_6B[] PROGMEM = {0x05, 0x08, 0x7F, 0x10, 0x28, 0x44, 0x00, };
const char cp_1B_6C[] PROGMEM = {0x02, 0x08, 0x7F, 0x00, };
const char cp_1B_6D[] PROGMEM = {0x08, 0x08, 0x7C, 0x04, 0x04, 0x7C, 0x04, 0x04, 0x78, 0x00, };
const char cp_1B_6E[] PROGMEM = {0x05, 0x08, 0x7C, 0x04, 0x04, 0x78, 0x00, };
const char cp_1B_6F[] PROGMEM = {0x05, 0x08, 0x38, 0x44, 0x44, 0x38, 0x00, };
const char cp_1B_70[] PROGMEM = {0x05, 0x08, 0xFE, 0x22, 0x22, 0x1C, 0x00, };
const char cp_1B_71[] PROGMEM = {0x05, 0x08, 0x1C, 0x22, 0x22, 0xFE, 0x00, };
const char cp_1B_72[] PROGMEM = {0x03, 0x08, 0x7C, 0x04, 0x00, };
const char cp_1B_73[] PROGMEM = {0x05, 0x08, 0x48, 0x54, 0x54, 0x24, 0x00, };
const char cp_1B_74[] PROGMEM = {0x03, 0x08, 0x7E, 0x44, 0x00, };
const char cp_1B_75[] PROGMEM = {0x05, 0x08, 0x3C, 0x40, 0x40, 0x7C, 0x00, };
const char cp_1B_76[] PROGMEM = {0x06, 0x08, 0x0C, 0x30, 0x40, 0x30, 0x0C, 0x00, };
const char cp_1B_77[] PROGMEM = {0x08, 0x08, 0x1C, 0x60, 0x10, 0x0C, 0x10, 0x60, 0x1C, 0x00, };
const char cp_1B_78[] PROGMEM = {0x05, 0x08, 0x6C, 0x10, 0x10, 0x6C, 0x00, };
const char cp_1B_79[] PROGMEM = {0x05, 0x08, 0x8E, 0x70, 0x10, 0x0E, 0x00, };
const char cp_1B_7A[] PROGMEM = {0x05, 0x08, 0x64, 0x54, 0x54, 0x4C, 0x00, };
const char cp_1B_7B[] PROGMEM = {0x03, 0x08, 0x10, 0xEE, 0x01, };
const char cp_1B_7C[] PROGMEM = {0x02, 0x08, 0x00, 0xFF, };
const char cp_1B_7D[] PROGMEM = {0x03, 0x08, 0x01, 0xEE, 0x10, };
const char cp_1B_7E[] PROGMEM = {0x05, 0x08, 0x02, 0x01, 0x02, 0x01, 0x00, };
const char cp_1B_C4[] PROGMEM = {0x07, 0x08, 0x60, 0x18, 0x16, 0x11, 0x16, 0x18, 0x60, };
const char cp_1B_D6[] PROGMEM = {0x07, 0x08, 0x00, 0x3E, 0x41, 0x41, 0x41, 0x3E, 0x00, };
const char cp_1B_DC[] PROGMEM = {0x07, 0x08, 0x00, 0x3F, 0x40, 0x40, 0x40, 0x3F, 0x00, };
const char cp_1B_E4[] PROGMEM = {0x05, 0x08, 0x24, 0x55, 0x54, 0x79, 0x00, };
const char cp_1B_F6[] PROGMEM = {0x05, 0x08, 0x39, 0x44, 0x44, 0x39, 0x00, };
const char cp_1B_FC[] PROGMEM = {0x05, 0x08, 0x3D, 0x40, 0x40, 0x7D, 0x00, };
const char cp_1B_DF[] PROGMEM = {0x06, 0x08, 0x7E, 0x01, 0x4D, 0x52, 0x20, 0x00, };

const char cp_14_00[] PROGMEM = {0x07, 0x07, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, };
const char cp_14_01[] PROGMEM = {0x0D, 0x08, 0x20, 0x7D, 0xFD, 0x7F, 0x3C, 0x7E, 0xFC, 0x7E, 0x3C, 0x7F, 0xFF, 0x7C, 0x20, };
const char cp_14_02[] PROGMEM = {0x0D, 0x08, 0x20, 0x7C, 0xFF, 0x7F, 0x3C, 0x7E, 0xFC, 0x7E, 0x3C, 0x7F, 0xFD, 0x7D, 0x20, };
const char cp_14_03[] PROGMEM = {0x0D, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFB, 0xFB, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, };
const char cp_14_04[] PROGMEM = {0x0D, 0x08, 0x00, 0x00, 0x7F, 0x00, 0x2A, 0x2A, 0x2A, 0x2A, 0x2A, 0x00, 0x7F, 0x00, 0x00, };
const char cp_14_05[] PROGMEM = {0x0B, 0x08, 0x00, 0x7E, 0xFF, 0xE7, 0xE7, 0xE7, 0xE7, 0xFF, 0x7E, 0x00, 0x00, };
const char cp_14_06[] PROGMEM = {0x16, 0x08, 0x7E, 0x42, 0x42, 0x7E, 0x42, 0x42, 0x42, 0x42, 0x42, 0x7E, 0x42, 0x42, 0x7E, 0x00, 0xC0, 0xF0, 0x3C, 0x27, 0x27, 0x3C, 0xF0, 0xC0};
const char cp_14_07[] PROGMEM = {0x0F, 0x08, 0x92, 0x54, 0x28, 0xC6, 0x28, 0x54, 0x92, 0x00, 0x00, 0x12, 0xF5, 0xF2, 0xF5, 0x12, 0x01, };
const char cp_14_08[] PROGMEM = {0x0D, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFB, 0xFB, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, };
const char cp_14_09[] PROGMEM = {0x0A, 0x08, 0xFF, 0x81, 0x81, 0x8F, 0x8A, 0x8C, 0xF8, 0x00, 0xDF, 0xDF, };
const char cp_14_0A[] PROGMEM = {0x0B, 0x08, 0x00, 0x7E, 0xF7, 0xF3, 0x81, 0x81, 0xF3, 0xF7, 0x7E, 0x00, 0x00, };
const char cp_14_0B[] PROGMEM = {0x08, 0x08, 0xFE, 0x82, 0xAA, 0x82, 0xAA, 0xAA, 0x82, 0xFE, };
const char cp_14_0C[] PROGMEM = {0x0B, 0x08, 0x0E, 0xFF, 0xFF, 0x0E, 0x0E, 0x0E, 0x0E, 0x1B, 0x11, 0x1B, 0x0E, };
const char cp_14_0D[] PROGMEM = {0x0B, 0x08, 0x30, 0x30, 0x30, 0x30, 0x30, 0x38, 0x3C, 0x3E, 0x37, 0x32, 0x00, };
const char cp_14_0E[] PROGMEM = {0x6D, 0x0E, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x20, 0x20, 0x20, 0xFC, 0xFC, 0x20, 0x20, 0x20, 0x00, 0x00, 0x0C, 0x1E, 0x33, 0x21, 0x21, 0x21, 0x63, 0xC6, 0x84, 0x00, 0xFC, 0xFC, 0xF0, 0xC0, 0xC0, 0xF0, 0xFC, 0xFC, 0x00, 0x00, 0xC0, 0xF0, 0x3C, 0x3C, 0xF0, 0xC0, 0x00, 0x00, 0xFC, 0xFC, 0x44, 0x44, 0x44, 0xFC, 0xB8, 0x00, 0x00, 0x04, 0x04, 0xFC, 0xFC, 0x04, 0x04, 0x00, 0xFF, 0xFF, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0xFF, 0xFF, 0x00, 0x00, 0xC0, 0xF0, 0x3C, 0x3C, 0xF0, 0xC0, 0x00, 0x00, 0xFC, 0xFC, 0x78, 0xE0, 0x80, 0xFC, 0xFC, 0x00, 0x00, 0xFC, 0xFC, 0x04, 0x04, 0x0C, 0xF8, 0xF0, 0x00, 0x01, 0x0F, 0x01, 0x0F, 0x02, 0x02, 0x0F, 0x00, 0x00, 0x00, 0x00, 0x00, 0xE0, 0xE0, 0xE0, 0xE0, 0xE0, 0xE0, 0xE0, 0xE0, 0xE0, 0xE1, 0xE1, 0xE0, 0xE0, 0xE0, 0xE0, 0xE0, 0xE1, 0xE3, 0xE6, 0xE4, 0xE4, 0xE4, 0xE6, 0xE3, 0xE1, 0xE0, 0xE7, 0xE7, 0xE0, 0xE3, 0xE3, 0xE0, 0xE7, 0xE7, 0xE0, 0xE6, 0xE7, 0xE1, 0xE1, 0xE1, 0xE1, 0xE7, 0xE6, 0xE0, 0xE7, 0xE7, 0xE0, 0xE0, 0xE0, 0xE7, 0xE7, 0xE0, 0xE0, 0xE0, 0xE0, 0xE7, 0xE7, 0xE0, 0xE0, 0xE0, 0xE7, 0xE7, 0xE0, 0xE0, 0xE0, 0xE0, 0xE0, 0xE0, 0xE7, 0xE7, 0xE0, 0xE6, 0xE7, 0xE1, 0xE1, 0xE1, 0xE1, 0xE7, 0xE6, 0xE0, 0xE7, 0xE7, 0xE0, 0xE0, 0xE3, 0xE7, 0xE7, 0xE0, 0xE0, 0xE7, 0xE7, 0xE4, 0xE4, 0xE6, 0xE3, 0xE1, 0xE0, 0xE0, 0xE0, 0xE0, 0xE0, 0xE0, 0xE0, 0xE0, 0xE0, 0xE0, 0xE0, 0xE0, 0xE0};
const char cp_14_32[] PROGMEM = {0x08, 0x0B, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xF8, 0xF8, 0xF8, 0xF8, 0xF8, 0xF8, 0xF8, 0xF8, };
const char cp_14_33[] PROGMEM = {0x08, 0x0B, 0x80, 0xCC, 0x9E, 0xA2, 0x03, 0xA2, 0x1E, 0x0C, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFE, };
const char cp_14_34[] PROGMEM = {0x08, 0x0B, 0xFE, 0xFF, 0x03, 0x03, 0x03, 0x57, 0xAE, 0x00, 0xFF, 0xFF, 0xF8, 0xF8, 0xFC, 0xFD, 0xFE, 0xFC, };
const char cp_14_35[] PROGMEM = {0x08, 0x0B, 0x50, 0x20, 0x40, 0x80, 0xF8, 0xF4, 0xF4, 0xF8, 0xF9, 0xF8, 0xF8, 0xF8, 0xF9, 0xF9, 0xF9, 0xF9, };
const char cp_14_36[] PROGMEM = {0x08, 0x0B, 0xFF, 0xF1, 0xF1, 0xF1, 0xFF, 0x02, 0x04, 0xF8, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFC, 0xFA, 0xF9, };
const char cp_14_37[] PROGMEM = {0x05, 0x0B, 0x00, 0x00, 0x00, 0x00, 0x00, 0xF8, 0xF8, 0xF8, 0xF8, 0xF8, };
const char cp_14_38[] PROGMEM = {0x05, 0x0B, 0x00, 0xFF, 0x01, 0x01, 0xFF, 0xF8, 0xFF, 0xFC, 0xFC, 0xFF, };
const char cp_14_39[] PROGMEM = {0x05, 0x0B, 0x00, 0xFF, 0x01, 0x01, 0xFF, 0xF8, 0xFF, 0xFE, 0xFE, 0xFF, };
const char cp_14_3A[] PROGMEM = {0x05, 0x0B, 0x00, 0xFF, 0x81, 0x81, 0xFF, 0xF8, 0xFF, 0xFF, 0xFF, 0xFF, };
const char cp_14_3B[] PROGMEM = {0x05, 0x0B, 0x00, 0xFF, 0xE1, 0xE1, 0xFF, 0xF8, 0xFF, 0xFF, 0xFF, 0xFF, };
const char cp_14_3C[] PROGMEM = {0x05, 0x0B, 0x00, 0xFF, 0xF9, 0xF9, 0xFF, 0xF8, 0xFF, 0xFF, 0xFF, 0xFF, };
const char cp_14_3D[] PROGMEM = {0x05, 0x0B, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0xF8, 0xFF, 0xFF, 0xFF, 0xFF, };
const char cp_14_50[] PROGMEM = {0x10, 0x07, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, };
const char cp_14_51[] PROGMEM = {0x10, 0x07, 0x80, 0x94, 0x94, 0x94, 0x80, 0x88, 0x9C, 0xBE, 0xFF, 0x9C, 0x9C, 0x9C, 0x80, 0x80, 0x80, 0x80, };
const char cp_14_52[] PROGMEM = {0x10, 0x07, 0x80, 0x94, 0x94, 0x94, 0x80, 0x9C, 0x9C, 0x9C, 0xFF, 0xBE, 0x9C, 0x88, 0x80, 0x80, 0x80, 0x80, };
const char cp_14_53[] PROGMEM = {0x10, 0x07, 0x80, 0x94, 0x94, 0x94, 0x80, 0x88, 0x98, 0xBF, 0xFF, 0xBF, 0x98, 0x88, 0x80, 0x80, 0x80, 0x80, };
const char cp_14_54[] PROGMEM = {0x10, 0x07, 0x80, 0x94, 0x94, 0x94, 0x80, 0x88, 0x8C, 0xFE, 0xFF, 0xFE, 0x8C, 0x88, 0x80, 0x80, 0x80, 0x80, };
const char cp_14_5A[] PROGMEM = {0x07, 0x07, 0x80, 0x80, 0xFE, 0x84, 0x84, 0x8E, 0x84, };
const char cp_14_5B[] PROGMEM = {0x07, 0x07, 0x80, 0x80, 0xFE, 0x84, 0x83, 0x83, 0x80, };
const char cp_14_5C[] PROGMEM = {0x07, 0x07, 0x80, 0x80, 0xFE, 0xA4, 0x9B, 0x9B, 0x80, };
const char cp_14_5D[] PROGMEM = {0x07, 0x07, 0x83, 0x8C, 0xF0, 0x8C, 0xF0, 0x8C, 0x83, };
const char cp_14_64[] PROGMEM = {0x07, 0x07, 0xBE, 0xC1, 0xC9, 0xC9, 0xC9, 0xC1, 0xBE, };
const char cp_14_65[] PROGMEM = {0x07, 0x07, 0xBE, 0xE3, 0xE3, 0xE3, 0xE3, 0xE3, 0xBE, };
const char cp_14_66[] PROGMEM = {0x07, 0x07, 0xBE, 0xC1, 0xC9, 0xDD, 0xFF, 0xC1, 0xBE, };
const char cp_14_67[] PROGMEM = {0x07, 0x07, 0xBE, 0xC1, 0xFF, 0xDD, 0xC9, 0xC1, 0xBE, };
const char cp_14_68[] PROGMEM = {0x07, 0x07, 0xBE, 0xC1, 0xC9, 0xC9, 0xC9, 0xC1, 0xBE, };
const char cp_14_69[] PROGMEM = {0x07, 0x07, 0xBE, 0xF7, 0xF3, 0xC1, 0xF3, 0xF7, 0xBE, };
const char cp_14_6E[] PROGMEM = {0x07, 0x07, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, };
const char cp_14_6F[] PROGMEM = {0x78, 0x0B, 0xFF, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0xFF, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0xFF, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0xFF, 0xFF, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFF, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFF, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFC, 0xFF};
const char cp_14_70[] PROGMEM = {0x07, 0x07, 0xBD, 0xFD, 0xBF, 0xFC, 0xBF, 0xFF, 0xBC, };
const char cp_14_71[] PROGMEM = {0x07, 0x07, 0xBC, 0xFF, 0xBF, 0xFC, 0xBF, 0xFD, 0xBD, };
const char cp_14_72[] PROGMEM = {0x07, 0x07, 0xF6, 0x96, 0xFF, 0xFF, 0xFF, 0xFF, 0xAA, };
const char cp_14_73[] PROGMEM = {0x07, 0x07, 0xB7, 0xB4, 0xFF, 0xFF, 0xFF, 0xFF, 0xAA, };
const char cp_14_74[] PROGMEM = {0x07, 0x07, 0x80, 0x88, 0x88, 0xBE, 0xBE, 0xBE, 0x80, };
const char cp_14_75[] PROGMEM = {0x07, 0x07, 0x80, 0xBE, 0xBE, 0xBE, 0x88, 0x88, 0x80, };
const char cp_14_76[] PROGMEM = {0x07, 0x07, 0x80, 0x8E, 0x8E, 0xBE, 0x8E, 0x8E, 0x80, };
const char cp_14_77[] PROGMEM = {0x07, 0x07, 0x80, 0xB8, 0xB8, 0xBF, 0xB8, 0xB8, 0x80, };
const char cp_14_78[] PROGMEM = {0x07, 0x07, 0x94, 0x94, 0x94, 0xF7, 0xA2, 0x94, 0x88, };
const char cp_14_79[] PROGMEM = {0x07, 0x07, 0x88, 0x94, 0xA2, 0xF7, 0x94, 0x94, 0x94, };
const char cp_14_7A[] PROGMEM = {0x07, 0x07, 0x88, 0x8C, 0xFA, 0x81, 0xFA, 0x8C, 0x88, };
const char cp_14_7B[] PROGMEM = {0x07, 0x07, 0x88, 0x98, 0xAF, 0xC0, 0xAF, 0x98, 0x88, };
const char cp_14_7C[] PROGMEM = {0x07, 0x07, 0x80, 0x80, 0xFF, 0xBE, 0x9C, 0x88, 0x80, };
const char cp_14_7D[] PROGMEM = {0x07, 0x07, 0x80, 0x88, 0x9C, 0xBE, 0xFF, 0x80, 0x80, };
const char cp_14_7E[] PROGMEM = {0x07, 0x07, 0xFF, 0xE3, 0xD5, 0xC9, 0xD5, 0xE3, 0xFF, };
const char cp_14_7F[] PROGMEM = {0x07, 0x07, 0xFF, 0xC1, 0xDD, 0xDD, 0xDD, 0xC1, 0xFF, };
const char cp_14_82[] PROGMEM = {0x07, 0x07, 0xFF, 0xC9, 0xD9, 0xFF, 0xD9, 0xC9, 0xFF, };
const char cp_14_83[] PROGMEM = {0x07, 0x07, 0xFF, 0xC9, 0xCD, 0xFF, 0xCD, 0xC9, 0xFF, };
const char cp_14_84[] PROGMEM = {0x07, 0x07, 0x9C, 0xB6, 0xF7, 0xF7, 0xF7, 0xB6, 0x9C, };
const char cp_14_87[] PROGMEM = {0x07, 0x07, 0xFF, 0xC1, 0xCF, 0xCA, 0xFC, 0x80, 0xEF, };
const char cp_14_8C[] PROGMEM = {0x08, 0x21, 0xFE, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x7F, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFC, 0xFE, 0xFE, 0xFE, 0xFE, 0xFE, 0xFE, 0xFE, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFE, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF};
const char cp_14_8D[] PROGMEM = {0x07, 0x21, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFE, 0xFE, 0xFE, 0xFE, 0xFE, 0xFE, 0xFE, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF};
const char cp_14_8E[] PROGMEM = {0x08, 0x21, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFE, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x7F, 0xFE, 0xFE, 0xFE, 0xFE, 0xFE, 0xFE, 0xFE, 0xFC, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFE};
const char cp_14_8F[] PROGMEM = {0x07, 0x21, 0xFE, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFE, 0x7F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x7F, 0xFC, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFC, 0xFF, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xFE, 0xFE, 0xFE, 0xFE, 0xFE, 0xFE, 0xFE};
const char cp_14_90[] PROGMEM = {0x07, 0x21, 0xFE, 0x00, 0xF0, 0xE0, 0xC0, 0x80, 0xFE, 0x7F, 0x00, 0x07, 0x03, 0x01, 0x00, 0x7F, 0xFC, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFC, 0xFF, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xFE, 0xFE, 0xFE, 0xFE, 0xFE, 0xFE, 0xFE};
const char cp_14_91[] PROGMEM = {0x07, 0x21, 0xFE, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFE, 0x7F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x7F, 0xFC, 0x00, 0xE0, 0xC0, 0x80, 0x00, 0xFC, 0xFF, 0x00, 0x0F, 0x07, 0x03, 0x01, 0xFF, 0xFE, 0xFE, 0xFE, 0xFE, 0xFE, 0xFE, 0xFE};
const char cp_14_92[] PROGMEM = {0x07, 0x21, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0xFC, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFC, 0xFF, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xFE, 0xFE, 0xFE, 0xFE, 0xFE, 0xFE, 0xFE};
const char cp_14_93[] PROGMEM = {0x07, 0x21, 0xFE, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFE, 0x7F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x7F, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF};
const char cp_14_94[] PROGMEM = {0x07, 0x21, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF};
const char cp_14_95[] PROGMEM = {0x07, 0x21, 0xFE, 0x00, 0xF0, 0xE0, 0xC0, 0x80, 0xFE, 0x7F, 0x00, 0x07, 0x03, 0x01, 0x00, 0x7F, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF};
const char cp_14_96[] PROGMEM = {0x07, 0x21, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0xFC, 0x00, 0xE0, 0xC0, 0x80, 0x00, 0xFC, 0xFF, 0x00, 0x0F, 0x07, 0x03, 0x01, 0xFF, 0xFE, 0xFE, 0xFE, 0xFE, 0xFE, 0xFE, 0xFE};
const char cp_14_97[] PROGMEM = {0x07, 0x21, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFE, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x7F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFC, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xFE, 0xFE, 0xFE, 0xFE, 0xFE, 0xFE, 0xFE};
const char cp_14_98[] PROGMEM = {0x07, 0x21, 0x00, 0x00, 0xF0, 0xE0, 0xC0, 0x80, 0xFE, 0x00, 0x00, 0x07, 0x03, 0x01, 0x00, 0x7F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFC, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xFE, 0xFE, 0xFE, 0xFE, 0xFE, 0xFE, 0xFE};
const char cp_14_99[] PROGMEM = {0x07, 0x21, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFE, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x7F, 0x00, 0x00, 0xE0, 0xC0, 0x80, 0x00, 0xFC, 0x00, 0x00, 0x0F, 0x07, 0x03, 0x01, 0xFF, 0xFE, 0xFE, 0xFE, 0xFE, 0xFE, 0xFE, 0xFE};

const char cp_13_00[] PROGMEM = {0x07, 0x07, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, };
const char cp_13_01[] PROGMEM = {0x07, 0x07, 0xC0, 0xA0, 0x94, 0x88, 0x90, 0x80, 0x80, };
const char cp_13_81[] PROGMEM = {0x07, 0x07, 0xC0, 0xA0, 0x90, 0x88, 0x84, 0x82, 0x81, };
const char cp_13_91[] PROGMEM = {0x07, 0x07, 0xC0, 0xA0, 0x90, 0x88, 0x8C, 0x8A, 0x89, };
const char cp_13_C1[] PROGMEM = {0x07, 0x07, 0xC0, 0xA0, 0x90, 0x8F, 0x84, 0x82, 0x81, };
const char cp_13_83[] PROGMEM = {0x07, 0x07, 0xC0, 0xA0, 0x90, 0xF8, 0x84, 0x82, 0x81, };
const char cp_13_89[] PROGMEM = {0x07, 0x07, 0xC8, 0xA8, 0x98, 0x88, 0x84, 0x82, 0x81, };
const char cp_13_D1[] PROGMEM = {0x07, 0x07, 0xC0, 0xA0, 0x90, 0x8F, 0x8C, 0x8A, 0x89, };
const char cp_13_51[] PROGMEM = {0x07, 0x07, 0xC0, 0xA0, 0x90, 0x8F, 0x88, 0x88, 0x88, };
const char cp_13_31[] PROGMEM = {0x07, 0x07, 0xC1, 0xA2, 0x94, 0x88, 0x88, 0x88, 0x88, };
const char cp_13_45[] PROGMEM = {0x07, 0x07, 0xC0, 0xA0, 0x90, 0x8F, 0x90, 0xA0, 0xC0, };
const char cp_13_43[] PROGMEM = {0x07, 0x07, 0xC0, 0xA0, 0x90, 0xFF, 0x80, 0x80, 0x80, };
const char cp_13_19[] PROGMEM = {0x07, 0x07, 0xC8, 0xA8, 0x98, 0x88, 0x88, 0x88, 0x88, };
const char cp_13_8B[] PROGMEM = {0x07, 0x07, 0xC8, 0xA8, 0x98, 0xF8, 0x84, 0x82, 0x81, };
const char cp_13_47[] PROGMEM = {0x07, 0x07, 0xC0, 0xA0, 0x90, 0xFF, 0x90, 0xA0, 0xC0, };
const char cp_13_39[] PROGMEM = {0x07, 0x07, 0xC9, 0xAA, 0x9C, 0x88, 0x88, 0x88, 0x88, };
const char cp_13_99[] PROGMEM = {0x07, 0x07, 0xC8, 0xA8, 0x98, 0x88, 0x8C, 0x8A, 0x89, };
const char cp_13_C3[] PROGMEM = {0x07, 0x07, 0xC0, 0xA0, 0x90, 0xFF, 0x84, 0x82, 0x81, };
const char cp_13_A5[] PROGMEM = {0x07, 0x07, 0xC1, 0xA2, 0x94, 0x88, 0x94, 0xA2, 0xC1, };
const char cp_13_11[] PROGMEM = {0x07, 0x07, 0xC0, 0xA0, 0x90, 0x88, 0x88, 0x88, 0x88, };
const char cp_13_41[] PROGMEM = {0x07, 0x07, 0xC0, 0xA0, 0x90, 0x8F, 0x80, 0x80, 0x80, };
const char cp_13_02[] PROGMEM = {0x07, 0x07, 0x80, 0x80, 0xC0, 0xC0, 0xC0, 0x80, 0x80, };
const char cp_13_42[] PROGMEM = {0x07, 0x07, 0x80, 0x80, 0x80, 0xFF, 0x80, 0x80, 0x80, };
const char cp_13_8A[] PROGMEM = {0x07, 0x07, 0x88, 0x88, 0x88, 0xF8, 0x84, 0x82, 0x81, };
const char cp_13_32[] PROGMEM = {0x07, 0x07, 0x81, 0x82, 0x84, 0xF8, 0x88, 0x88, 0x88, };
const char cp_13_62[] PROGMEM = {0x07, 0x07, 0x81, 0x82, 0x84, 0xFF, 0x80, 0x80, 0x80, };
const char cp_13_A2[] PROGMEM = {0x07, 0x07, 0x81, 0x82, 0x84, 0xF8, 0x84, 0x82, 0x81, };
const char cp_13_C2[] PROGMEM = {0x07, 0x07, 0x80, 0x80, 0x80, 0xFF, 0x84, 0x82, 0x81, };
const char cp_13_46[] PROGMEM = {0x07, 0x07, 0x80, 0x80, 0x80, 0xFF, 0x90, 0xA0, 0xC0, };
const char cp_13_26[] PROGMEM = {0x07, 0x07, 0x81, 0x82, 0x84, 0xF8, 0x90, 0xA0, 0xC0, };
const char cp_13_E2[] PROGMEM = {0x07, 0x07, 0x81, 0x82, 0x84, 0xFF, 0x84, 0x82, 0x81, };
const char cp_13_36[] PROGMEM = {0x07, 0x07, 0x81, 0x82, 0x84, 0xF8, 0x98, 0xA8, 0xC8, };
const char cp_13_66[] PROGMEM = {0x07, 0x07, 0x81, 0x82, 0x84, 0xFF, 0x90, 0xA0, 0xC0, };
const char cp_13_5A[] PROGMEM = {0x07, 0x07, 0x88, 0x88, 0x88, 0xFF, 0x88, 0x88, 0x88, };
const char cp_13_82[] PROGMEM = {0x07, 0x07, 0x80, 0x80, 0x80, 0xF8, 0x84, 0x82, 0x81, };
const char cp_13_22[] PROGMEM = {0x07, 0x07, 0x81, 0x82, 0x84, 0xF8, 0x80, 0x80, 0x80, };
const char cp_13_24[] PROGMEM = {0x07, 0x07, 0x81, 0x82, 0x84, 0x88, 0x90, 0xA0, 0xC0, };
const char cp_13_64[] PROGMEM = {0x07, 0x07, 0x81, 0x82, 0x84, 0x8F, 0x90, 0xA0, 0xC0, };
const char cp_13_2C[] PROGMEM = {0x07, 0x07, 0x89, 0x8A, 0x8C, 0x88, 0x90, 0xA0, 0xC0, };
const char cp_13_34[] PROGMEM = {0x07, 0x07, 0x81, 0x82, 0x84, 0x88, 0x98, 0xA8, 0xC8, };
const char cp_13_1C[] PROGMEM = {0x07, 0x07, 0x88, 0x88, 0x88, 0x88, 0x98, 0xA8, 0xC8, };
const char cp_13_4C[] PROGMEM = {0x07, 0x07, 0x88, 0x88, 0x88, 0x8F, 0x90, 0xA0, 0xC0, };
const char cp_13_8C[] PROGMEM = {0x07, 0x07, 0x88, 0x88, 0x88, 0x88, 0x94, 0xA2, 0xC1, };
const char cp_13_6C[] PROGMEM = {0x07, 0x07, 0x89, 0x8A, 0x8C, 0x8F, 0x90, 0xA0, 0xC0, };
const char cp_13_9C[] PROGMEM = {0x07, 0x07, 0x88, 0x88, 0x88, 0x88, 0x9C, 0xAA, 0xC9, };
const char cp_13_3C[] PROGMEM = {0x07, 0x07, 0x89, 0x8A, 0x8C, 0x88, 0x98, 0xA8, 0xC8, };
const char cp_13_44[] PROGMEM = {0x07, 0x07, 0x80, 0x80, 0x80, 0x8F, 0x90, 0xA0, 0xC0, };
const char cp_13_0C[] PROGMEM = {0x07, 0x07, 0x88, 0x88, 0x88, 0x88, 0x90, 0xA0, 0xC0, };
const char cp_13_04[] PROGMEM = {0x07, 0x07, 0x80, 0x80, 0x90, 0x88, 0x94, 0xA0, 0xC0, };
const char cp_13_18[] PROGMEM = {0x07, 0x07, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, };
const char cp_13_38[] PROGMEM = {0x07, 0x07, 0x89, 0x8A, 0x8C, 0x88, 0x88, 0x88, 0x88, };
const char cp_13_98[] PROGMEM = {0x07, 0x07, 0x88, 0x88, 0x88, 0x88, 0x8C, 0x8A, 0x89, };
const char cp_13_88[] PROGMEM = {0x07, 0x07, 0x88, 0x88, 0x88, 0x88, 0x84, 0x82, 0x81, };
const char cp_13_08[] PROGMEM = {0x07, 0x07, 0x9C, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, };
const char cp_13_30[] PROGMEM = {0x07, 0x07, 0x81, 0x82, 0x84, 0x88, 0x88, 0x88, 0x88, };
const char cp_13_10[] PROGMEM = {0x07, 0x07, 0x80, 0x80, 0x80, 0x80, 0x80, 0x80, 0x9C, };
const char cp_13_20[] PROGMEM = {0x07, 0x07, 0x81, 0x82, 0x94, 0x88, 0x84, 0x80, 0x80, };
const char cp_13_40[] PROGMEM = {0x07, 0x07, 0x80, 0x80, 0x81, 0x81, 0x81, 0x80, 0x80, };
const char cp_13_80[] PROGMEM = {0x07, 0x07, 0x80, 0x80, 0x84, 0x88, 0x94, 0x82, 0x81, };
const char cp_13_05[] PROGMEM = {0x07, 0x07, 0xC0, 0xA0, 0x90, 0x88, 0x90, 0xA0, 0xC0, };
const char cp_13_12[] PROGMEM = {0x07, 0x07, 0x80, 0x80, 0x80, 0xF8, 0x88, 0x88, 0x88, };
const char cp_13_84[] PROGMEM = {0x07, 0x07, 0x80, 0x80, 0x80, 0x88, 0x94, 0xA2, 0xC1, };
const char cp_13_48[] PROGMEM = {0x07, 0x07, 0x88, 0x88, 0x88, 0x8F, 0x80, 0x80, 0x80, };
const char cp_13_0A[] PROGMEM = {0x07, 0x07, 0x88, 0x88, 0x88, 0xF8, 0x80, 0x80, 0x80, };
const char cp_13_21[] PROGMEM = {0x07, 0x07, 0xC1, 0xA2, 0x94, 0x88, 0x80, 0x80, 0x80, };
const char cp_13_50[] PROGMEM = {0x07, 0x07, 0x80, 0x80, 0x80, 0x8F, 0x88, 0x88, 0x88, };
const char cp_13_A0[] PROGMEM = {0x07, 0x07, 0x81, 0x82, 0x84, 0x88, 0x84, 0x82, 0x81, };
const char cp_13_EF[] PROGMEM = {0x07, 0x07, 0xC0, 0xB0, 0x8C, 0xE3, 0x98, 0x86, 0x81, };
const char cp_13_DF[] PROGMEM = {0x07, 0x07, 0xC8, 0xA8, 0xA4, 0x94, 0x92, 0x8A, 0x89, };
const char cp_13_BF[] PROGMEM = {0x07, 0x07, 0x81, 0x86, 0x98, 0xE3, 0x8C, 0xB0, 0xC0, };
const char cp_13_7F[] PROGMEM = {0x07, 0x07, 0x89, 0x8A, 0x92, 0x94, 0xA4, 0xA8, 0xC8, };
const char cp_13_F8[] PROGMEM = {0x07, 0x07, 0xC1, 0x80, 0x80, 0x80, 0x80, 0x80, 0xC1, };
const char cp_13_F4[] PROGMEM = {0x10, 0x07, 0x80, 0x94, 0x94, 0x94, 0x80, 0x88, 0x9C, 0xBE, 0xFF, 0x9C, 0x9C, 0x9C, 0x80, 0x80, 0x80, 0x80, };
const char cp_13_EC[] PROGMEM = {0x10, 0x07, 0x80, 0x94, 0x94, 0x94, 0x80, 0x9C, 0x9C, 0x9C, 0xFF, 0xBE, 0x9C, 0x88, 0x80, 0x80, 0x80, 0x80, };
const char cp_13_DC[] PROGMEM = {0x10, 0x07, 0x80, 0x94, 0x94, 0x94, 0x80, 0x88, 0x98, 0xBF, 0xFF, 0xBF, 0x98, 0x88, 0x80, 0x80, 0x80, 0x80, };
const char cp_13_BC[] PROGMEM = {0x10, 0x07, 0x80, 0x94, 0x94, 0x94, 0x80, 0x88, 0x8C, 0xFE, 0xFF, 0xFE, 0x8C, 0x88, 0x80, 0x80, 0x80, 0x80, };
const char cp_13_7C[] PROGMEM = {0x07, 0x07, 0x88, 0x90, 0xA0, 0xC0, 0x80, 0x80, 0x80, };
const char cp_13_F2[] PROGMEM = {0x07, 0x07, 0x88, 0x84, 0x82, 0x81, 0x80, 0x80, 0x80, };
const char cp_13_EA[] PROGMEM = {0x07, 0x07, 0x80, 0x80, 0x80, 0x81, 0x82, 0x84, 0x88, };
const char cp_13_DA[] PROGMEM = {0x07, 0x07, 0x80, 0x80, 0x80, 0xC0, 0xA0, 0x90, 0x88, };
const char cp_13_BA[] PROGMEM = {0x07, 0x07, 0x90, 0xA0, 0xC0, 0x80, 0x80, 0x80, 0x80, };
const char cp_13_7A[] PROGMEM = {0x07, 0x07, 0x84, 0x82, 0x81, 0x80, 0x80, 0x80, 0x80, };
const char cp_13_E6[] PROGMEM = {0x07, 0x07, 0x80, 0x80, 0x80, 0x80, 0x81, 0x82, 0x84, };
const char cp_13_D6[] PROGMEM = {0x07, 0x07, 0x80, 0x80, 0x80, 0x80, 0xC0, 0xA0, 0x90, };
const char cp_13_B6[] PROGMEM = {0x07, 0x07, 0x88, 0x88, 0x88, 0xC8, 0xA8, 0x98, 0x88, };
const char cp_13_76[] PROGMEM = {0x07, 0x07, 0x88, 0x98, 0xA8, 0xC8, 0x88, 0x88, 0x88, };
const char cp_13_CE[] PROGMEM = {0x07, 0x07, 0x88, 0x90, 0xA0, 0xC0, 0xA0, 0x90, 0x88, };
const char cp_13_AE[] PROGMEM = {0x07, 0x07, 0x88, 0x90, 0xA0, 0xFF, 0x80, 0x80, 0x80, };
const char cp_13_6E[] PROGMEM = {0x07, 0x07, 0x88, 0x84, 0x82, 0xFF, 0x80, 0x80, 0x80, };
const char cp_13_9E[] PROGMEM = {0x07, 0x07, 0x88, 0x94, 0xA2, 0xC1, 0x80, 0x80, 0x80, };
const char cp_13_5E[] PROGMEM = {0x07, 0x07, 0x80, 0x80, 0x80, 0xFF, 0x82, 0x84, 0x88, };
const char cp_13_3E[] PROGMEM = {0x07, 0x07, 0x80, 0x80, 0x80, 0xFF, 0xA0, 0x90, 0x88, };
const char cp_13_F1[] PROGMEM = {0x07, 0x07, 0x80, 0x80, 0x80, 0xC1, 0xA2, 0x94, 0x88, };
const char cp_13_E9[] PROGMEM = {0x07, 0x07, 0x88, 0x8C, 0x8A, 0x89, 0x88, 0x88, 0x88, };
const char cp_13_D9[] PROGMEM = {0x07, 0x07, 0x88, 0x88, 0x88, 0x89, 0x8A, 0x8C, 0x88, };
const char cp_13_B9[] PROGMEM = {0x07, 0x07, 0x88, 0x84, 0x82, 0x81, 0x82, 0x84, 0x88, };
const char cp_13_79[] PROGMEM = {0x07, 0x07, 0x88, 0x90, 0xA0, 0xFF, 0xA0, 0x90, 0x88, };
const char cp_13_E5[] PROGMEM = {0x07, 0x07, 0x88, 0x9C, 0xAA, 0xC9, 0x88, 0x88, 0x88, };
const char cp_13_D5[] PROGMEM = {0x07, 0x07, 0x88, 0x88, 0x88, 0xC9, 0xAA, 0x9C, 0x88, };
const char cp_13_B5[] PROGMEM = {0x07, 0x07, 0x88, 0x84, 0x82, 0xFF, 0x82, 0x84, 0x88, };
const char cp_13_75[] PROGMEM = {0x07, 0x07, 0x88, 0x88, 0x88, 0x88, 0xC8, 0xA8, 0x98, };
const char cp_13_CD[] PROGMEM = {0x07, 0x07, 0x98, 0xA8, 0xC8, 0x88, 0x88, 0x88, 0x88, };
const char cp_13_AD[] PROGMEM = {0x07, 0x07, 0x90, 0xA0, 0xC0, 0x80, 0xC0, 0xA0, 0x90, };
const char cp_13_6D[] PROGMEM = {0x07, 0x07, 0x90, 0xA0, 0xC0, 0xFF, 0x80, 0x80, 0x80, };
const char cp_13_9D[] PROGMEM = {0x07, 0x07, 0x84, 0x82, 0x81, 0xFF, 0x80, 0x80, 0x80, };
const char cp_13_5D[] PROGMEM = {0x07, 0x07, 0x94, 0xA2, 0xC1, 0x80, 0x80, 0x80, 0x80, };
const char cp_13_3D[] PROGMEM = {0x07, 0x07, 0x80, 0x80, 0x80, 0xFF, 0x81, 0x82, 0x84, };
const char cp_13_E3[] PROGMEM = {0x07, 0x07, 0x80, 0x80, 0x80, 0xFF, 0xC0, 0xA0, 0x90, };
const char cp_13_D3[] PROGMEM = {0x07, 0x07, 0x80, 0x80, 0x80, 0x80, 0xC1, 0xA2, 0x94, };
const char cp_13_B3[] PROGMEM = {0x07, 0x07, 0x8C, 0x8A, 0x89, 0x88, 0x88, 0x88, 0x88, };
const char cp_13_73[] PROGMEM = {0x07, 0x07, 0x88, 0x88, 0x88, 0x88, 0x89, 0x8A, 0x8C, };
const char cp_13_CB[] PROGMEM = {0x07, 0x07, 0x84, 0x82, 0x81, 0x80, 0x81, 0x82, 0x84, };
const char cp_13_AB[] PROGMEM = {0x07, 0x07, 0x90, 0xA0, 0xC0, 0xFF, 0xC0, 0xA0, 0x90, };
const char cp_13_6B[] PROGMEM = {0x07, 0x07, 0x9C, 0xAA, 0xC9, 0x88, 0x88, 0x88, 0x88, };
const char cp_13_9B[] PROGMEM = {0x07, 0x07, 0x88, 0x88, 0x88, 0x88, 0xC9, 0xAA, 0x9C, };
const char cp_13_5B[] PROGMEM = {0x07, 0x07, 0x84, 0x82, 0x81, 0xFF, 0x81, 0x82, 0x84, };
const char cp_13_3B[] PROGMEM = {0x07, 0x07, 0x88, 0x90, 0xA0, 0xC1, 0x82, 0x84, 0x88, };
const char cp_13_C7[] PROGMEM = {0x07, 0x07, 0x88, 0x84, 0x82, 0xC1, 0xA0, 0x90, 0x88, };
const char cp_13_A7[] PROGMEM = {0x07, 0x07, 0x90, 0xA0, 0xC0, 0x80, 0x81, 0x82, 0x84, };
const char cp_13_67[] PROGMEM = {0x07, 0x07, 0x84, 0x82, 0x81, 0x80, 0xC0, 0xA0, 0x90, };

const char cp_12_00[] PROGMEM = {0x0B, 0x0B, 0x00, 0x00, 0x00, 0xFE, 0x22, 0x22, 0x22, 0x02, 0x00, 0x00, 0x00, 0xF8, 0xF8, 0xF8, 0xFB, 0xF8, 0xF8, 0xF8, 0xF8, 0xF8, 0xF8, 0xF8};
const char cp_12_01[] PROGMEM = {0x0B, 0x0B, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xF8, 0xFA, 0xFA, 0xFA, 0xFA, 0xFA, 0xFA, 0xFA, 0xFA, 0xFA, 0xF8};
const char cp_12_02[] PROGMEM = {0x0B, 0x0B, 0x00, 0x00, 0x70, 0x50, 0x50, 0x88, 0x04, 0xFE, 0x00, 0x00, 0x00, 0xF8, 0xF8, 0xF8, 0xF8, 0xF8, 0xF8, 0xF9, 0xFB, 0xF8, 0xF8, 0xF8};
const char cp_12_03[] PROGMEM = {0x0B, 0x0B, 0x00, 0x00, 0x00, 0x00, 0xFC, 0x82, 0xFC, 0x00, 0x00, 0x00, 0x00, 0xF8, 0xF8, 0xF8, 0xF8, 0xF8, 0xFB, 0xF8, 0xF8, 0xF8, 0xF8, 0xF8};
const char cp_12_04[] PROGMEM = {0x0B, 0x0B, 0x00, 0x70, 0x20, 0x20, 0x20, 0x40, 0x88, 0x88, 0x88, 0x70, 0x00, 0xF8, 0xF8, 0xF8, 0xF8, 0xF8, 0xF8, 0xF8, 0xF8, 0xF8, 0xF8, 0xF8};
const char cp_12_05[] PROGMEM = {0x0B, 0x0B, 0x00, 0x00, 0xC0, 0xB0, 0x8C, 0x82, 0x8C, 0xB0, 0xC0, 0x00, 0x00, 0xF8, 0xF8, 0xF8, 0xF8, 0xF9, 0xFB, 0xF9, 0xF8, 0xF8, 0xF8, 0xF8};
const char cp_12_06[] PROGMEM = {0x0B, 0x0B, 0x00, 0x00, 0xFC, 0xF8, 0xF8, 0x70, 0x70, 0x70, 0x20, 0x20, 0x00, 0xF8, 0xF8, 0xF9, 0xF8, 0xF8, 0xF8, 0xF8, 0xF8, 0xF8, 0xF8, 0xF8};
const char cp_12_07[] PROGMEM = {0x0B, 0x0B, 0x00, 0x00, 0x00, 0x48, 0xD4, 0xC8, 0xD4, 0x48, 0x04, 0x00, 0x00, 0xF8, 0xF8, 0xF8, 0xF8, 0xFB, 0xFB, 0xFB, 0xF8, 0xF8, 0xF8, 0xF8};
const char cp_12_08[] PROGMEM = {0x0B, 0x0B, 0x00, 0x20, 0x24, 0xA8, 0x50, 0x8E, 0x50, 0xA8, 0x24, 0x20, 0x00, 0xF8, 0xF8, 0xF9, 0xF8, 0xF8, 0xFB, 0xF8, 0xF8, 0xF9, 0xF8, 0xF8};
const char cp_12_09[] PROGMEM = {0x0B, 0x0B, 0x00, 0x00, 0x80, 0xC0, 0xC0, 0xFE, 0x0A, 0x14, 0x14, 0x00, 0x00, 0xF8, 0xF8, 0xF9, 0xFB, 0xFB, 0xF9, 0xF8, 0xF8, 0xF8, 0xF8, 0xF8};
const char cp_12_0A[] PROGMEM = {0x0B, 0x0B, 0x00, 0x70, 0x70, 0x70, 0x20, 0x70, 0xA8, 0xA8, 0x88, 0x70, 0x00, 0xF8, 0xF8, 0xF8, 0xF8, 0xF8, 0xF8, 0xF8, 0xF8, 0xF8, 0xF8, 0xF8};
const char cp_12_0B[] PROGMEM = {0x0B, 0x0B, 0x00, 0x00, 0xFC, 0xFE, 0x0E, 0x9E, 0x8E, 0xFC, 0x24, 0x00, 0x00, 0xF8, 0xF8, 0xF9, 0xFB, 0xF8, 0xF8, 0xFA, 0xF9, 0xF8, 0xF8, 0xF8};
const char cp_12_80[] PROGMEM = {0x0B, 0x0B, 0xFE, 0xFF, 0xFF, 0x01, 0xDD, 0xDD, 0xDD, 0xFD, 0xFF, 0xFF, 0xFE, 0xFB, 0xFF, 0xFF, 0xFC, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFB};
const char cp_12_82[] PROGMEM = {0x0B, 0x0B, 0xFE, 0xFF, 0x8F, 0xAF, 0xAF, 0x77, 0xFB, 0x01, 0xFF, 0xFF, 0xFE, 0xFB, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFE, 0xFC, 0xFF, 0xFF, 0xFB};
const char cp_12_83[] PROGMEM = {0x0B, 0x0B, 0xFE, 0xFF, 0xFF, 0xFF, 0x03, 0x7D, 0x03, 0xFF, 0xFF, 0xFF, 0xFE, 0xFB, 0xFF, 0xFF, 0xFF, 0xFF, 0xFC, 0xFF, 0xFF, 0xFF, 0xFF, 0xFB};
const char cp_12_84[] PROGMEM = {0x0B, 0x0B, 0xFE, 0x8F, 0xDF, 0xDF, 0xDF, 0xBF, 0x77, 0x77, 0x77, 0x8F, 0xFE, 0xFB, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFB};
const char cp_12_85[] PROGMEM = {0x0B, 0x0B, 0xFE, 0xFF, 0x3F, 0x4F, 0x73, 0x7D, 0x73, 0x4F, 0x3F, 0xFF, 0xFE, 0xFB, 0xFF, 0xFF, 0xFF, 0xFE, 0xFC, 0xFE, 0xFF, 0xFF, 0xFF, 0xFB};
const char cp_12_86[] PROGMEM = {0x0B, 0x0B, 0xFE, 0xFF, 0x03, 0x07, 0x07, 0x8F, 0x8F, 0x8F, 0xDF, 0xDF, 0xFE, 0xFB, 0xFF, 0xFE, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFB};
const char cp_12_87[] PROGMEM = {0x0B, 0x0B, 0xFE, 0xFF, 0xFF, 0xB7, 0x2B, 0x37, 0x2B, 0xB7, 0xFB, 0xFF, 0xFE, 0xFB, 0xFF, 0xFF, 0xFF, 0xFC, 0xFC, 0xFC, 0xFF, 0xFF, 0xFF, 0xFB};
const char cp_12_88[] PROGMEM = {0x0B, 0x0B, 0xFE, 0xDF, 0xDB, 0x57, 0xAF, 0x71, 0xAF, 0x57, 0xDB, 0xDF, 0xFE, 0xFB, 0xFF, 0xFE, 0xFF, 0xFF, 0xFC, 0xFF, 0xFF, 0xFE, 0xFF, 0xFB};
const char cp_12_89[] PROGMEM = {0x0B, 0x0B, 0xFE, 0xFF, 0x7F, 0x3F, 0x3F, 0x01, 0xF5, 0xE1, 0xEB, 0xFF, 0xFE, 0xFB, 0xFF, 0xFE, 0xFC, 0xFC, 0xFE, 0xFF, 0xFF, 0xFF, 0xFF, 0xFB};
const char cp_12_8A[] PROGMEM = {0x0B, 0x0B, 0xFE, 0x8F, 0x8F, 0x8F, 0xDF, 0x8F, 0x57, 0x57, 0x77, 0x8F, 0xFE, 0xFB, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFB};
const char cp_12_8B[] PROGMEM = {0x0B, 0x0B, 0xFE, 0xFF, 0x03, 0x01, 0xF1, 0x61, 0x71, 0x03, 0xDB, 0xFF, 0xFE, 0xFB, 0xFF, 0xFE, 0xFC, 0xFF, 0xFF, 0xFD, 0xFE, 0xFF, 0xFF, 0xFB};

const char cp_1B_80[] PROGMEM = {0x05, 0x07, 0x88, 0x9C, 0xBE, 0xFF, 0x80, };
const char cp_1B_81[] PROGMEM = {0x05, 0x07, 0xFF, 0xBE, 0x9C, 0x88, 0x80, };
const char cp_1B_82[] PROGMEM = {0x08, 0x07, 0xA0, 0xB0, 0xB8, 0xBC, 0xB8, 0xB0, 0xA0, 0x80, };
const char cp_1B_83[] PROGMEM = {0x08, 0x07, 0x84, 0x8C, 0x9C, 0xBC, 0x9C, 0x8C, 0x84, 0x80, };
const char cp_1B_84[] PROGMEM = {0x09, 0x07, 0x88, 0x9C, 0xBE, 0xFF, 0x88, 0x88, 0x88, 0x8F, 0x80, };

PGM_P const cp_12_a[]  PROGMEM =
  {
    cp_12_00,
    cp_12_01,
    cp_12_02,
    cp_12_03,
    cp_12_04,
    cp_12_05,
    cp_12_06,
    cp_12_07,
    cp_12_08,
    cp_12_09,
    cp_12_0A,
    cp_12_0B,
  };

PGM_P const cp_12_b[]  PROGMEM =
  {
    cp_12_80,
    NULL,
    cp_12_82,
    cp_12_83,
    cp_12_84,
    cp_12_85,
    cp_12_86,
    cp_12_87,
    cp_12_88,
    cp_12_89,
    cp_12_8A,
    cp_12_8B,
  };

PGM_P const cp_13[]  PROGMEM =     // Gleisplan
  {
     cp_13_00, cp_13_01, cp_13_02, NULL,     cp_13_04, cp_13_05, NULL,     NULL,     cp_13_08, NULL,     cp_13_0A, NULL,     cp_13_0C, NULL,     NULL,     NULL,    
     cp_13_10, cp_13_11, cp_13_12, NULL,     NULL,     NULL,     NULL,     NULL,     cp_13_18, cp_13_19, NULL,     NULL,     cp_13_1C, NULL,     NULL,     NULL,    
     cp_13_20, cp_13_21, cp_13_22, NULL,     cp_13_24, NULL,     cp_13_26, NULL,     NULL,     NULL,     NULL,     NULL,     cp_13_2C, NULL,     NULL,     NULL,    
     cp_13_30, cp_13_31, cp_13_32, NULL,     cp_13_34, NULL,     cp_13_36, NULL,     cp_13_38, cp_13_39, NULL,     cp_13_3B, cp_13_3C, cp_13_3D, cp_13_3E, NULL,    
     cp_13_40, cp_13_41, cp_13_42, cp_13_43, cp_13_44, cp_13_45, cp_13_46, cp_13_47, cp_13_48, NULL,     NULL,     NULL,     cp_13_4C, NULL,     NULL,     NULL,    
     cp_13_50, cp_13_51, NULL,     NULL,     NULL,     NULL,     NULL,     NULL,     NULL,     NULL,     cp_13_5A, cp_13_5B, NULL,     cp_13_5D, cp_13_5E, NULL,    
     NULL,     NULL,     cp_13_62, NULL,     cp_13_64, NULL,     cp_13_66, cp_13_67, NULL,     NULL,     NULL,     cp_13_6B, cp_13_6C, cp_13_6D, cp_13_6E, NULL,    
     NULL,     NULL,     NULL,     cp_13_73, NULL,     cp_13_75, cp_13_76, NULL,     NULL,     cp_13_79, cp_13_7A, NULL,     cp_13_7C, NULL,     NULL,     cp_13_7F,
     cp_13_80, cp_13_81, cp_13_82, cp_13_83, cp_13_84, NULL,     NULL,     NULL,     cp_13_88, cp_13_89, cp_13_8A, cp_13_8B, cp_13_8C, NULL,     NULL,     NULL,    
     NULL,     cp_13_91, NULL,     NULL,     NULL,     NULL,     NULL,     NULL,     cp_13_98, cp_13_99, NULL,     cp_13_9B, cp_13_9C, cp_13_9D, cp_13_9E, NULL,    
     cp_13_A0, NULL,     cp_13_A2, NULL,     NULL,     cp_13_A5, NULL,     cp_13_A7, NULL,     NULL,     NULL,     cp_13_AB, NULL,     cp_13_AD, cp_13_AE, NULL,    
     NULL,     NULL,     NULL,     cp_13_B3, NULL,     cp_13_B5, cp_13_B6, NULL,     NULL,     cp_13_B9, cp_13_BA, NULL,     cp_13_BC, NULL,     NULL,     cp_13_BF,
     NULL,     cp_13_C1, cp_13_C2, cp_13_C3, NULL,     NULL,     NULL,     cp_13_C7, NULL,     NULL,     NULL,     cp_13_CB, NULL,     cp_13_CD, cp_13_CE, NULL,    
     NULL,     cp_13_D1, NULL,     cp_13_D3, NULL,     cp_13_D5, cp_13_D6, NULL,     NULL,     cp_13_D9, cp_13_DA, NULL,     cp_13_DC, NULL,     NULL,     cp_13_DF,
     NULL,     NULL,     cp_13_E2, cp_13_E3, NULL,     cp_13_E5, cp_13_E6, NULL,     NULL,     cp_13_E9, cp_13_EA, NULL,     cp_13_EC, NULL,     NULL,     cp_13_EF,
     NULL,     cp_13_F1, cp_13_F2, NULL,     cp_13_F4, NULL,     NULL,     NULL,     cp_13_F8, NULL,     NULL,     NULL,     NULL,     NULL,     NULL,     NULL,    
  };

PGM_P const cp_14_a[]  PROGMEM =   // Funktionssymbole
  {
    cp_14_00,
    cp_14_01,
    cp_14_02,
    cp_14_03,
    cp_14_04,
    cp_14_05,
    cp_14_06,
    cp_14_07,
    cp_14_08,
    cp_14_09,
    cp_14_0A,
    cp_14_0B,
    cp_14_0C,
    cp_14_0D,
    cp_14_0E,
  };
PGM_P const cp_14_b[]  PROGMEM =
  {
    cp_14_32,
    cp_14_33,
    cp_14_34,
    cp_14_35,
    cp_14_36,
    cp_14_37,
    cp_14_38,
    cp_14_39,
    cp_14_3A,
    cp_14_3B,
    cp_14_3C,
    cp_14_3D,
  };
PGM_P const cp_14_c[]  PROGMEM =
  {
    cp_14_50,
    cp_14_51,
    cp_14_52,
    cp_14_53,
    cp_14_54,
    NULL,  //   55
    NULL,  //   56
    NULL,  //   57
    NULL,  //   58
    NULL,  //   59
    cp_14_5A,
    cp_14_5B,
    cp_14_5C,
    cp_14_5D,
    NULL,  //   5E
    NULL,  //   5F
    NULL,  //   60
    NULL,  //   61
    NULL,  //   62
    NULL,  //   63
    cp_14_64,
    cp_14_65,
    cp_14_66,
    cp_14_67,
    cp_14_68,
    cp_14_69,
    NULL,  //   6A
    NULL,  //   6B
    NULL,  //   6C
    NULL,  //   6D
    cp_14_6E,
    cp_14_6F,
    cp_14_70,
    cp_14_71,
    cp_14_72,
    cp_14_73,
    cp_14_74,
    cp_14_75,
    cp_14_76,
    cp_14_77,
    cp_14_78,
    cp_14_79,
    cp_14_7A,
    cp_14_7B,
    cp_14_7C,
    cp_14_7D,
    cp_14_7E,
    cp_14_7F,
    NULL,    //80
    NULL,    //81
    cp_14_82,
    cp_14_83,
    cp_14_84,
    NULL,    //85
    NULL,    //86
    cp_14_87,
    NULL,    //88
    NULL,    //89
    NULL,    //8A
    NULL,    //8B
    cp_14_8C,
    cp_14_8D,
    cp_14_8E,
    cp_14_8F,
    cp_14_90,
    cp_14_91,
    cp_14_92,
    cp_14_93,
    cp_14_94,
    cp_14_95,
    cp_14_96,
    cp_14_97,
    cp_14_98,
    cp_14_99,
  };

PGM_P const cp_1B[]  PROGMEM =
  {
    cp_1B_20,
    cp_1B_21,
    NULL,
    cp_1B_23,
    cp_1B_24,
    cp_1B_25,
    cp_1B_26,
    cp_1B_27,
    cp_1B_28,
    cp_1B_29,
    cp_1B_2A,
    cp_1B_2B,
    cp_1B_2C,
    cp_1B_2D,
    cp_1B_2E,
    cp_1B_2F,
    cp_1B_30,
    cp_1B_31,
    cp_1B_32,
    cp_1B_33,
    cp_1B_34,
    cp_1B_35,
    cp_1B_36,
    cp_1B_37,
    cp_1B_38,
    cp_1B_39,
    cp_1B_3A,
    cp_1B_3B,
    cp_1B_3C,
    cp_1B_3D,
    cp_1B_3E,
    cp_1B_3F,
    cp_1B_40,
    cp_1B_41,
    cp_1B_42,
    cp_1B_43,
    cp_1B_44,
    cp_1B_45,
    cp_1B_46,
    cp_1B_47,
    cp_1B_48,
    cp_1B_49,
    cp_1B_4A,
    cp_1B_4B,
    cp_1B_4C,
    cp_1B_4D,
    cp_1B_4E,
    cp_1B_4F,
    cp_1B_50,
    cp_1B_51,
    cp_1B_52,
    cp_1B_53,
    cp_1B_54,
    cp_1B_55,
    cp_1B_56,
    cp_1B_57,
    cp_1B_58,
    cp_1B_59,
    cp_1B_5A,
    cp_1B_5B,
    cp_1B_5C,
    cp_1B_5D,
    cp_1B_5E,
    cp_1B_5F,
    cp_1B_60,
    cp_1B_61,
    cp_1B_62,
    cp_1B_63,
    cp_1B_64,
    cp_1B_65,
    cp_1B_66,
    cp_1B_67,
    cp_1B_68,
    cp_1B_69,
    cp_1B_6A,
    cp_1B_6B,
    cp_1B_6C,
    cp_1B_6D,
    cp_1B_6E,
    cp_1B_6F,
    cp_1B_70,
    cp_1B_71,
    cp_1B_72,
    cp_1B_73,
    cp_1B_74,
    cp_1B_75,
    cp_1B_76,
    cp_1B_77,
    cp_1B_78,
    cp_1B_79,
    cp_1B_7A,
    cp_1B_7B,
    cp_1B_7C,
    cp_1B_7D,
    cp_1B_7E,
    NULL,
    cp_1B_80,
    cp_1B_81,
    cp_1B_82,
    cp_1B_83,
    cp_1B_84,
};

PGM_P const cp_1C[]  PROGMEM =
 {
    cp_1C_20,
    cp_1C_21,
    NULL,
    cp_1C_23,
    cp_1C_24,
    cp_1C_25,
    cp_1C_26,
    cp_1C_27,
    cp_1C_28,
    cp_1C_29,
    cp_1C_2A,
    cp_1C_2B,
    cp_1C_2C,
    cp_1C_2D,
    cp_1C_2E,
    cp_1C_2F,
    cp_1C_30,
    cp_1C_31,
    cp_1C_32,
    cp_1C_33,
    cp_1C_34,
    cp_1C_35,
    cp_1C_36,
    cp_1C_37,
    cp_1C_38,
    cp_1C_39,
    cp_1C_3A,
    cp_1C_3B,
    cp_1C_3C,
    cp_1C_3D,
    cp_1C_3E,
    cp_1C_3F,
    cp_1C_40,
    cp_1C_41,
    cp_1C_42,
    cp_1C_43,
    cp_1C_44,
    cp_1C_45,
    cp_1C_46,
    cp_1C_47,
    cp_1C_48,
    cp_1C_49,
    cp_1C_4A,
    cp_1C_4B,
    cp_1C_4C,
    cp_1C_4D,
    cp_1C_4E,
    cp_1C_4F,
    cp_1C_50,
    cp_1C_51,
    cp_1C_52,
    cp_1C_53,
    cp_1C_54,
    cp_1C_55,
    cp_1C_56,
    cp_1C_57,
    cp_1C_58,
    cp_1C_59,
    cp_1C_5A,
    cp_1C_5B,
    cp_1C_5C,
    cp_1C_5D,
    cp_1C_5E,
    cp_1C_5F,
    cp_1C_60,
    cp_1C_61,
    cp_1C_62,
    cp_1C_63,
    cp_1C_64,
    cp_1C_65,
    cp_1C_66,
    cp_1C_67,
    cp_1C_68,
    cp_1C_69,
    cp_1C_6A,
    cp_1C_6B,
    cp_1C_6C,
    cp_1C_6D,
    cp_1C_6E,
    cp_1C_6F,
    cp_1C_70,
    cp_1C_71,
    cp_1C_72,
    cp_1C_73,
    cp_1C_74,
    cp_1C_75,
    cp_1C_76,
    cp_1C_77,
    cp_1C_78,
    cp_1C_79,
    cp_1C_7A,
    cp_1C_7B,
    cp_1C_7C,
    cp_1C_7D,
    cp_1C_7E,
 };

PGM_P const cp_1F[]  PROGMEM = 
  {
    cp_1F_20, 
    cp_1F_21, 
    NULL,
    cp_1F_23, 
    cp_1F_24, 
    cp_1F_25, 
    cp_1F_26, 
    cp_1F_27, 
    cp_1F_28, 
    cp_1F_29, 
    cp_1F_2A, 
    cp_1F_2B, 
    cp_1F_2C, 
    cp_1F_2D, 
    cp_1F_2E, 
    cp_1F_2F, 
    cp_1F_30, 
    cp_1F_31, 
    cp_1F_32, 
    cp_1F_33, 
    cp_1F_34, 
    cp_1F_35, 
    cp_1F_36, 
    cp_1F_37, 
    cp_1F_38, 
    cp_1F_39, 
    cp_1F_3A, 
    cp_1F_3B, 
    cp_1F_3C, 
    cp_1F_3D, 
    cp_1F_3E, 
    cp_1F_3F, 
    cp_1F_40, 
    cp_1F_41, 
    cp_1F_42, 
    cp_1F_43, 
    cp_1F_44, 
    cp_1F_45, 
    cp_1F_46, 
    cp_1F_47, 
    cp_1F_48, 
    cp_1F_49, 
    cp_1F_4A, 
    cp_1F_4B, 
    cp_1F_4C, 
    cp_1F_4D, 
    cp_1F_4E, 
    cp_1F_4F, 
    cp_1F_50, 
    cp_1F_51, 
    cp_1F_52, 
    cp_1F_53, 
    cp_1F_54, 
    cp_1F_55, 
    cp_1F_56, 
    cp_1F_57, 
    cp_1F_58, 
    cp_1F_59, 
    cp_1F_5A, 
    cp_1F_5B, 
    cp_1F_5C, 
    cp_1F_5D, 
    cp_1F_5E, 
    cp_1F_5F, 
    cp_1F_60, 
    cp_1F_61, 
    cp_1F_62, 
    cp_1F_63, 
    cp_1F_64, 
    cp_1F_65, 
    cp_1F_66, 
    cp_1F_67, 
    cp_1F_68, 
    cp_1F_69, 
    cp_1F_6A, 
    cp_1F_6B, 
    cp_1F_6C, 
    cp_1F_6D, 
    cp_1F_6E, 
    cp_1F_6F, 
    cp_1F_70, 
    cp_1F_71, 
    cp_1F_72, 
    cp_1F_73, 
    cp_1F_74, 
    cp_1F_75, 
    cp_1F_76, 
    cp_1F_77, 
    cp_1F_78, 
    cp_1F_79, 
    cp_1F_7A, 
    cp_1F_7B, 
    cp_1F_7C, 
    cp_1F_7D, 
    cp_1F_7E, 
  };


extern unsigned char display_codepage;


// get_cp_pointer liefert einen Pointer auf eine Struktur width, heigth, pixels[]
// zurck. Das ist die entsprechende Bitmap des Zeichens in der gewhlten Codepage.
// Wenn keine BMP hinterlegt ist, wird NULL zurckgeliefert.
// Aufrufparameter: z: ASCII Code des Zeichens
PGM_P get_cp_pointer(unsigned char z)
  {
    switch(display_codepage)
      {
        default: return(NULL);
        case 0x12:
            switch (z)
              {
                default:            return(NULL);
                case 0x00 ... 0x0B: return((PGM_P)pgm_read_word(&cp_12_a[z]));
                case 0x80 ... 0x8B: return((PGM_P)pgm_read_word(&cp_12_b[z-0x80]));
              }
        case 0x13:
            switch (z)
              {
                default:            return(NULL);
                case 0x00 ... 0xFF: return((PGM_P)pgm_read_word(&cp_13[z]));
              }
        case 0x14:
            switch (z)
              {
                default:            return(NULL);
                case 0x00 ... 0x0E: return((PGM_P)pgm_read_word(&cp_14_a[z]));
                case 0x32 ... 0x3D: return((PGM_P)pgm_read_word(&cp_14_b[z-0x32]));
                case 0x50 ... 0x99: return((PGM_P)pgm_read_word(&cp_14_c[z-0x50]));
              }
        case 0x1B:
            switch (z)
              {
                default:            return(NULL);
                case 0x20 ... 0x84: return((PGM_P)pgm_read_word(&cp_1B[z-0x20]));
                case 0xC4:          return(cp_1B_C4);
                case 0xD6:          return(cp_1B_D6);
                case 0xDC:          return(cp_1B_DC);
                case 0xE4:          return(cp_1B_E4);
                case 0xF6:          return(cp_1B_F6);
                case 0xFC:          return(cp_1B_FC);
                case 0xDF:          return(cp_1B_DF);
              }
        case 0x1C:
            switch (z)
              {
                default:            return(NULL);
                case 0x20 ... 0x7E: return((PGM_P)pgm_read_word(&cp_1C[z-0x20]));
                case 0xC4:          return(cp_1C_C4);
                case 0xD6:          return(cp_1C_D6);
                case 0xDC:          return(cp_1C_DC);
                case 0xE4:          return(cp_1C_E4);
                case 0xF6:          return(cp_1C_F6);
                case 0xFC:          return(cp_1C_FC);
                case 0xDF:          return(cp_1C_DF);
              }
        case 0x1F:
            switch (z)
              {
                default:            return(NULL);
                case 0x20 ... 0x7E: return((PGM_P)pgm_read_word(&cp_1F[z-0x20]));
                case 0xC4:          return(cp_1F_C4);
                case 0xD6:          return(cp_1F_D6);
                case 0xDC:          return(cp_1F_DC);
                case 0xE4:          return(cp_1F_E4);
                case 0xF6:          return(cp_1F_F6);
                case 0xFC:          return(cp_1F_FC);
                case 0xDF:          return(cp_1F_DF);
              }
      }
  }


//---------------------------------------------------------------------------------
#if (1==0)
PGM_P z_ptr;

void test(void)
  {
    unsigned char width, height;
    z_ptr = get_cp_pointer(0x41);
     
     
     width = pgm_read_byte(z_ptr++);
     height = pgm_read_byte(z_ptr++);
     PORTA = width;
     PORTA = height;
     PORTA = pgm_read_byte(z_ptr++);
     PORTA = pgm_read_byte(z_ptr++);
     PORTA = pgm_read_byte(z_ptr++);
     PORTA = pgm_read_byte(z_ptr++);
     PORTA = pgm_read_byte(z_ptr++);
     PORTA = pgm_read_byte(z_ptr++);

  }
#endif
