//----------------------------------------------------------------
//
// OpenDCC
// Throttle MFT 1.0
//
// Copyright (c) 2008-2009 Jean Michel Fischer, Wolfgang Kufer
//
// This source file is subject of the GNU general public license 2,
// that is available at the world-wide-web at
// http://www.gnu.org/licenses/gpl.txt
//
// This code is initially based on:
// http://www.mikrocontroller.net/articles/AVR-GCC-Tutorial
//
//-----------------------------------------------------------------
//
// file:      display.h
// author:    Wolfgang Kufer
// contact:   kufer@gmx.de
// webpage:   http://www.opendcc.de
// history:   2008-09-18 V0.01 jmf started
//            2009-01-13 V0.02 kw  comments, tests
//            2009-01-26 V0.03 kw  splash + set_cursor jetzt ab 0,0
//            2011-01-22 V0.04 kw  added prototypes for color, title, switch
//
//-----------------------------------------------------------------
//
// purpose:   supply mid-level routines,
//            showing the content
//
// Interface: downstream: lcd_text.h
//            upstream:
//
//-----------------------------------------------------------------

#ifndef _DISPLAY_H_
#define _DISPLAY_H_

#include <stdbool.h>

extern unsigned char display_time_allowed;

// - softkeys

void display_softkey(uint8_t key, const char *data);
void display_softkey_P(uint8_t key, const char * progmem_data); // PGM_P
void clear_softkey(uint8_t key);

void display_text(unsigned char col, unsigned char row, char * text);

void display_title(const char *title);

void display_status(t_status status);      // show status at upper right corner

void display_batt_state(void);

void display_connect_state(t_connect_state connect_state);

void check_status_display(unsigned char key);

void display_error(unsigned char errnum);
void display_error2(unsigned char errnum, unsigned char code);

// speed: -126 ...+126; +126 = forward
// output is compressed to 0..7
void display_loc_speed(t_format format, unsigned char speed, unsigned char dir);
void display_loc_name(char * name);

// for advanced switch menu
void display_switch_name(char * name);


void  LCD_PF_string_P(const char *progmem_data);        // prop font 5x7
void  LCD_PF_string(const char *data);


#endif /* _DISPLAY_H_ */
