//----------------------------------------------------------------
//
// OpenDCC
// Throttle MFT 1.0
//
// Copyright (c) 2008-2009 Wolfgang Kufer
//
// This source file is subject of the GNU general public license 2,
// that is available at the world-wide-web at
// http://www.gnu.org/licenses/gpl.txt
//
// Here we do the access to a spi flash
//
//-----------------------------------------------------------------
//
// file:      flash_driver_m25p80.h
// author:    Wolfgang Kufer
// contact:   kufer_at_gmx.de
// webpage:   http://www.opendcc.de
// history:   2009-07-04 V0.07 kw  started
//
//-----------------------------------------------------------------
//
// purpose:   control of a spi driven flash
//
// howto:     3 Layers:
//            Layer 0: doing the SPI_transfer
//            Layer 1: running the commands for m25p80
//            Layer 2: performing read, write, erase
//
//            handling of SPI_CS:
//            we assert and deassert CS in layer 1 to gruup commands
//            we dont use HOLD or PROTECTION
//
//-----------------------------------------------------------------

void flash_init(void);

void flash_erase_complete(void);

// read a block of data from addr in flash
// here we use normal read (this is up to 20MHz)
void flash_read(uint32_t addr, uint8_t* buffer, uint16_t count);

// write to a page in flash at addr (max. 256 bytes in sequence)
// Note: this is only changing from 1 to 0 - so erase is need before!

void flash_write(uint32_t addr, const uint8_t* buffer, uint16_t count);


// erase the sector which contains address addr /512kBit are erased!
void flash_erase_sector(uint32_t addr);



