//------------------------------------------------------------------------
//
// OpenDCC - Rotary Encoder & Keys
//
// Copyright (c) 2008 Kufer
//
// This source file is subject of the GNU general public license 2,
// that is available at the world-wide-web at
// http://www.gnu.org/licenses/gpl.txt
// 
//------------------------------------------------------------------------
//
// file:      keyboard.h
// author:    Wolfgang Kufer
// contact:   kufer@gmx.de
// webpage:   http://www.opendcc.de
// history:   2008-09-23 V0.01 kw started
//            2010-04-26 V0.02 kw header guard
//
//------------------------------------------------------------------------
//
// purpose:   create keystrokes from rotary encoder
//            here: hardware interface, accelleration functions
//
// content:   1. rotary encoder
//            2. keyboard (2 rows)
//
//------------------------------------------------------------------------
//
// interface: 1. call init_keyboard();
//            2. whenever the knob is rotated, a keystroke is issued
//            2. whenever a key is pressed, a keystroke is issued
//            3. the calling program must ask get_knob_rotate() to
//               receive the actual rotation - this value may be zero,
//               even if a knob_keystroke was issued!
//               get_knob_rotate() returns the sum of rotation steps.
//------------------------------------------------------------------------
//

#ifndef _KEYBOARD_H_
#define _KEYBOARD_H_

#include "keycodes.h"    // table (scan -> keystroke)
#include "cortos.h"

extern void keyboard_poll(void);        // to be called every 1-2ms, results go to fifo

extern void knob_poll(void);            // to be called every 1-2ms, results go to fifo

// - config

extern void init_keyboard(void);

void set_knob_speedup_none(void);       // no speed up table

void set_knob_speedup_normal(void);     // accelerate up to 10 times

// - access

extern unsigned char get_wait_keystroke(void);    // busy waiting for keystroke

extern unsigned char is_shift_pressed(void);      // shift key

extern signed int get_knob_rotate(void);          // get accumulated knob rotation

extern unsigned char keystroke_present(void);     // true if a keystroke could be fetched

// - for hook functions

extern cr_fifo_t key_fifo;

#endif

