//------------------------------------------------------------------------
//
// OpenDCC - Keboard and Rotary Encoder
//
// Copyright (c) 2008 Kufer
//
// This source file is subject of the GNU general public license 2,
// that is available at the world-wide-web at
// http://www.gnu.org/licenses/gpl.txt
//
//------------------------------------------------------------------------
//
// file:      keys.h
// author:    Wolfgang Kufer
// contact:   kufer@gmx.de
// webpage:   http://www.opendcc.de
// history:   2008-11-20 V0.01 kw  started
//            2009-03-02 V0.02 kw  added some keys
//            2009-06-30 V0.03 kw  added KEY_PARSER_TIME, KEY_CONNECT
//            2010-05-12 V0.04 kw  added KEY_DISCONNECT
//            2010-06-06 V0.05 nn  added release_keycodes
//
//------------------------------------------------------------------------
//
// purpose:   define keystroke codes
//            please use only the literals throuhout the whole code
//
// note:      Bit 6 (0x40) is reserved for shift, it can be masked in the
//            application
//
                                    // Scan line 0 
#define     KEY_DOWN            0x10
#define     KEY_LEFT            0x11
#define     KEY_CENTER          0x12
#define     KEY_RIGHT           0x13
#define     KEY_UP              0x14
#define     KEY_SHIFT           0x40    // if only shift is pressed
#define     KEY_KNOB            0x20
#define     KEY_STOP            0x80
                                    // Scan line 0 with shift pressed
#define     KEY_SH_DOWN         0x50
#define     KEY_SH_LEFT         0x51
#define     KEY_SH_CENTER       0x52
#define     KEY_SH_RIGHT        0x53
#define     KEY_SH_UP           0x54
#define     KEY_SHIFT           0x40    // if only shift is pressed
#define     KEY_SH_KNOB         0x60
#define     KEY_SH_STOP         0xC0
                                    // Scan line 1
#define     KEY_A               0x18   // these keys must be ordered and start with 0b00
#define     KEY_B               0x19
#define     KEY_C               0x1A
#define     KEY_D               0x1B
                                    // Scan line 1 with shift pressed
#define     KEY_SH_A            0x58
#define     KEY_SH_B            0x59
#define     KEY_SH_C            0x5A
#define     KEY_SH_D            0x5B

#define     KEY_KNOB_TURNED     0x21   // not a real key; this only annouces a knob turned event

#define     KEY_SHIFT_RELEASE   0x41   // this keystrok is issued, when shift is released

// For PC-Throttle, we would also need release events

#define     KEY_DOWN_RELEASE    0x30
#define     KEY_LEFT_RELEASE    0x31
#define     KEY_CENTER_RELEASE  0x32
#define     KEY_RIGHT_RELEASE   0x33
#define     KEY_UP_RELEASE      0x34

#define     KEY_A_RELEASE       0x38   // these keys must be ordered and start with 0b00
#define     KEY_B_RELEASE       0x39
#define     KEY_C_RELEASE       0x3A
#define     KEY_D_RELEASE       0x3B
#define     KEY_KNOB_RELEASE    0x61

#define     KEY_STOP_RELEASE    0x81


#define     KEY_LAST_REAL_KEY   0x81

//------------------------------------------------ no real key beyond this point!!

// The following keystrokes are dummies,
// issued by programmer, to force an update of the current screen
#define     KEY_PROGRAMMER      0xD0

// The following keystrokes are dummies,
// issued by system monitor, to force an update of the current screen

#define     KEY_BATT_EMPTY      0xD1
#define     KEY_BATT_20_100     0xD2
#define     KEY_BATT_40_100     0xD3
#define     KEY_BATT_60_100     0xD4
#define     KEY_BATT_FULL       0xD5
#define     KEY_VCCIO           0xD6    // Power Event (connect / disconnect)


#define     KEY_XBEE_ANNOUNCE   0xD7    // xbee break event (enter debug mode)
#define     KEY_XBEE_REC        0xD8    // xbee rec event
#define     KEY_XBEE_ERROR      0xD9    // xbee communication error
#define     KEY_XBEE_COORD      0xDA    // coordinator active
#define     KEY_XBEE_RUNNING    0xDB    // init done
#define     KEY_XBEE_AI         0xDC    // association state changed
#define     KEY_DISCONNECT      0xDD    // Disconnection Event
#define     KEY_CONNECT         0xDE    // Connection Event
#define     KEY_HEARTBEAT       0xDF

// The following keystrokes are dummies,
// issued by parser, to force an update of the current screen

#define     KEY_PARSER          0xE0    // general Event (obsolete)
#define     KEY_PARSER_STATE    0xE1    // State change
#define     KEY_PARSER_FB       0xE2    // Feedback event
#define     KEY_PARSER_SWITCH   0xE3    // Accessory event
#define     KEY_PARSER_LOK      0xE4    // Lok event
#define     KEY_PARSER_STOLEN   0xE5    // Lok owner event
#define     KEY_PARSER_PROG     0xE6    // programming event
#define     KEY_PARSER_DATABASE 0xE7    // new database entry received
#define     KEY_PARSER_CFG      0xE8    // command station config message
#define     KEY_PARSER_MESSAGE  0xE9    // raw pc message received
#define     KEY_PARSER_REMOTE   0xEA    // enter remote mode
#define     KEY_PARSER_TIME     0xEB    // time code received
#define     KEY_PARSER_SIGNAL   0xEC    // Extended Accessory event



// no other key above 0xE0


// old keys (obsolete)
#if (0==1)
#define  KEY_1           1
#define  KEY_2           2
#define  KEY_3           3
#define  KEY_4           4
#define  KEY_5           5
#define  KEY_6           6
#define  KEY_7           7
#define  KEY_8           8
#define  KEY_9           9
#define  KEY_0          10
#define  KEY_OK         11
#define  KEY_CHANGE     12
#define  KEY_ESC        13
#endif

