#ifndef _LCD_DRIVER_ST7565_H_
#define _LCD_DRIVER_ST7565_H_
#include <avr/pgmspace.h>


//LCD spec definitions
#define LCD_PAGE_HEIGHT     8   //8 lines per page
#define LCD_LINES          64   // must be a multiple of PAGE_HEIGHT - (int conversions!)
#define LCD_LINE_LENGTH   128


//            2010-07-12 V0.06 kw  added LCD_pixelPattern


//------------------------------------------------------------------------------
// Global variables used by driver
//

extern unsigned char display_invers;       // this is either 0 or 0xFF
                                           // 00: print font bitmap as is
                                           // ff: print inverted 
extern unsigned char display_keep;         // this is either 0 or 0xFF 
                                           // 00: replace video content
                                           // ff: keep video content             

extern uint8_t LCD_currentX;
extern uint8_t LCD_currentY;

extern volatile uint8_t update_blocked;

typedef struct
  {
    uint8_t page_modified;
  } t_update_lcd;

extern t_update_lcd update_lcd[LCD_LINES / LCD_PAGE_HEIGHT ];

typedef struct
  {
    uint8_t Mode;
    uint8_t OffAct;
    uint8_t OffCount;
    uint8_t OnAct;
    uint8_t OnCount;
  } t_LCD_linePixel;

extern t_LCD_linePixel LCD_linePixel;
//------------------------------------------------------------------------------
// Calls


void lcd_init(void);
void lcd_reset(void);

void LCD_setCursorXY(uint8_t x, uint8_t y);
void LCD_getCursorXY(uint8_t* x, uint8_t* y);
void LCD_pixelOff(uint8_t x, uint8_t y);
void LCD_invertPixel(uint8_t x, uint8_t y);
void LCD_pixelOn(uint8_t x, uint8_t y);
void LCD_pixelPattern(uint8_t x, uint8_t y);   // based on struct line_pixels


void LCD_invertPage(uint8_t page, uint8_t x1, uint8_t x2);
void LCD_onPage(uint8_t page,uint8_t x1,uint8_t x2);
void LCD_offPage(uint8_t page,uint8_t x1,uint8_t x2);
void LCD_fillPage_with_BMP(uint8_t width, PGM_VOID_P bitmap_P);
void LCD_drawBMP_aligned(PGM_VOID_P bitmap_P, uint8_t width, uint8_t height);

void LCD_drawBMP(PGM_VOID_P  bitmap_P);

void LCD_clr(void);
void lcd_clear(void);  // same
void LCD_fill_with_counter(void);
void LCD_fill_with_BMP(uint8_t* bitmap_P);

//cursor
void cursor_off(void);
void cursor_on(void);

//char function (font 5x7)
void LCD_putchar(uint8_t c);
void LCD_PF_putchar(uint8_t c);   // same, but variable run length
unsigned char LCD_PF_get_sizeX(uint8_t c);  // query for char size
void LCD_puts(uint8_t* pString);
void LCD_putsp(uint8_t* pString, uint8_t page, uint8_t x);

//char function (font 4x6)
void LCD_number_6px(char* data);

// lowlevel
void    LCD_writeByte(uint8_t data); // needed for bmp download
void    LCD_contrast(uint8_t contrast);

// housekeeping
// call this function at end of your display routines
void enable_display_update(void);

// no tasking
void update_display_complete(void);

#endif
