//------------------------------------------------------------------------
//
// OpenDCC - Throttle MFT (My First Throttle)
//
// Copyright (c) 2009 
//
// This source file is subject of the GNU general public license 3,
// that is available at the world-wide-web at
// http://www.gnu.org/licenses/gpl.txt
//
//------------------------------------------------------------------------
//
// file:      font5x7.h
// author:    Wolfgang Kufer
// contact:   kufer@gmx.de
// webpage:   http://www.opendcc.de
// history:   2009-03-18 V0.02 kw  added font5x7prop
//
//------------------------------------------------------------------------
//
// purpose:   Graphic LCD Font (Ascii Characters)
//
//------------------------------------------------------------------------
//
// content:   Pixel Data
//            Each byte of a character is a column of it.
//            The LSB is the top most pixel, the MSB the bottom.
//            I.e. 0x01 is a pixel at the top most row, where 0x80 is one at the bottom.
//
// reference: This file is mainly based on the original work from
//            Pascal Stang, font5x7.h, V0.01 from 10/19/2001
//
// changes:   I added special characters in the range 0..31
//            and made a duplication with variable run length
//
//------------------------------------------------------------------------

#ifndef FONT5X7_H
#define FONT5X7_H

// Char Defines for font extention
#define C_ARROW_L_LIGHT     0x14   // *: left arrow >> 
#define C_ARROW_R_LIGHT     0x15   // *  right arrow <<

#define C_ARROW_LEFT_UP     0x16   // *: arrow left up (135)
#define C_ARROW_RIGHT_UP    0x17   // *: arrow right up (45)
#define C_ARROW_LEFT_DOWN   0x18   // *: arrow left down (225)
#define C_ARROW_RIGHT_DOWN  0x19   // *: arrow right down (315)

#define C_ARROW_UP_SMALL    0x1A   // |
#define C_ARROW_RIGHT_SMALL 0x1B   // |
#define C_ARROW_DOWN_SMALL  0x1C   // |
#define C_ARROW_LEFT_SMALL  0x1D   // |

#define C_ARROW_UP_DOWN     0x1E

#define C_NUM_EXP_0         0x0A   // small upper 0
#define C_NUM_EXP_1         0x01   // small upper 1
#define C_NUM_EXP_2         0x02   // small upper 2
#define C_NUM_EXP_3         0x03   // small upper 3
#define C_NUM_EXP_4         0x04   // small upper 4
#define C_NUM_EXP_5         0x05   // small upper 5
#define C_NUM_EXP_6         0x06   // small upper 6
#define C_NUM_EXP_7         0x07   // small upper 7
#define C_NUM_EXP_8         0x08   // small upper 8
#define C_NUM_EXP_9         0x09   // small upper 9  

#define C_BLOCK_SMALL       0x0B   //
#define C_BLOCK_M2          0x0C   // medium, used for digit

#define Font5x7_WIDTH       5
#define Font5x7_HEIGHT      7

static const unsigned char __attribute__ ((progmem)) Font5x7[] = {
// extentions for MFT
	0xFF, 0x00, 0x00, 0x00, 0x00,// void
	0x12, 0x1F, 0x10, 0x00, 0x00,// 0x01 small 1
	0x12, 0x19, 0x15, 0x12, 0x00,// 0x02 small 2
	0x11, 0x15, 0x15, 0x0A, 0x00,// 0x03 small 3
	0x0C, 0x0A, 0x1F, 0x08, 0x00,// 0x04 small 4
	0x17, 0x15, 0x15, 0x09, 0x00,// 0x05 small 5
	0x0E, 0x15, 0x15, 0x08, 0x00,// 0x06 small 6
	0x01, 0x19, 0x05, 0x03, 0x00,// 0x07 small 7
	0x0A, 0x15, 0x15, 0x0A, 0x00,// 0x08 small 8
	0x02, 0x15, 0x15, 0x0A, 0x00,// 0x09 small 9
	0x0E, 0x11, 0x11, 0x0E, 0x00,// 0x0A small 0
    0x00, 0x18, 0x18, 0x00, 0x00,// 0x0B block small
	0x3C, 0x3C, 0x3C, 0x3C, 0x00,// 0x0C block medium
	0xFF, 0x00, 0x00, 0x00, 0x00,// 0x0D
	0xFF, 0x00, 0x00, 0x00, 0x00,// 0x0E
    0xFF, 0x00, 0x00, 0x00, 0x00,// 0x0F
   	0xFF, 0x00, 0x00, 0x00, 0x00,// 0x10
	0xFF, 0x00, 0x00, 0x00, 0x00,// 0x11
	0xFF, 0x00, 0x00, 0x00, 0x00,// 0x12
	0xFF, 0x00, 0x00, 0x00, 0x00,// 0x13
	0x08, 0x14, 0x2A, 0x14, 0x22,// 0x14 left arrow >> 
	0x22, 0x14, 0x2A, 0x14, 0x08,// 0x15 right arrow <<
	0x07, 0x03, 0x05, 0x08, 0x10,// 0x16 arrow left up (135)
	0x10, 0x08, 0x05, 0x03, 0x07,// 0x17 arrow right up (45)
	0x70, 0x60, 0x50, 0x08, 0x04,// 0x18 arrow left down (225) 
	0x04, 0x08, 0x50, 0x60, 0x70,// 0x19 arrow right down (315)  
	0x04, 0x02, 0x7F, 0x02, 0x04,// 0x1A arrow up small
	0x08, 0x08, 0x2A, 0x1C, 0x08,// 0x1B arrow right small
	0x10, 0x20, 0x7F, 0x20, 0x10,// 0x1C arrow down small 
	0x08, 0x1C, 0x2A, 0x08, 0x08,// 0x1D arrow left small 
	0x14, 0x22, 0x7F, 0x22, 0x14,// 0x1E arrow up-down
    0x00, 0x00, 0x00, 0x00, 0x00,// 0x1F wide space
// standard ascii 5x7 font (by Pascal Stang)
// defines ascii characters 0x20-0x7F (32-127)
	0x00, 0x00, 0x00, 0x00, 0x00,// 0x20  (space)
	0x00, 0x00, 0x5F, 0x00, 0x00,// 0x21 !
	0x00, 0x07, 0x00, 0x07, 0x00,// 0x22 "
	0x14, 0x7F, 0x14, 0x7F, 0x14,// 0x23 #
	0x24, 0x2A, 0x7F, 0x2A, 0x12,// 0x24 $
	0x23, 0x13, 0x08, 0x64, 0x62,// 0x25 %
	0x36, 0x49, 0x55, 0x22, 0x50,// 0x26 &
	0x00, 0x05, 0x03, 0x00, 0x00,// 0x27 '
	0x00, 0x1C, 0x22, 0x41, 0x00,// 0x28 (
	0x00, 0x41, 0x22, 0x1C, 0x00,// 0x29 )
	0x08, 0x2A, 0x1C, 0x2A, 0x08,// 0x2A *
	0x08, 0x08, 0x3E, 0x08, 0x08,// 0x2B +
	0x00, 0x50, 0x30, 0x00, 0x00,// 0x2C ,
	0x08, 0x08, 0x08, 0x08, 0x08,// 0x2D -
	0x00, 0x60, 0x60, 0x00, 0x00,// 0x2E .
	0x20, 0x10, 0x08, 0x04, 0x02,// 0x2F /
	0x3E, 0x51, 0x49, 0x45, 0x3E,// 0x30 0
	0x00, 0x42, 0x7F, 0x40, 0x00,// 0x31 1
	0x42, 0x61, 0x51, 0x49, 0x46,// 0x32 2
	0x21, 0x41, 0x45, 0x4B, 0x31,// 0x33 3
	0x18, 0x14, 0x12, 0x7F, 0x10,// 0x34 4
	0x27, 0x45, 0x45, 0x45, 0x39,// 0x35 5
	0x3C, 0x4A, 0x49, 0x49, 0x30,// 0x36 6
	0x01, 0x71, 0x09, 0x05, 0x03,// 0x37 7
	0x36, 0x49, 0x49, 0x49, 0x36,// 0x38 8
	0x06, 0x49, 0x49, 0x29, 0x1E,// 0x39 9
	0x00, 0x36, 0x36, 0x00, 0x00,// 0x3A :
	0x00, 0x56, 0x36, 0x00, 0x00,// 0x3B ;
	0x00, 0x08, 0x14, 0x22, 0x41,// 0x3C <
	0x14, 0x14, 0x14, 0x14, 0x14,// 0x3D =
	0x41, 0x22, 0x14, 0x08, 0x00,// 0x3E >
	0x02, 0x01, 0x51, 0x09, 0x06,// 0x3F ?
	0x32, 0x49, 0x79, 0x41, 0x3E,// 0x40 @
	0x7E, 0x11, 0x11, 0x11, 0x7E,// 0x41 A
	0x7F, 0x49, 0x49, 0x49, 0x36,// 0x42 B
	0x3E, 0x41, 0x41, 0x41, 0x22,// 0x43 C
	0x7F, 0x41, 0x41, 0x22, 0x1C,// 0x44 D
	0x7F, 0x49, 0x49, 0x49, 0x41,// 0x45 E
	0x7F, 0x09, 0x09, 0x01, 0x01,// 0x46 F
	0x3E, 0x41, 0x41, 0x51, 0x32,// 0x47 G
	0x7F, 0x08, 0x08, 0x08, 0x7F,// 0x48 H
	0x00, 0x41, 0x7F, 0x41, 0x00,// 0x49 I
	0x20, 0x40, 0x41, 0x3F, 0x01,// 0x4A J
	0x7F, 0x08, 0x14, 0x22, 0x41,// 0x4B K
	0x7F, 0x40, 0x40, 0x40, 0x40,// 0x4C L
	0x7F, 0x02, 0x04, 0x02, 0x7F,// 0x4D M
	0x7F, 0x04, 0x08, 0x10, 0x7F,// 0x4E N
	0x3E, 0x41, 0x41, 0x41, 0x3E,// 0x4F O
	0x7F, 0x09, 0x09, 0x09, 0x06,// 0x50 P
	0x3E, 0x41, 0x51, 0x21, 0x5E,// 0x51 Q
	0x7F, 0x09, 0x19, 0x29, 0x46,// 0x52 R
	0x46, 0x49, 0x49, 0x49, 0x31,// 0x53 S
	0x01, 0x01, 0x7F, 0x01, 0x01,// 0x54 T
	0x3F, 0x40, 0x40, 0x40, 0x3F,// 0x55 U
	0x1F, 0x20, 0x40, 0x20, 0x1F,// 0x56 V
	0x7F, 0x20, 0x18, 0x20, 0x7F,// 0x57 W
	0x63, 0x14, 0x08, 0x14, 0x63,// 0x58 X
	0x03, 0x04, 0x78, 0x04, 0x03,// 0x59 Y
	0x61, 0x51, 0x49, 0x45, 0x43,// 0x5A Z
	0x00, 0x00, 0x7F, 0x41, 0x41,// 0x5B [
	0x02, 0x04, 0x08, 0x10, 0x20,// 0x5C "\"
	0x41, 0x41, 0x7F, 0x00, 0x00,// 0x5D ]
	0x04, 0x02, 0x01, 0x02, 0x04,// 0x5E ^
	0x40, 0x40, 0x40, 0x40, 0x40,// 0x5F _
	0x00, 0x01, 0x02, 0x04, 0x00,// 0x60 `
	0x20, 0x54, 0x54, 0x54, 0x78,// 0x61 a
	0x7F, 0x48, 0x44, 0x44, 0x38,// 0x62 b
	0x38, 0x44, 0x44, 0x44, 0x20,// 0x63 c
	0x38, 0x44, 0x44, 0x48, 0x7F,// 0x64 d
	0x38, 0x54, 0x54, 0x54, 0x18,// 0x65 e
	0x08, 0x7E, 0x09, 0x01, 0x02,// 0x66 f
	0x08, 0x14, 0x54, 0x54, 0x3C,// 0x67 g
	0x7F, 0x08, 0x04, 0x04, 0x78,// 0x68 h
	0x00, 0x44, 0x7D, 0x40, 0x00,// 0x69 i
	0x20, 0x40, 0x44, 0x3D, 0x00,// 0x6A j
	0x00, 0x7F, 0x10, 0x28, 0x44,// 0x6B k
	0x00, 0x41, 0x7F, 0x40, 0x00,// 0x6C l
	0x7C, 0x04, 0x18, 0x04, 0x78,// 0x6D m
	0x7C, 0x08, 0x04, 0x04, 0x78,// 0x6E n
	0x38, 0x44, 0x44, 0x44, 0x38,// 0x6F o
	0x7C, 0x14, 0x14, 0x14, 0x08,// 0x70 p
	0x08, 0x14, 0x14, 0x18, 0x7C,// 0x71 q
	0x7C, 0x08, 0x04, 0x04, 0x08,// 0x72 r
	0x48, 0x54, 0x54, 0x54, 0x20,// 0x73 s
	0x04, 0x3F, 0x44, 0x40, 0x20,// 0x74 t
	0x3C, 0x40, 0x40, 0x20, 0x7C,// 0x75 u
	0x1C, 0x20, 0x40, 0x20, 0x1C,// 0x76 v
	0x3C, 0x40, 0x30, 0x40, 0x3C,// 0x77 w
	0x44, 0x28, 0x10, 0x28, 0x44,// 0x78 x
	0x0C, 0x50, 0x50, 0x50, 0x3C,// 0x79 y
	0x44, 0x64, 0x54, 0x4C, 0x44,// 0x7A z
	0x00, 0x08, 0x36, 0x41, 0x00,// 0x7B {
	0x00, 0x00, 0x7F, 0x00, 0x00,// 0x7C |
	0x00, 0x41, 0x36, 0x08, 0x00,// 0x7D }
	0x08, 0x08, 0x2A, 0x1C, 0x08,// 0x7E ->
	0x08, 0x1C, 0x2A, 0x08, 0x08 // 0x7F <-
};

//------------------------------------------------------------------------
// The same font (fixed pixel) with variable run length
// We use the pattern 0xAA as ignore pattern
// All char are left adjusted.

#define IgnP  0xAA   // Ignore Pattern

#define Font5x7prop_WIDTH       5
#define Font5x7prop_HEIGHT      7

static const unsigned char __attribute__ ((progmem)) Font5x7prop[] = {
// extentions for MFT
	0x08, IgnP, IgnP, IgnP, IgnP,// void
	0x12, 0x1F, 0x10, IgnP, IgnP,// 0x01 small 1
	0x12, 0x19, 0x15, 0x12, IgnP,// 0x02 small 2
	0x11, 0x15, 0x15, 0x0A, IgnP,// 0x03 small 3
	0x0C, 0x0A, 0x1F, 0x08, IgnP,// 0x04 small 4
	0x17, 0x15, 0x15, 0x09, IgnP,// 0x05 small 5
	0x0E, 0x15, 0x15, 0x08, IgnP,// 0x06 small 6
	0x01, 0x19, 0x05, 0x03, IgnP,// 0x07 small 7
	0x0A, 0x15, 0x15, 0x0A, IgnP,// 0x08 small 8
	0x02, 0x15, 0x15, 0x0A, IgnP,// 0x09 small 9
	0x0E, 0x11, 0x11, 0x0E, IgnP,// 0x0A small 0
	0x00, 0x18, 0x18, 0x00, IgnP,// 0x0B block small
	0x3C, 0x3C, 0x3C, 0x3C, IgnP,// 0x0C block medium
	0xFF, IgnP, IgnP, IgnP, IgnP,// 0x0D
	0xFF, IgnP, IgnP, IgnP, IgnP,// 0x0E
    0xFF, IgnP, IgnP, IgnP, IgnP,// 0x0F
   	0xFF, IgnP, IgnP, IgnP, IgnP,// 0x10
	0xFF, IgnP, IgnP, IgnP, IgnP,// 0x11
	0xFF, IgnP, IgnP, IgnP, IgnP,// 0x12
	0xFF, IgnP, IgnP, IgnP, IgnP,// 0x13
	0x08, 0x14, 0x2A, 0x14, 0x22,// 0x14 left arrow >> 
	0x22, 0x14, 0x2A, 0x14, 0x08,// 0x15 right arrow <<
	0x07, 0x03, 0x05, 0x08, 0x10,// 0x16 arrow left up (135)
	0x10, 0x08, 0x05, 0x03, 0x07,// 0x17 arrow right up (45)
	0x70, 0x60, 0x50, 0x08, 0x04,// 0x18 arrow left down (225) 
	0x04, 0x08, 0x50, 0x60, 0x70,// 0x19 arrow right down (315)  
	0x04, 0x02, 0x7F, 0x02, 0x04,// 0x1A arrow up small
	0x08, 0x08, 0x2A, 0x1C, 0x08,// 0x1B arrow right small
	0x10, 0x20, 0x7F, 0x20, 0x10,// 0x1C arrow down small 
	0x08, 0x1C, 0x2A, 0x08, 0x08,// 0x1D arrow left small 
	0x14, 0x22, 0x7F, 0x22, 0x14,// 0x1E arrow up-down
    0x00, 0x00, 0x00, 0x00, 0x00,// 0x1F wide space
// standard ascii 5x7 font (by Pascal Stang)
// defines ascii characters 0x20-0x7F (32-127)
	0x00, 0x00, IgnP, IgnP, IgnP,// 0x20  (space)
	0x5F, IgnP, IgnP, IgnP, IgnP,// 0x21 !
	0x07, 0x00, 0x07, IgnP, IgnP,// 0x22 "
	0x14, 0x7F, 0x14, 0x7F, 0x14,// 0x23 #
	0x24, 0x2A, 0x7F, 0x2A, 0x12,// 0x24 $
	0x23, 0x13, 0x08, 0x64, 0x62,// 0x25 %
	0x36, 0x49, 0x55, 0x22, 0x50,// 0x26 &
	0x05, 0x03, IgnP, IgnP, IgnP,// 0x27 '
	0x1C, 0x22, 0x41, IgnP, IgnP,// 0x28 (
	0x41, 0x22, 0x1C, IgnP, IgnP,// 0x29 )
	0x08, 0x2A, 0x1C, 0x2A, 0x08,// 0x2A *
	0x08, 0x08, 0x3E, 0x08, 0x08,// 0x2B +
	0x50, 0x30, IgnP, IgnP, IgnP,// 0x2C ,
	0x08, 0x08, 0x08, 0x08, 0x08,// 0x2D -
	0x60, 0x60, IgnP, IgnP, IgnP,// 0x2E .
	0x20, 0x10, 0x08, 0x04, 0x02,// 0x2F /
	0x3E, 0x51, 0x49, 0x45, 0x3E,// 0x30 0
	0x42, 0x7F, 0x40, IgnP, IgnP,// 0x31 1
	0x42, 0x61, 0x51, 0x49, 0x46,// 0x32 2
	0x21, 0x41, 0x45, 0x4B, 0x31,// 0x33 3
	0x18, 0x14, 0x12, 0x7F, 0x10,// 0x34 4
	0x27, 0x45, 0x45, 0x45, 0x39,// 0x35 5
	0x3C, 0x4A, 0x49, 0x49, 0x30,// 0x36 6
	0x01, 0x71, 0x09, 0x05, 0x03,// 0x37 7
	0x36, 0x49, 0x49, 0x49, 0x36,// 0x38 8
	0x06, 0x49, 0x49, 0x29, 0x1E,// 0x39 9
	0x36, 0x36, IgnP, IgnP, IgnP,// 0x3A :
	0x56, 0x36, IgnP, IgnP, IgnP,// 0x3B ;
	0x08, 0x14, 0x22, 0x41, IgnP,// 0x3C <
	0x14, 0x14, 0x14, 0x14, 0x14,// 0x3D =
	0x41, 0x22, 0x14, 0x08, IgnP,// 0x3E >
	0x02, 0x01, 0x51, 0x09, 0x06,// 0x3F ?
	0x32, 0x49, 0x79, 0x41, 0x3E,// 0x40 @
	0x7E, 0x11, 0x11, 0x11, 0x7E,// 0x41 A
	0x7F, 0x49, 0x49, 0x49, 0x36,// 0x42 B
	0x3E, 0x41, 0x41, 0x41, 0x22,// 0x43 C
	0x7F, 0x41, 0x41, 0x22, 0x1C,// 0x44 D
	0x7F, 0x49, 0x49, 0x49, 0x41,// 0x45 E
	0x7F, 0x09, 0x09, 0x01, 0x01,// 0x46 F
	0x3E, 0x41, 0x41, 0x51, 0x32,// 0x47 G
	0x7F, 0x08, 0x08, 0x08, 0x7F,// 0x48 H
	0x41, 0x7F, 0x41, IgnP, IgnP,// 0x49 I
	0x20, 0x40, 0x41, 0x3F, 0x01,// 0x4A J
	0x7F, 0x08, 0x14, 0x22, 0x41,// 0x4B K
	0x7F, 0x40, 0x40, 0x40, 0x40,// 0x4C L
	0x7F, 0x02, 0x04, 0x02, 0x7F,// 0x4D M
	0x7F, 0x04, 0x08, 0x10, 0x7F,// 0x4E N
	0x3E, 0x41, 0x41, 0x41, 0x3E,// 0x4F O
	0x7F, 0x09, 0x09, 0x09, 0x06,// 0x50 P
	0x3E, 0x41, 0x51, 0x21, 0x5E,// 0x51 Q
	0x7F, 0x09, 0x19, 0x29, 0x46,// 0x52 R
	0x46, 0x49, 0x49, 0x49, 0x31,// 0x53 S
	0x01, 0x01, 0x7F, 0x01, 0x01,// 0x54 T
	0x3F, 0x40, 0x40, 0x40, 0x3F,// 0x55 U
	0x1F, 0x20, 0x40, 0x20, 0x1F,// 0x56 V
	0x7F, 0x20, 0x18, 0x20, 0x7F,// 0x57 W
	0x63, 0x14, 0x08, 0x14, 0x63,// 0x58 X
	0x03, 0x04, 0x78, 0x04, 0x03,// 0x59 Y
	0x61, 0x51, 0x49, 0x45, 0x43,// 0x5A Z
	0x7F, 0x41, 0x41, IgnP, IgnP,// 0x5B [
	0x02, 0x04, 0x08, 0x10, 0x20,// 0x5C "\"
	0x41, 0x41, 0x7F, IgnP, IgnP,// 0x5D ]
	0x04, 0x02, 0x01, 0x02, 0x04,// 0x5E ^
	0x40, 0x40, 0x40, 0x40, 0x40,// 0x5F _
	0x01, 0x02, 0x04, IgnP, IgnP,// 0x60 `
	0x20, 0x54, 0x54, 0x54, 0x78,// 0x61 a
	0x7F, 0x48, 0x44, 0x44, 0x38,// 0x62 b
	0x38, 0x44, 0x44, 0x44, 0x20,// 0x63 c
	0x38, 0x44, 0x44, 0x48, 0x7F,// 0x64 d
	0x38, 0x54, 0x54, 0x54, 0x18,// 0x65 e
	0x08, 0x7E, 0x09, 0x01, 0x02,// 0x66 f
	0x08, 0x14, 0x54, 0x54, 0x3C,// 0x67 g
	0x7F, 0x08, 0x04, 0x04, 0x78,// 0x68 h
	0x44, 0x7D, 0x40, IgnP, IgnP,// 0x69 i
	0x20, 0x40, 0x44, 0x3D, IgnP,// 0x6A j
	0x7F, 0x10, 0x28, 0x44, IgnP,// 0x6B k
	0x41, 0x7F, 0x40, IgnP, IgnP,// 0x6C l
	0x7C, 0x04, 0x18, 0x04, 0x78,// 0x6D m
	0x7C, 0x08, 0x04, 0x04, 0x78,// 0x6E n
	0x38, 0x44, 0x44, 0x44, 0x38,// 0x6F o
	0x7C, 0x14, 0x14, 0x14, 0x08,// 0x70 p
	0x08, 0x14, 0x14, 0x18, 0x7C,// 0x71 q
	0x7C, 0x08, 0x04, 0x04, 0x08,// 0x72 r
	0x48, 0x54, 0x54, 0x54, 0x20,// 0x73 s
	0x04, 0x3F, 0x44, 0x40, 0x20,// 0x74 t
	0x3C, 0x40, 0x40, 0x20, 0x7C,// 0x75 u
	0x1C, 0x20, 0x40, 0x20, 0x1C,// 0x76 v
	0x3C, 0x40, 0x30, 0x40, 0x3C,// 0x77 w
	0x44, 0x28, 0x10, 0x28, 0x44,// 0x78 x
	0x0C, 0x50, 0x50, 0x50, 0x3C,// 0x79 y
	0x44, 0x64, 0x54, 0x4C, 0x44,// 0x7A z
	0x08, 0x36, 0x41, IgnP, IgnP,// 0x7B {
	0x7F, IgnP, IgnP, IgnP, IgnP,// 0x7C |
	0x41, 0x36, 0x08, IgnP, IgnP,// 0x7D }
	0x08, 0x08, 0x2A, 0x1C, 0x08,// 0x7E ->
	0x08, 0x1C, 0x2A, 0x08, 0x08 // 0x7F <-
};
#endif

