//----------------------------------------------------------------
//
// OpenDCC
// Throttle MFT 1.0
//
// Copyright (c) 2008-2009 Jean Michel Fischer, Wolfgang Kufer
//
// This source file is subject of the GNU general public license 2,
// that is available at the world-wide-web at
// http://www.gnu.org/licenses/gpl.txt
//
// This code is initially based on:
// http://www.mikrocontroller.net/articles/AVR-GCC-Tutorial 
//
//-----------------------------------------------------------------
//
// file:      lcd_text.h
// author:    Wolfgang Kufer
// contact:   kufer@gmx.de
// webpage:   http://www.opendcc.de
// history:   2008-09-18 V0.01 jmf started
//            2009-01-13 V0.01 kw  comments, tests
//            2009-03-07 V0.04 kw  get_cursor neu dazu
//            2009-08-07 V0.05 kw  lcdhex extended
//
//-----------------------------------------------------------------
//
// purpose:   control of a char lcd display
//            supported controllers: KS0073
//            either spi oder 4 bit parallel
//
//-----------------------------------------------------------------

#ifndef _LCD_TEXT_H_
#define _LCD_TEXT_H_

#include "lcd_driver_st7565.h"

#include <stdlib.h>



//-----------------------------------------------------------------------------
// Highlevel routines:

typedef struct
  {
    unsigned char x;         // col, range 0..19
    unsigned char y;         // row, range 0..3
    unsigned char string[];
  }
  t_text;


void lcd_init(void);
void lcd_home(void);
void lcd_clear(void);


void set_cursor(uint8_t x, uint8_t y);
void get_cursor(uint8_t* x, uint8_t* y);

void cursor_on(void);
void cursor_on_at(uint8_t x, uint8_t y, uint8_t size);
void cursor_blink(void);
void cursor_off(void);

void lcd_putc(char data);                           // puts data at cursor position
void lcd_putc_cnt(unsigned char count, char data);  // puts count data at cursor position
void lcd_blank(unsigned char toblank);              // puts blanks at cursor position

void lcd_string_P(const char *progmem_data);        // print string from Progmem at current pos.
void lcd_string(char *data);                        // print string  at current pos.

void lcd_int(int data);
void lcd_int2(int data);
void lcd_int02(int data);
void lcd_int3(int data);                            // print int, 3 chars wide, leading blank
void lcd_int4(int data);
void lcd_int04(int data);
void lcd_int5(int data);

void lcd_hex2(uint8_t data);
void lcd_hex4(uint16_t data);
void lcd_hex8(uint32_t data);

void lcd_bool(unsigned char data);                  // display a single logic bin at cursor position.



#endif /* LCD_TEXT_H_ */
