//------------------------------------------------------------------------
//
// OpenDCC - LED Controller
//
// Copyright (c) 2008 Kufer
//
// This source file is subject of the GNU general public license 2,
// that is available at the world-wide-web at
// http://www.gnu.org/licenses/gpl.txt
// 
//------------------------------------------------------------------------
//
// file:      led.h
// author:    Wolfgang Kufer
// contact:   kufer@gmx.de
// webpage:   http://www.opendcc.de
// history:   2008-09-23 V0.01 kw started
//            2010-07-30 V0.02 kw led_orange added
//
//------------------------------------------------------------------------
//
// purpose:   LED Control
//
//------------------------------------------------------------------------
//
// interface: 1. call init_knob();
//            2. whenever the knob is rotated, a keystroke is issued
//            3. the calling program must ask get_knob_rotate() to
//               receive the actual rotation - this value may be zero,
//               even if a knob_keystroke was issued!
//               get_knob_rotate() returns the sum of rotation steps.
//------------------------------------------------------------------------
//
#ifndef _LED_H_
#define _LED_H_

#define NUM_OF_LED  5
#define LED_A       0
#define LED_B       1
#define LED_C       2
#define LED_D       3
#define LED_STOP    4


#define LED_TICK_PERIOD  20000L 
#if ((LED_TICK_PERIOD / SYSTICK_PERIOD) == 0)
  #error: LED_TICK_PERIOD too small!
#endif

typedef enum
  {
    LED_COLOR_OFF   = 0x00,     // off
    LED_COLOR_RED   = 0x01,     // red
    LED_COLOR_GREEN = 0x02,     // green
  } t_led_color;


extern void init_led(void);                 // call at power up

extern signed int run_led(void);                  // call every LED_TICK


/// set_global_bright(unsigned char bright)
//  sets the overall brightness
//  parameter:  bright: 0..100;  100=fully on
extern void set_global_bright(unsigned char bright);

extern unsigned char get_global_bright(void);

void save_brightness(void);

void restore_brightness(t_power_mode power_mode);

void set_led_brightness(unsigned char value);  // 0..100
void set_disp_brightness(unsigned char value);  // 0..100



// LED access

void blink_led_red_fast(unsigned char led_enum);
void blink_led_red_soft(unsigned char led_enum);

void blink_led_green_fast(unsigned char led_enum);
void blink_led_green_soft(unsigned char led_enum);

void blink_led_red_green(unsigned char led_enum);

void turn_led_off(unsigned char led_enum);
void turn_led_off_soft(unsigned char led_enum);
void turn_led_red_soft(unsigned char led_enum);
void turn_led_green_soft(unsigned char led_enum);
void turn_led_red_immediate(unsigned char led_enum);
void turn_led_green_immediate(unsigned char led_enum);

void led_orange(unsigned char led_enum);




// debug only
extern void advance_bootloader_led(void);   // tiny shifter

#endif


