//----------------------------------------------------------------
//
// OpenDCC
// Throttle MFT 1.0
//
// Copyright (c) 2009, 2010 Wolfgang Kufer
//
// This source file is subject of the GNU general public license 3,
// that is available at the world-wide-web at
// http://www.gnu.org/licenses/gpl.txt
//
//
//-----------------------------------------------------------------
//
// file:      lok_graphic.c
// author:    Wolfgang Kufer
// contact:   kufer@gmx.de
// webpage:   http://www.opendcc.de
// history:   2008-09-18 V0.01 kw  started
//            2010-04-27 V0.02 kw  some loco added
//            2011-04-01 V0.03 kw  locos added
//
//-----------------------------------------------------------------
//
// purpose:   select and display a graphic image
//
// Interface: downstream: we use lcd_driver_
//
//-----------------------------------------------------------------

#include <avr/io.h>
#include <avr/interrupt.h>
#include <avr/pgmspace.h>        // put var to program memory
#include <util/delay.h>
#include <stdio.h>

#include "config.h"
#include "cortos.h"
#include "hardware.h"           // CS for SPI

#include "lcd_ks0073_charset.h"
#include "display.h"

#include "lcd_driver_ks0073.h"
#include "lcd_driver_st7565.h"

//#include <avr/interrupt.h>

uint8_t cursor_x;
uint8_t cursor_y;




#if (DISPLAY == LCD_EA204)

void LCD_lok_picture(unsigned int id)
  {
  }


#elif  (DISPLAY == LCD_EA128x64)

//------------------------------------------------------------------------------------
//
// Picture includes
// Warning: This is limited to the first 64k of flash!
//          PGM_VOID_P is only a 16 bit value, so more than 64k is not accessible!
//
//------------------------------------------------------------------------------------

    #include "lokbmp/no_picture_glcd.h"
    #include "lokbmp/ID1000_glcd.h"     //  default
    #include "lokbmp/ID1001_glcd.h"     //  BBII
    #include "lokbmp/ID1002_glcd.h"     //s KI
    #include "lokbmp/ID1003_glcd.h"     //s Trusetal
    #include "lokbmp/ID1004_glcd.h"     //s IVK Reko
    #include "lokbmp/ID1005_glcd.h"     //s VIIK 
    #include "lokbmp/ID1006_glcd.h"     //s VIK (saechs.)
    #include "lokbmp/ID1007_glcd.h"     //  BR96
    #include "lokbmp/ID1008_glcd.h"     //  Gt4/4
    #include "lokbmp/ID1009_glcd.h"     //s  saechs IIIK
    #include "lokbmp/ID100A_glcd.h"     //s  saechs IIK neu
    #include "lokbmp/ID100B_glcd.h"     //s  saechs IIK alt
    #include "lokbmp/ID100C_glcd.h"     //s  saechs VK
    #include "lokbmp/ID100D_glcd.h"     //s  HF110C
    #include "lokbmp/ID100E_glcd.h"     //s  Spreewaldlok
    #include "lokbmp/ID100F_glcd.h"     //s  Uh
    #include "lokbmp/ID1010_glcd.h"     //s  BR73
    #include "lokbmp/ID1011_glcd.h"     // 
    #include "lokbmp/ID1012_glcd.h"     // 
    #include "lokbmp/ID1013_glcd.h"     //b    DXI
    #include "lokbmp/ID1014_glcd.h"     //b    Gtl 4/4
    #include "lokbmp/ID1015_glcd.h"     //     Shy
    #include "lokbmp/ID1016_glcd.h"     //     BR81
#if (PICS_INCLUDED_UK)
    #include "lokbmp/ID1017_glcd.h"     //UK   0-4-0T
    #include "lokbmp/ID1018_glcd.h"     //UK   0-6-0T
    #include "lokbmp/ID1019_glcd.h"     //UK   0-4-0ST
#endif


    #include "lokbmp/ID2000_glcd.h"     //  default
    #include "lokbmp/ID2001_glcd.h"     //  1-4-1
    #include "lokbmp/ID2002_glcd.h"     //s Mh6
    #include "lokbmp/ID2003_glcd.h"     //  BR01
    #include "lokbmp/ID2004_glcd.h"     //  S3/6
    #include "lokbmp/ID2005_glcd.h"     //s BR994652
    #include "lokbmp/ID2006_glcd.h"     //
    #include "lokbmp/ID2007_glcd.h"     //
    #include "lokbmp/ID2008_glcd.h"     //  P8 (BR38)
#if (PICS_INCLUDED_UK)
    #include "lokbmp/ID2009_glcd.h"     // A4 PACIFIC
    #include "lokbmp/ID200A_glcd.h"     // BRITANNIA
    #include "lokbmp/ID200B_glcd.h"     // 4-6-2 
    #include "lokbmp/ID200C_glcd.h"     // CORONATION
#endif


    #include "lokbmp/ID3000_glcd.h"     //  Typbild
    #include "lokbmp/ID3001_glcd.h"     //  V200
    #include "lokbmp/ID3002_glcd.h"     //  Am843 Trudy / Sersa
    #include "lokbmp/ID3003_glcd.h"     //  BR290
    #include "lokbmp/ID3004_glcd.h"     //  BR294
    #include "lokbmp/ID3005_glcd.h"     //  BR218 hell
    #include "lokbmp/ID3006_glcd.h"     //s BR199030
    #include "lokbmp/ID3007_glcd.h"     //s HF130C
    #include "lokbmp/ID3008_glcd.h"     //  V100
#if (PICS_INCLUDED_UK)
    #include "lokbmp/ID3009_glcd.h"     //UK   CLASS42
    #include "lokbmp/ID300A_glcd.h"     //UK   DELTIC
    #include "lokbmp/ID300B_glcd.h"     //UK   CLASS37
    #include "lokbmp/ID300C_glcd.h"     //UK   PEAK
    #include "lokbmp/ID3010_glcd.h"     //UK   CLASS47
    #include "lokbmp/ID3011_glcd.h"     //UK   WARSHIP
    #include "lokbmp/ID3012_glcd.h"     //UK   CLASS04
    #include "lokbmp/ID3013_glcd.h"     //UK   CLASS20
    #include "lokbmp/ID3014_glcd.h"     //UK   CLASS58
#endif

    #include "lokbmp/ID4000_glcd.h"     // Typbild
    #include "lokbmp/ID4001_glcd.h"     // RhB Krokodil
    #include "lokbmp/ID4002_glcd.h"     // E94
    #include "lokbmp/ID4003_glcd.h"     // Re460
    #include "lokbmp/ID4004_glcd.h"     // E103
    #include "lokbmp/ID4005_glcd.h"     // Taurus hell
    #include "lokbmp/ID4006_glcd.h"     // Taurus mittel
    #include "lokbmp/ID4007_glcd.h"     // Ce6/8
    #include "lokbmp/ID4008_glcd.h"     // Ep3/6
    #include "lokbmp/ID4009_glcd.h"     // BR111 ocean/beige
#if (PICS_INCLUDED_UK)
    #include "lokbmp/ID4010_glcd.h"     // CLASS 8X
    #include "lokbmp/ID4011_glcd.h"     // CLASS73
#endif

    #include "lokbmp/ID5000_glcd.h"     // Typbild
    #include "lokbmp/ID5001_glcd.h"     // TGV
    #include "lokbmp/ID5002_glcd.h"     // ICE
    #include "lokbmp/ID5003_glcd.h"     // Et423
#if (PICS_INCLUDED_UK)
    #include "lokbmp/ID5004_glcd.h"     // CLASS91
#endif

    #include "lokbmp/ID6000_glcd.h"     // Typbild
    #include "lokbmp/ID6001_glcd.h"     // VT98
    #include "lokbmp/ID6002_glcd.h"     // Lint
    #include "lokbmp/ID6003_glcd.h"     // Wismarer Schienenbus
    #include "lokbmp/ID6004_glcd.h"     // VT628
    #include "lokbmp/ID6005_glcd.h"     // Lint
#if (PICS_INCLUDED_UK)
    #include "lokbmp/ID6006_glcd.h"     // HST
#endif


#include "lokbmp/ID7001_glcd.h"     // 4-Achser P
#include "lokbmp/ID7002_glcd.h"     // Silberling Steuerwagen

#include "lokbmp/ID8001_glcd.h"     // Rottenkraftwagen
#include "lokbmp/ID8002_glcd.h"     // Tram

#include "lokbmp/ID9000_glcd.h"     // Typbild
#include "lokbmp/ID9001_glcd.h"     // Containerkran
#include "lokbmp/ID9002_glcd.h"     // Containerkran
#include "lokbmp/ID9003_glcd.h"     // Containerkran
#include "lokbmp/ID9004_glcd.h"     // Containerkran
#include "lokbmp/ID9005_glcd.h"     // Bockkran
#include "lokbmp/ID9006_glcd.h"     // Bockkran





const struct 
  {
    unsigned int id;
    const unsigned char * bitmap;
  } flash_lokbmp[] PROGMEM =
  {
    { 0x0000, no_picture_glcd_bmp },    // id must be in ascending order (scan)
    { 0x1000, id1000_glcd_bmp },
    { 0x1001, id1001_glcd_bmp },
    { 0x1002, id1002_glcd_bmp },
    { 0x1003, id1003_glcd_bmp },
    { 0x1004, id1004_glcd_bmp },
    { 0x1005, id1005_glcd_bmp },
    { 0x1006, id1006_glcd_bmp },
    { 0x1007, id1007_glcd_bmp },
    { 0x1008, id1008_glcd_bmp },
    { 0x1009, id1009_glcd_bmp },
    { 0x100a, id100a_glcd_bmp },
    { 0x100b, id100b_glcd_bmp },
    { 0x100c, id100c_glcd_bmp },
    { 0x100d, id100d_glcd_bmp },
    { 0x100e, id100e_glcd_bmp },
    { 0x100f, id100f_glcd_bmp },
    { 0x1010, id1010_glcd_bmp },
    { 0x1011, id1011_glcd_bmp },
    { 0x1012, id1012_glcd_bmp },
    { 0x1013, id1013_glcd_bmp },
    { 0x1014, id1014_glcd_bmp },
    { 0x1015, id1015_glcd_bmp },
    { 0x1016, id1016_glcd_bmp },
    #if (PICS_INCLUDED_UK)
    { 0x1017, id1017_glcd_bmp },
    { 0x1018, id1018_glcd_bmp },
    { 0x1019, id1019_glcd_bmp },
    #endif

    { 0x2000, id2000_glcd_bmp },
    { 0x2001, id2001_glcd_bmp },
    { 0x2002, id2002_glcd_bmp },
    { 0x2003, id2003_glcd_bmp },
    { 0x2004, id2004_glcd_bmp },
    { 0x2005, id2005_glcd_bmp },
    { 0x2006, id2006_glcd_bmp },
    { 0x2007, id2007_glcd_bmp },
    { 0x2008, id2008_glcd_bmp },
    #if (PICS_INCLUDED_UK)
    { 0x2009, id2009_glcd_bmp },
    { 0x200A, id200a_glcd_bmp },
    { 0x200B, id200b_glcd_bmp },
    { 0x200C, id200c_glcd_bmp },
    #endif


    { 0x3000, id3000_glcd_bmp },
    { 0x3001, id3001_glcd_bmp },
    { 0x3002, id3002_glcd_bmp },
    { 0x3003, id3003_glcd_bmp },
    { 0x3004, id3004_glcd_bmp },
    { 0x3005, id3005_glcd_bmp },
    { 0x3006, id3006_glcd_bmp },
    { 0x3007, id3007_glcd_bmp },
    { 0x3008, id3008_glcd_bmp },
    #if (PICS_INCLUDED_UK)
    { 0x3009, id3009_glcd_bmp },
    { 0x300A, id300a_glcd_bmp },
    { 0x300B, id300b_glcd_bmp },
    { 0x300C, id300c_glcd_bmp },
    { 0x3010, id3010_glcd_bmp },
    { 0x3011, id3011_glcd_bmp },
    { 0x3012, id3012_glcd_bmp },
    { 0x3013, id3013_glcd_bmp },
    { 0x3014, id3014_glcd_bmp },
    #endif


    { 0x4000, id4000_glcd_bmp },
    { 0x4001, id4001_glcd_bmp },
    { 0x4002, id4002_glcd_bmp },
    { 0x4003, id4003_glcd_bmp },
    { 0x4004, id4004_glcd_bmp },
    { 0x4005, id4005_glcd_bmp },
    { 0x4006, id4006_glcd_bmp },
    { 0x4007, id4007_glcd_bmp },
    { 0x4008, id4008_glcd_bmp },
    { 0x4009, id4009_glcd_bmp },
    #if (PICS_INCLUDED_UK)
    { 0x4010, id4010_glcd_bmp },
    { 0x4011, id4011_glcd_bmp },
    #endif

    { 0x5000, id5000_glcd_bmp },
    { 0x5001, id5001_glcd_bmp },
    { 0x5002, id5002_glcd_bmp },
    { 0x5003, id5003_glcd_bmp },
    #if (PICS_INCLUDED_UK)
    { 0x5004, id5004_glcd_bmp },
    #endif



    { 0x6000, id6000_glcd_bmp },
    { 0x6001, id6001_glcd_bmp },
    { 0x6002, id6002_glcd_bmp },
    { 0x6003, id6003_glcd_bmp },
    { 0x6004, id6004_glcd_bmp },
    { 0x6005, id6005_glcd_bmp },
    #if (PICS_INCLUDED_UK)
    { 0x6006, id6006_glcd_bmp },
    #endif
    
    { 0x7001, id7001_glcd_bmp },
    { 0x7002, id7002_glcd_bmp },
    
    { 0x8001, id8001_glcd_bmp },
    { 0x8002, id8002_glcd_bmp },

    { 0x9001, id9000_glcd_bmp },
    { 0x9001, id9001_glcd_bmp },
    { 0x9002, id9002_glcd_bmp },
    { 0x9003, id9003_glcd_bmp },
    { 0x9004, id9004_glcd_bmp },
    { 0x9005, id9005_glcd_bmp },
    { 0x9006, id9006_glcd_bmp },
    // 0xFFFF reserved
  };


PGM_VOID_P get_picture_pgm(unsigned int id)
  {
    unsigned int i;
    for (i=0; i<sizeof(flash_lokbmp)/sizeof(flash_lokbmp[0]); i++)
      {
        if (pgm_read_word(&flash_lokbmp[i].id) == id)
          {
            return ((PGM_VOID_P) pgm_read_word(&flash_lokbmp[i].bitmap));  // short, only 16bit!
          }
      }
    return(no_picture_glcd_bmp);  // not found
  }

static const char text_no_pic[]  PROGMEM = "No Picture";

void LCD_loc_picture(unsigned int id)
  {
    //!warning scan eeprom

    PGM_VOID_P my_pic;
    if ( (my_pic = get_picture_pgm(id)) )
      {
        LCD_drawBMP_aligned(my_pic, 64 /* width */, 3 /* height */);
        return;
      }
  }

unsigned int scan_picture_forward(unsigned int id)
  {
    unsigned int i;
    for (i=0; i<sizeof(flash_lokbmp)/sizeof(flash_lokbmp[0]); i++)
      {
        if (pgm_read_word(&flash_lokbmp[i].id) > id)
          {
            return (pgm_read_word(&flash_lokbmp[i].id));
          }
      }
    return(0xFFFF);  // not found
  }


unsigned int scan_picture_revers(unsigned int id)
  {
    unsigned int i;
    for (i=sizeof(flash_lokbmp)/sizeof(flash_lokbmp[0]) - 1; i>0; i--)
      {
        if (pgm_read_word(&flash_lokbmp[i].id) < id)
          {
            return (pgm_read_word(&flash_lokbmp[i].id));
          }
      }
    return(0x0000);  // not found
  }


#endif // (DISPLAY == LCD_EA204)



