//------------------------------------------------------------------------
//
// OpenDCC - Test Programm for Throttle
//
// Copyright (c) 2008 Kufer
//
// This source file is subject of the GNU general public license 2,
// that is available at the world-wide-web at
// http://www.gnu.org/licenses/gpl.txt
// 
//------------------------------------------------------------------------
//
// file:      timer.h
// author:    Wolfgang Kufer
// contact:   kufer@gmx.de
// webpage:   http://www.opendcc.de
// history:   2008-12-12 V0.1 kw started
//
//------------------------------------------------------------------------
//
// purpose:   simmle test program for throttle
//
//------------------------------------------------------------------------
//
#define T0_PRESCALER   8

#define T2_PRESCALER   64

#define SYSTICK_6US_FREQ    (F_CPU / T2_PRESCALER)
#define SYSTICK_6US_PERIOD  (1000000L / SYSTICK_6US_FREQ) 
#define SYSTICK_PERIOD      (256 * 1000000L / SYSTICK_6US_FREQ)        // 1638L
#define SYSTICK_10MS_PERIOD (SYSTICK_PERIOD * 6)

//------------------------------------------------------------------------
// Implementation of a delay (with coop RTOS):
// Do not use _delay_ms from the avr-libs, since these routines just
// burn cpu cycles and will be prolonged by intermediate interrupts.
// The following implementation will be independant from intermediate interrupts.
// 
// 1. large delays      max. range: 320s
//                      resolution: 10ms
//    example:
//      static signed int my_systick_10ms;
//      my_systick_10ms = get_systick_10ms();  // atomic!
//      while ((get_systick_10ms() - my_systick_10ms) <= MY_TIME / SYSTICK_10MS_PERIOD)
//      return;
//  
// 2. medium delays     max. range:   51s
//                      resolution: 1,6ms
//    example:
//      static int my_systick;
//      my_systick = get_systick_int();  // atomic!
//      while ((signed char)(systick - my_systick) <= MY_TIME / SYSTICK_PERIOD);
//      return;
//      (recommended method, matches the resolution of CORTOS)
// 
// 3. small delays      max. range: 200ms
//                      resolution: 6us 
//    example:
//      static signed int my_systick;
//      my_systick = get_systick_us();
//      while ((get_systick_us() - my_systick) <= MY_TIME / SYSTICK_6US_PERIOD) ;
//      return;
//      (more code, 
//       MY_TIME * SYSTICK_6US_FREQ / 1000000L gives better resolution,
//       but be aware of intermediate overflows when calcating the compare value;
//      )
//
// 4. small delays      max. range: 200ms
//                      resolution: 1,6ms
//    example:
//      static signed char my_systick;
//      my_systick = systick;
//      while ((signed char)(systick - my_systick) <= MY_TIME / SYSTICK_PERIOD);
//      return;
//      (small code, but only byte range)
// 

// extern volatile signed char systick;
// extern volatile signed int systick_10ms;  // only atomic access

signed char get_systick(void);            // 1.6ms resolution, range 200ms

signed int get_systick_us(void);          // 6us resolution, range 200ms

signed int get_systick_int(void);         // 1.6ms resolution, range 50sec

signed int get_systick_10ms(void);

void init_timer(void);
// void run_timer(void);   // to be called as often as possible

