//==============================================================================
//
// OpenDCC - WRP for MFT / Gateway
//
// Copyright (c) 2006-2008 Wolfgang Kufer
//
// This source file is subject of the GNU general public license 2,
// that is available at the world-wide-web at
// http://www.gnu.org/licenses/gpl.txt
//
//------------------------------------------------------------------------------
//
// file:      wrp.h
// author:    Wolfgang Kufer
// contact:   kufer@gmx.de
// history:   2009-07-10 V0.01 kw  start
//            2010-06-06 V0.05 kw  added LOC FUNCT
//            2010-06-24 V0.06 kw  added LOC CONTROL, added A_WATCH
//            2010-07-25 V0.07 kw  added FEEDBACK enums 
//            2010-07-28 V0.08 kw  added DEBUG Modes                                                     
//            2010-08-02 V0.09 kw  added FSUBSCRIBE                                                  
//
//------------------------------------------------------------------------------
//
// purpose:   model railway - a versatile protocol for wireless communication
//
// content:   WRP - WIRELESS RAILROAD PROTOCOL
//            here: typedefs and enums
//            please refer to www.opendcc.de for more details
//
// to do:     
//
//==============================================================================
//
// WRP consists of:
//
//   header     (1 Byte, holds length (0..127 and a Master Bit)
//   type       (4 Bit, type of message)
//   opcode     (4 Bit, sub-type)
//   addr       (16 bit, holds the main parameter)
//   data[64]   (64 Bytes, parameters for this message)
//
//==============================================================================

#ifndef _WRP_H_
#define _WRP_H_

// Defines for WRP

#define WRP_VERSION         0       // this is the main version index
#define WRP_SUBVERSION      9       // sub index


typedef enum
  {
    WRP_TYPE_STATE            = 0x01,
    WRP_TYPE_LOCO             = 0x02,
    WRP_TYPE_ACCESSORY        = 0x03,
    WRP_TYPE_FEEDBACK         = 0x04,
    WRP_TYPE_PROG             = 0x05,
    WRP_TYPE_CLOCK            = 0x0D,
    WRP_TYPE_SYSTEM           = 0x0E,
    WRP_TYPE_DEBUG            = 0x0F,
  } wrp_type_t;

typedef enum
  {
    WRP_OPCODE_OFF               = 0x00,
    WRP_OPCODE_STOP              = 0x01,
    WRP_OPCODE_SOFT_STOP         = 0x02,
    WRP_OPCODE_GO                = 0x03,
    // busy,
    WRP_OPCODE_PROGMODE          = 0x08,
    WRP_OPCODE_PROGBUSY          = 0x09,
    WRP_OPCODE_BUSY              = 0x0D,
    WRP_OPCODE_DISCONNECTED      = 0x0E,
    WRP_OPCODE_SQUERY            = 0x0F,
  } wrp_oc_state_t;

typedef enum
  {
    WRP_OPCODE_ESTOP             = 0x00,
    WRP_OPCODE_CONTROL           = 0x01,
    WRP_OPCODE_DRIVE             = 0x02,
    WRP_OPCODE_LQUERY	         = 0x04,
    WRP_OPCODE_LSTOLEN	         = 0x05,
    WRP_OPCODE_LERROR	         = 0x06,
    WRP_OPCODE_LRESERVE          = 0x08,
    WRP_OPCODE_LFREE             = 0x09,
    WRP_OPCODE_LOCATE	         = 0x0F,
  } wrp_oc_loco_t;

typedef enum
  {
    WRP_OPCODE_A_QUERY           = 0x00,
    WRP_OPCODE_A_SET             = 0x01,
    WRP_OPCODE_A_RESET	         = 0x02,
    WRP_OPCODE_A_POSIT	         = 0x03,
    WRP_OPCODE_A_WATCH           = 0x04,
    WRP_OPCODE_A_UNWATCH         = 0x05,
    WRP_OPCODE_XA_SET            = 0x08,   // set extended Accesory
    WRP_OPCODE_XA_POSIT          = 0x09,   // show extended Accesory
    WRP_OPCODE_XA_QUERY          = 0x0A,   // query extended Accesory
  } wrp_oc_accessory_t;

typedef enum
  {
    WRP_OPCODE_FEVENT            = 0x00,
    WRP_OPCODE_FBITS8            = 0x01,
    WRP_OPCODE_FBIDI             = 0x02,
    WRP_OPCODE_FCONFIG           = 0x03,
    WRP_OPCODE_FQUERY1           = 0x08,
    WRP_OPCODE_FQUERY8           = 0x09,
    WRP_OPCODE_FSUBSCRIBE        = 0x0A,
    WRP_OPCODE_FQBIDI            = 0x0B,
    WRP_OPCODE_FQCONFIG          = 0x0C,
  } wrp_oc_feedback_t;

typedef enum
  {
    WRP_OPCODE_PROG_STAT         = 0x00,      
    WRP_OPCODE_RDCV	             = 0x01,  
    WRP_OPCODE_WRCV	             = 0x02,
    WRP_OPCODE_POM_RDCV	         = 0x03,
    WRP_OPCODE_POM_WRCV 	     = 0x04,
    WRP_OPCODE_PAC_RDCV	         = 0x05,
    WRP_OPCODE_PAC_WRCV 	     = 0x06,
    WRP_OPCODE_PEX_RDCV	         = 0x07,
    WRP_OPCODE_PEX_WRCV	         = 0x08,
    WRP_OPCODE_PQUERY            = 0x0E,    
    WRP_OPCODE_POM_QUERY         = 0x0F,    
  } wrp_oc_prog_t;

typedef enum
  {
    WRP_OPCODE_CLKOFF            = 0x00,
    WRP_OPCODE_CLKON             = 0x01,
    WRP_OPCODE_CLKSET            = 0x02,
    WRP_OPCODE_CLKQRY            = 0x03,
  } wrp_oc_clock_t;

typedef enum
  {
    WRP_OPCODE_IDLE              = 0x00,
    WRP_OPCODE_SILENT            = 0x01,
    WRP_OPCODE_APPLY             = 0x02,
    WRP_OPCODE_GRANTED           = 0x03,
    WRP_OPCODE_CONNECT           = 0x04,
    WRP_OPCODE_SYSINFO           = 0x06,
    WRP_OPCODE_SYSQUERY          = 0x07,
    WRP_OPCODE_PICTURE           = 0x08,
    WRP_OPCODE_LOCO_DB           = 0x09,
    WRP_OPCODE_CS_CV_QRY         = 0x0E,
    WRP_OPCODE_CS_CV_SET         = 0x0F,
  } wrp_oc_system_t;

typedef enum
  {
    WRP_OPCODE_PING              = 0x00,
    WRP_OPCODE_ANNOUNCE          = 0x01,
    WRP_OPCODE_FIRMWARE          = 0x02,
    WRP_OPCODE_DISPLAY           = 0x0D,
    WRP_OPCODE_LED               = 0x0E,
    WRP_OPCODE_KEYBOARD          = 0x0F,
  } wrp_oc_debug_t;

//--------------------------------------------------------------

typedef enum
  {
    WRP_DCC14                    = 0x00,
    WRP_DCC27                    = 0x01,
    WRP_DCC28                    = 0x02,
    WRP_DCC128                   = 0x03,
  } wrp_format_t;

// define structure to help decoding (general)
typedef struct {
    uint8_t header:8;
    wrp_type_t type:4;
    uint8_t opcode:4;
    uint16_t addr;
    uint8_t data[64];
} __attribute__ ((__packed__)) wrp_pkt_t;


// define structure to help decoding (loco bitfield)
typedef union
  {
    struct {
            uint8_t occupied:1;
            uint8_t reserver3_1: 3;
            wrp_format_t format: 3;
            uint8_t dir: 1;
           };
    uint8_t as_byte;      
  }
  __attribute__ ((__packed__)) wrp_loco_bits_t;


#endif // _WRP_H_
