////========================================================================
//
// OpenDCC - MFT / Gateway
//
// Copyright (c) 2009 Wolfgang Kufer
//
// This source file is subject of the GNU general public license 2,
// that is available at the world-wide-web at
// http://www.gnu.org/licenses/gpl.txt
//
//------------------------------------------------------------------------
//
// file:      xbee_if.h
// author:    Wolfgang Kufer
// contact:   kufer@gmx.de
// history:   2009-07-10 V0.01 kw start
//            2010-08-06 V0.02 kw added xbee_hw_version
//            2010-08-14 V0.03 kw added xbee_rssi
//
//------------------------------------------------------------------------
//
// purpose:   central station for dcc - client for xbee modules
//
// content:   collector for incoming byte
//            packetizing
//            packet decoding
//
// note:      xbee uses big endian for length, we are little endian
//            ntohs is done send and receive routines
// to do:
//
//========================================================================

#ifndef _XBEE_IF_H_
#define _XBEE_IF_H_

//========================================================================
#define MASTER   1
#define CLIENT   2

#define XBEE_IF    MASTER   // CLIENT or MASTER

//========================================================================
#define STANDARD64  1
#define ZB_MODE     2

#define XBEE_MODE    ZB_MODE // STANDARD64  // ZB_MODE = use ZigBEE commands (series2 only)
                                            // STANDARD64 = use 802.15.4 commands (series1 only)

//========================================================================

#include "xbee_protocol.h"
#include "wrp.h"

//------------------------------------------------------------------------
//
//  0. GLOBALS
//
//------------------------------------------------------------------------

extern uint8_t xbee_module_detected;        // TRUE if we have a module
extern uint8_t xbee_error;                  // error number
extern uint8_t  xbee_ai_state;

extern uint16_t pan_id;                     // the PAN of the network (should be 0x1310)
extern uint8_t  xbee_channel;               // the Channel we are operation on (read only)
extern uint8_t  xbee_rssi;                  // Signal strength on last receive (given in dBm *-1)
extern uint16_t xbee_short;                 // Local Adress, Coordinator is 0x0000

extern uint16_t xbee_hw_version;            // firmware version of module
extern uint16_t xbee_fw_version;            // firmware version of module
extern uint32_t xbee_serial_high;           // our serial number, high bits
extern uint32_t xbee_serial_low;            // low bits.


extern uint8_t base_station_mac[8];         // when ever we send something - this is our host
                                            // 00 00 00 00 00 00 FF FF -> broad cast


typedef enum
  {
    XBEE_DISCONNECTED             = 0x00,   // any error - 
    XBEE_VOID                     = 0x01,  
    XBEE_COORDINATOR              = 0x02,
    XBEE_ENDPOINT                 = 0x03,   // joined
    XBEE_RUNNING                  = 0x04,   // joined and agreed
  } xbee_connect_t;

xbee_connect_t xbee_connect;


// --------------------------------------------------------------------------------  data

typedef struct 
  {
    uint8_t     message_size; // size for next message
    uint8_t     message[XBEE_MAX_DATA_LEN];

  } payload_t;

extern payload_t payload;


// -----------------------------------------------------------------------  task & control

void set_xbee_state(xbee_connect_t neu);

uint8_t detect_xbee_module(void);     

void restart_xbee(void);

t_cr_task init_xbee(void);

t_cr_task run_xbee_client(void);


//------------------------------------------------------------------------
//  TX Interface
//

void xb_make_at_command(uint16_t at_command);

// create a api message with 0x10 (payload is of type model railway)
// void xb_make_message_to_host(wrp_pkt_t *payload);

// this sends the accumulated payload to the host (as ZB_TX-Paket)
void xb_send_payload_to_host(void);

// send_xbee_message puts a prepared message in xbee_tx to output fifo
// (busy waiting if fifo is getting full)
void send_xbee_message(void);

#endif // _XBEE_IF_H_
