//========================================================================
//
// OpenDCC
//
// Copyright (c) 2008 Wolfgang Kufer
//
// This source file is subject of the GNU general public license 2,
// that is available at the world-wide-web at
// http://www.gnu.org/licenses/gpl.txt
//
//------------------------------------------------------------------------
//
// file:      xp_client_hardware
// author:    Wolfgang Kufer
// contact:   kufer@gmx.de
// history:   2008-09-20 V0.01 kw  first version
//            2009-02-12 V0.02 kw  added definition for MFT
//
//------------------------------------------------------------------------
// If you want to use the xp_client:
//  --> please add your board definition below
//
//========================================================================
// here we define the used hardware resources:
//
//   a) UART:   may be the only UART, UART0 or UART1, see below and header
//   b) TIMER:  this must run at something between 0.2us to 2us.
//              The timer must run in wrap around mode, we use OCR
//              and the corresponding compare interrupt
//              (preferred TIMER0 or TIMER2)
//   c) PORT:   a port, which controls the direction setting.
//              This port must be initialized as output
//
//========================================================================

#ifndef __XP_CLIENT_HARDWARE_H__
#define __XP_CLIENT_HARDWARE_H__

//=============================================================================
// Used Hardware
//----------------------------------------------------------------------------

#define UART   1
#define UART0  2                    // define some numbers (!=0)
#define UART1  3

#define TIMER0 10                   // define some numbers (!=0)
#define TIMER2 11 


#ifndef BOARD
 #warning SEVERE Warning - please define a BOARD
 #warning see xp_client_if.c for explanations
 // use following statements in your config.h
 // #define BOARD_my_new_hardware 5
 // #define BOARD BOARD_my_new_hardware
#else

    // OpenDCC Command Station,
    // Port USART1
    #if (BOARD == BOARD_OPENDCC)
        #define XPRESSNET_UART             UART1                   // may be UART, UART0 or UART1
        #define HARDWARE_SET_XP_RECEIVE    PORTB &= ~(1 << PB5)
        #define HARDWARE_SET_XP_TRANSMIT   PORTB |= (1 << PB5)
        #define XPRESSNET_TIMER            TIMER2
    #endif

    // XP railcom bridge
    // USART0
    #if (BOARD == BOARD_RAILCOM_XP_BRIDGE)
        #define XPRESSNET_UART             UART0                   // may be UART, UART0 or UART1
        #define HARDWARE_SET_XP_RECEIVE    PORTB &= ~(1 << PB7)
        #define HARDWARE_SET_XP_TRANSMIT   PORTB |= (1 << PB7)
        #define XPRESSNET_TIMER            TIMER2
    #endif

    #if (BOARD == JEAN_MICHEL_FISCHER)
        #define XPRESSNET_UART             UART
        #define HARDWARE_SET_XP_RECEIVE    PORTB &= ~(1 << PB2)
        #define HARDWARE_SET_XP_TRANSMIT   PORTB |= (1 << PB2)
        #define XPRESSNET_TIMER            TIMER2
    #endif

    #if (BOARD == BOARD_MFT)               // Version 1.0 or 1.1 of MyFirstThrottle
        #define XPRESSNET_UART             UART0
        #define HARDWARE_SET_XP_RECEIVE    { DISABLE_XP_TX; ENABLE_XP_RX; }
        #define HARDWARE_SET_XP_TRANSMIT   { DISABLE_XP_RX; ENABLE_XP_TX; }
        #define XPRESSNET_TIMER            TIMER0
    #endif

    #if (BOARD == BOARD_GATEWAY0)          // Gateway, Xpressnet connected to UART0 (XP-USB)
        #define XPRESSNET_UART             UART0
        #define HARDWARE_SET_XP_RECEIVE    { DISABLE_XP_TX; ENABLE_XP_RX; }
        #define HARDWARE_SET_XP_TRANSMIT   { DISABLE_XP_RX; ENABLE_XP_TX; }
        #define XPRESSNET_TIMER            TIMER0
    #endif

    #if (BOARD == BOARD_GATEWAY1)          // Gateway, Xpressnet connected to UART1 (XP-XBEE Bridge)
        #define XPRESSNET_UART             UART1
        #define HARDWARE_SET_XP_RECEIVE    { DISABLE_XP_TX; ENABLE_XP_RX; }
        #define HARDWARE_SET_XP_TRANSMIT   { DISABLE_XP_RX; ENABLE_XP_TX; }
        #define XPRESSNET_TIMER            TIMER0
    #endif

    #ifndef XPRESSNET_UART
        #warning SEVERE Warning - BOARD definition is void
    #endif

#endif  // ifndef BOARD

#endif  // __XP_CLIENT_HARDWARE_H__
