//----------------------------------------------------------------
//
// OpenDCC
//
// Copyright (c) 2006 Kufer
//
// This source file is subject of the GNU general public license 2,
// that is available at the world-wide-web at
// http://www.gnu.org/licenses/gpl.txt
//
//-----------------------------------------------------------------
//
// file:      xp_client_if.h
// author:    Wolfgang Kufer
// contact:   kufer@gmx.de
// history:   2008-07-11 V0.01 kw  started
//            2009-02-28 V0.02 kw  xp_active added
//
//-----------------------------------------------------------------
//
// purpose:   lowcost central station for dcc
// content:   routines for Xpressnet master (RS485)
//
//-----------------------------------------------------------------


#ifndef __XP_CLIENT_IF_H__
#define __XP_CLIENT_IF_H__

#include <stdbool.h>

typedef struct
  {
    union
      {
        struct
          {
            unsigned char size: 4;          // amount of data bytes without xor
            unsigned char type: 4;          // Lenz enum
          } ;
        unsigned char header;
      } ;
    unsigned char data[15];                 // the message content
  } t_xp_message;

// extern t_xp_message xp_tx_msg;
// extern volatile unsigned char xp_tx_msg_ready;

extern unsigned char slot_id;

typedef enum {SLOT_MANUAL, SLOT_AUTOMATIC} t_slot_mode;
extern t_slot_mode slot_mode;

extern unsigned char slots_in_use[32];

typedef enum
  {
    XP_DISCONNECTED             = 0x00,
    XP_CONNECTED                = 0x01,
  } xp_connect_t;

xp_connect_t xp_connect;




//=============================================================================
// Upstream Interface
//----------------------------------------------------------------------------
//
void init_xp_client_if(void);                   // setup the interrupts and fifos

void stop_xp_client_if(void);                   // disable further ints

void set_XP_to_receive(void);                   // raw hw access - direction in

void set_XP_to_transmit(void);                  // raw hw access - direction out

bool fifo_put_xp_out(t_xp_message *new_message);// message interface -here the main drops its
                                                // message

// local

bool XP_send_byte (const unsigned char c);       // sends one byte with isr and fifo, bit 8 = 0

bool XP_is_all_sent(void);                       // true if fifo is empty and all data are sent

bool XP_tx_ready (void);                         // true if byte can be sent

unsigned int XP_rx_read (void);                  // reads one byte (including call bytes)
bool XP_rx_ready (void);                         // true if one byte can be read




// debug only:

    #define X_RxBuffer_Size  64              // mind. 16
    extern unsigned int X_RxBuffer[X_RxBuffer_Size];

extern unsigned char X_rx_read_ptr;        // point to next read
extern unsigned char X_rx_write_ptr;       // point to next write
extern unsigned char X_rx_fill;



#if (DEBUG == 3)
  void X_push_to_rx(unsigned char d);
#endif


#endif  // __XP_CLIENT_IF_H__

